# org.openapitools.client - Kotlin client library for Lichess.org API reference

## Requires

* Kotlin 1.4.30
* Gradle 6.8.3

## Build

First, create the gradle wrapper script:

```
gradle wrapper
```

Then, run:

```
./gradlew check assemble
```

This runs all tests and packages the library.

## Features/Implementation Notes

* Supports JSON inputs/outputs, File inputs, and Form inputs.
* Supports collection formats for query parameters: csv, tsv, ssv, pipes.
* Some Kotlin and Java types are fully qualified to avoid conflicts with types defined in OpenAPI definitions.
* Implementation of ApiClient is intended to reduce method counts, specifically to benefit Android targets.

<a name="documentation-for-api-endpoints"></a>
## Documentation for API Endpoints

All URIs are relative to *https://lichess.org*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountApi* | [**account**](docs/AccountApi.md#account) | **GET** /api/account/preferences | Get my preferences
*AccountApi* | [**accountEmail**](docs/AccountApi.md#accountemail) | **GET** /api/account/email | Get my email address
*AccountApi* | [**accountKid**](docs/AccountApi.md#accountkid) | **GET** /api/account/kid | Get my kid mode status
*AccountApi* | [**accountKidPost**](docs/AccountApi.md#accountkidpost) | **POST** /api/account/kid | Set my kid mode status
*AccountApi* | [**accountMe**](docs/AccountApi.md#accountme) | **GET** /api/account | Get my profile
*AnalysisApi* | [**apiCloudEval**](docs/AnalysisApi.md#apicloudeval) | **GET** /api/cloud-eval | Get cloud evaluation of a position.
*ArenaTournamentsApi* | [**apiTeamArena**](docs/ArenaTournamentsApi.md#apiteamarena) | **GET** /api/team/{teamId}/arena | Get team Arena tournaments
*ArenaTournamentsApi* | [**apiTournament**](docs/ArenaTournamentsApi.md#apitournament) | **GET** /api/tournament | Get current tournaments
*ArenaTournamentsApi* | [**apiTournamentJoin**](docs/ArenaTournamentsApi.md#apitournamentjoin) | **POST** /api/tournament/{id}/join | Join an Arena tournament
*ArenaTournamentsApi* | [**apiTournamentPost**](docs/ArenaTournamentsApi.md#apitournamentpost) | **POST** /api/tournament | Create a new Arena tournament
*ArenaTournamentsApi* | [**apiTournamentTeamBattlePost**](docs/ArenaTournamentsApi.md#apitournamentteambattlepost) | **POST** /api/tournament/team-battle/{id} | Update a team battle
*ArenaTournamentsApi* | [**apiTournamentTerminate**](docs/ArenaTournamentsApi.md#apitournamentterminate) | **POST** /api/tournament/{id}/terminate | Terminate an Arena tournament
*ArenaTournamentsApi* | [**apiTournamentUpdate**](docs/ArenaTournamentsApi.md#apitournamentupdate) | **POST** /api/tournament/{id} | Update an Arena tournament
*ArenaTournamentsApi* | [**apiTournamentWithdraw**](docs/ArenaTournamentsApi.md#apitournamentwithdraw) | **POST** /api/tournament/{id}/withdraw | Pause of leave an Arena tournament
*ArenaTournamentsApi* | [**apiUserNameTournamentCreated**](docs/ArenaTournamentsApi.md#apiusernametournamentcreated) | **GET** /api/user/{username}/tournament/created | Get tournaments created by a user
*ArenaTournamentsApi* | [**gamesByTournament**](docs/ArenaTournamentsApi.md#gamesbytournament) | **GET** /api/tournament/{id}/games | Export games of an Arena tournament
*ArenaTournamentsApi* | [**resultsByTournament**](docs/ArenaTournamentsApi.md#resultsbytournament) | **GET** /api/tournament/{id}/results | Get results of an Arena tournament
*ArenaTournamentsApi* | [**teamsByTournament**](docs/ArenaTournamentsApi.md#teamsbytournament) | **GET** /api/tournament/{id}/teams | Get team standing of a team battle
*ArenaTournamentsApi* | [**tournament**](docs/ArenaTournamentsApi.md#tournament) | **GET** /api/tournament/{id} | Get info about an Arena tournament
*BoardApi* | [**apiBoardSeek**](docs/BoardApi.md#apiboardseek) | **POST** /api/board/seek | Create a seek
*BoardApi* | [**apiStreamEvent**](docs/BoardApi.md#apistreamevent) | **GET** /api/stream/event | Stream incoming events
*BoardApi* | [**boardGameAbort**](docs/BoardApi.md#boardgameabort) | **POST** /api/board/game/{gameId}/abort | Abort a game
*BoardApi* | [**boardGameChatGet**](docs/BoardApi.md#boardgamechatget) | **GET** /api/board/game/{gameId}/chat | Fetch the game chat
*BoardApi* | [**boardGameChatPost**](docs/BoardApi.md#boardgamechatpost) | **POST** /api/board/game/{gameId}/chat | Write in the chat
*BoardApi* | [**boardGameClaimVictory**](docs/BoardApi.md#boardgameclaimvictory) | **POST** /api/board/game/{gameId}/claim-victory | Claim victory of a game
*BoardApi* | [**boardGameDraw**](docs/BoardApi.md#boardgamedraw) | **POST** /api/board/game/{gameId}/draw/{accept} | Handle draw offers
*BoardApi* | [**boardGameMove**](docs/BoardApi.md#boardgamemove) | **POST** /api/board/game/{gameId}/move/{move} | Make a Board move
*BoardApi* | [**boardGameResign**](docs/BoardApi.md#boardgameresign) | **POST** /api/board/game/{gameId}/resign | Resign a game
*BoardApi* | [**boardGameStream**](docs/BoardApi.md#boardgamestream) | **GET** /api/board/game/stream/{gameId} | Stream Board game state
*BoardApi* | [**boardGameTakeback**](docs/BoardApi.md#boardgametakeback) | **POST** /api/board/game/{gameId}/takeback/{accept} | Handle takeback offers
*BotApi* | [**apiBotOnline**](docs/BotApi.md#apibotonline) | **GET** /api/bot/online | Get online bots
*BotApi* | [**apiStreamEvent**](docs/BotApi.md#apistreamevent) | **GET** /api/stream/event | Stream incoming events
*BotApi* | [**botAccountUpgrade**](docs/BotApi.md#botaccountupgrade) | **POST** /api/bot/account/upgrade | Upgrade to Bot account
*BotApi* | [**botGameAbort**](docs/BotApi.md#botgameabort) | **POST** /api/bot/game/{gameId}/abort | Abort a game
*BotApi* | [**botGameChat**](docs/BotApi.md#botgamechat) | **POST** /api/bot/game/{gameId}/chat | Write in the chat
*BotApi* | [**botGameMove**](docs/BotApi.md#botgamemove) | **POST** /api/bot/game/{gameId}/move/{move} | Make a Bot move
*BotApi* | [**botGameResign**](docs/BotApi.md#botgameresign) | **POST** /api/bot/game/{gameId}/resign | Resign a game
*BotApi* | [**botGameStream**](docs/BotApi.md#botgamestream) | **GET** /api/bot/game/stream/{gameId} | Stream Bot game state
*BroadcastsApi* | [**broadcastAllRoundsPgn**](docs/BroadcastsApi.md#broadcastallroundspgn) | **GET** /api/broadcast/{broadcastTournamentId}.pgn | Export all rounds as PGN
*BroadcastsApi* | [**broadcastIndex**](docs/BroadcastsApi.md#broadcastindex) | **GET** /api/broadcast | Get official broadcasts
*BroadcastsApi* | [**broadcastPush**](docs/BroadcastsApi.md#broadcastpush) | **POST** /broadcast/round/{broadcastRoundId}/push | Push PGN to your broadcast round
*BroadcastsApi* | [**broadcastRoundCreate**](docs/BroadcastsApi.md#broadcastroundcreate) | **POST** /broadcast/{broadcastTournamentId}/new | Create a broadcast round
*BroadcastsApi* | [**broadcastRoundGet**](docs/BroadcastsApi.md#broadcastroundget) | **GET** /broadcast/{broadcastTournamentSlug}/{broadcastRoundSlug}/{broadcastRoundId} | Get your broadcast round
*BroadcastsApi* | [**broadcastRoundPgn**](docs/BroadcastsApi.md#broadcastroundpgn) | **GET** /api/broadcast/round/{broadcastRoundId}.pgn | Export one round as PGN
*BroadcastsApi* | [**broadcastRoundUpdate**](docs/BroadcastsApi.md#broadcastroundupdate) | **POST** /broadcast/round/{broadcastRoundId}/edit | Update your broadcast round
*BroadcastsApi* | [**broadcastStreamRoundPgn**](docs/BroadcastsApi.md#broadcaststreamroundpgn) | **GET** /api/stream/broadcast/round/{broadcastRoundId}.pgn | Stream an ongoing broadcast tournament as PGN
*BroadcastsApi* | [**broadcastTourCreate**](docs/BroadcastsApi.md#broadcasttourcreate) | **POST** /broadcast/new | Create a broadcast tournament
*BroadcastsApi* | [**broadcastTourGet**](docs/BroadcastsApi.md#broadcasttourget) | **GET** /broadcast/{slug}/{broadcastTournamentId} | Get your broadcast tournament
*BroadcastsApi* | [**broadcastTourUpdate**](docs/BroadcastsApi.md#broadcasttourupdate) | **POST** /broadcast/{broadcastTournamentId}/edit | Update your broadcast tournament
*BulkPairingsApi* | [**bulkPairingCreate**](docs/BulkPairingsApi.md#bulkpairingcreate) | **POST** /api/bulk-pairing | Create a bulk pairing
*BulkPairingsApi* | [**bulkPairingDelete**](docs/BulkPairingsApi.md#bulkpairingdelete) | **DELETE** /api/bulk-pairing/{id} | Cancel a bulk pairing
*BulkPairingsApi* | [**bulkPairingGet**](docs/BulkPairingsApi.md#bulkpairingget) | **GET** /api/bulk-pairing | View upcoming bulk pairings
*BulkPairingsApi* | [**bulkPairingStartClocks**](docs/BulkPairingsApi.md#bulkpairingstartclocks) | **POST** /api/bulk-pairing/{id}/start-clocks | Manually start clocks
*ChallengesApi* | [**adminChallengeTokens**](docs/ChallengesApi.md#adminchallengetokens) | **POST** /api/token/admin-challenge | Admin challenge tokens
*ChallengesApi* | [**challengeAccept**](docs/ChallengesApi.md#challengeaccept) | **POST** /api/challenge/{challengeId}/accept | Accept a challenge
*ChallengesApi* | [**challengeAi**](docs/ChallengesApi.md#challengeai) | **POST** /api/challenge/ai | Challenge the AI
*ChallengesApi* | [**challengeCancel**](docs/ChallengesApi.md#challengecancel) | **POST** /api/challenge/{challengeId}/cancel | Cancel a challenge
*ChallengesApi* | [**challengeCreate**](docs/ChallengesApi.md#challengecreate) | **POST** /api/challenge/{username} | Create a challenge
*ChallengesApi* | [**challengeDecline**](docs/ChallengesApi.md#challengedecline) | **POST** /api/challenge/{challengeId}/decline | Decline a challenge
*ChallengesApi* | [**challengeList**](docs/ChallengesApi.md#challengelist) | **GET** /api/challenge | List your challenges
*ChallengesApi* | [**challengeOpen**](docs/ChallengesApi.md#challengeopen) | **POST** /api/challenge/open | Open-ended challenge
*ChallengesApi* | [**challengeStartClocks**](docs/ChallengesApi.md#challengestartclocks) | **POST** /api/challenge/{gameId}/start-clocks | Start clocks of a game
*ChallengesApi* | [**roundAddTime**](docs/ChallengesApi.md#roundaddtime) | **POST** /api/round/{gameId}/add-time/{seconds} | Add time to the opponent clock
*GamesApi* | [**apiAccountPlaying**](docs/GamesApi.md#apiaccountplaying) | **GET** /api/account/playing | Get my ongoing games
*GamesApi* | [**apiGamesUser**](docs/GamesApi.md#apigamesuser) | **GET** /api/games/user/{username} | Export games of a user
*GamesApi* | [**apiUserCurrentGame**](docs/GamesApi.md#apiusercurrentgame) | **GET** /api/user/{username}/current-game | Export ongoing game of a user
*GamesApi* | [**gameImport**](docs/GamesApi.md#gameimport) | **POST** /api/import | Import one game
*GamesApi* | [**gamePgn**](docs/GamesApi.md#gamepgn) | **GET** /game/export/{gameId} | Export one game
*GamesApi* | [**gamesByUsers**](docs/GamesApi.md#gamesbyusers) | **POST** /api/stream/games-by-users | Stream games of users
*GamesApi* | [**gamesExportIds**](docs/GamesApi.md#gamesexportids) | **POST** /games/export/_ids | Export games by IDs
*GamesApi* | [**streamGame**](docs/GamesApi.md#streamgame) | **GET** /api/stream/game/{id} | Stream moves of a game
*MessagingApi* | [**inboxUsername**](docs/MessagingApi.md#inboxusername) | **POST** /inbox/{username} | Send a private message
*OAuthApi* | [**apiToken**](docs/OAuthApi.md#apitoken) | **POST** /api/token | Obtain access token
*OAuthApi* | [**apiTokenDelete**](docs/OAuthApi.md#apitokendelete) | **DELETE** /api/token | Revoke access token
*OAuthApi* | [**oauth**](docs/OAuthApi.md#oauth) | **GET** /oauth | Request authorization code
*OpeningExplorerApi* | [**openingExplorerLichess**](docs/OpeningExplorerApi.md#openingexplorerlichess) | **GET** /lichess | Lichess games
*OpeningExplorerApi* | [**openingExplorerMaster**](docs/OpeningExplorerApi.md#openingexplorermaster) | **GET** /masters | Masters database
*OpeningExplorerApi* | [**openingExplorerMasterGame**](docs/OpeningExplorerApi.md#openingexplorermastergame) | **GET** /master/pgn/{gameId} | OTB master game
*OpeningExplorerApi* | [**openingExplorerPlayer**](docs/OpeningExplorerApi.md#openingexplorerplayer) | **GET** /player? | Player games
*PuzzlesApi* | [**apiPuzzleActivity**](docs/PuzzlesApi.md#apipuzzleactivity) | **GET** /api/puzzle/activity | Get your puzzle activity
*PuzzlesApi* | [**apiPuzzleDaily**](docs/PuzzlesApi.md#apipuzzledaily) | **GET** /api/puzzle/daily | Get the daily puzzle
*PuzzlesApi* | [**apiPuzzleDashboard**](docs/PuzzlesApi.md#apipuzzledashboard) | **GET** /api/puzzle/dashboard/{days} | Get your puzzle dashboard
*PuzzlesApi* | [**apiStormDashboard**](docs/PuzzlesApi.md#apistormdashboard) | **GET** /api/storm/dashboard/{username} | Get the storm dashboard of a player
*RelationsApi* | [**apiUserFollowing**](docs/RelationsApi.md#apiuserfollowing) | **GET** /api/rel/following | Get users followed the logged in user
*RelationsApi* | [**followUser**](docs/RelationsApi.md#followuser) | **POST** /api/rel/follow/{username} | Follow a player
*RelationsApi* | [**unfollowUser**](docs/RelationsApi.md#unfollowuser) | **POST** /api/rel/unfollow/{username} | Unfollow a player
*SimulsApi* | [**apiSimul**](docs/SimulsApi.md#apisimul) | **GET** /api/simul | Get current simuls
*StudiesApi* | [**studyAllChaptersPgn**](docs/StudiesApi.md#studyallchapterspgn) | **GET** /api/study/{studyId}.pgn | Export all chapters
*StudiesApi* | [**studyChapterPgn**](docs/StudiesApi.md#studychapterpgn) | **GET** /study/{studyId}/{chapterId}.pgn | Export one study chapter
*StudiesApi* | [**studyExportAllPgn**](docs/StudiesApi.md#studyexportallpgn) | **GET** /study/by/{username}/export.pgn | Export all studies of a user
*SwissTournamentsApi* | [**apiSwissJoin**](docs/SwissTournamentsApi.md#apiswissjoin) | **POST** /api/swiss/{id}/join | Join a Swiss tournament
*SwissTournamentsApi* | [**apiSwissNew**](docs/SwissTournamentsApi.md#apiswissnew) | **POST** /api/swiss/new/{teamId} | Create a new Swiss tournament
*SwissTournamentsApi* | [**apiSwissTerminate**](docs/SwissTournamentsApi.md#apiswissterminate) | **POST** /api/swiss/{id}/terminate | Terminate a Swiss tournament
*SwissTournamentsApi* | [**apiSwissUpdate**](docs/SwissTournamentsApi.md#apiswissupdate) | **POST** /api/swiss/{id}/edit | Update a Swiss tournament.
*SwissTournamentsApi* | [**apiTeamSwiss**](docs/SwissTournamentsApi.md#apiteamswiss) | **GET** /api/team/{teamId}/swiss | Get team swiss tournaments
*SwissTournamentsApi* | [**gamesBySwiss**](docs/SwissTournamentsApi.md#gamesbyswiss) | **GET** /api/swiss/{id}/games | Export games of a Swiss tournament
*SwissTournamentsApi* | [**resultsBySwiss**](docs/SwissTournamentsApi.md#resultsbyswiss) | **GET** /api/swiss/{id}/results | Get results of a swiss tournament
*SwissTournamentsApi* | [**swissTrf**](docs/SwissTournamentsApi.md#swisstrf) | **GET** /swiss/{id}.trf | Export TRF of a Swiss tournament
*TVApi* | [**tvChannelGames**](docs/TVApi.md#tvchannelgames) | **GET** /api/tv/{channel} | Get best ongoing games of a TV channel
*TVApi* | [**tvChannels**](docs/TVApi.md#tvchannels) | **GET** /api/tv/channels | Get current TV games
*TVApi* | [**tvFeed**](docs/TVApi.md#tvfeed) | **GET** /api/tv/feed | Stream current TV game
*TablebaseApi* | [**antichessAtomic**](docs/TablebaseApi.md#antichessatomic) | **GET** /antichess | Tablebase lookup for Antichess
*TablebaseApi* | [**tablebaseAtomic**](docs/TablebaseApi.md#tablebaseatomic) | **GET** /atomic | Tablebase lookup for Atomic chess
*TablebaseApi* | [**tablebaseStandard**](docs/TablebaseApi.md#tablebasestandard) | **GET** /standard | Tablebase lookup
*TeamsApi* | [**apiTeamArena**](docs/TeamsApi.md#apiteamarena) | **GET** /api/team/{teamId}/arena | Get team Arena tournaments
*TeamsApi* | [**apiTeamSwiss**](docs/TeamsApi.md#apiteamswiss) | **GET** /api/team/{teamId}/swiss | Get team swiss tournaments
*TeamsApi* | [**teamAll**](docs/TeamsApi.md#teamall) | **GET** /api/team/all | Get popular teams
*TeamsApi* | [**teamIdJoin**](docs/TeamsApi.md#teamidjoin) | **POST** /team/{teamId}/join | Join a team
*TeamsApi* | [**teamIdKickUserId**](docs/TeamsApi.md#teamidkickuserid) | **POST** /team/{teamId}/kick/{userId} | Kick a user from your team
*TeamsApi* | [**teamIdPmAll**](docs/TeamsApi.md#teamidpmall) | **POST** /team/{teamId}/pm-all | Message all members
*TeamsApi* | [**teamIdQuit**](docs/TeamsApi.md#teamidquit) | **POST** /team/{teamId}/quit | Leave a team
*TeamsApi* | [**teamIdUsers**](docs/TeamsApi.md#teamidusers) | **GET** /api/team/{teamId}/users | Get members of a team
*TeamsApi* | [**teamOfUsername**](docs/TeamsApi.md#teamofusername) | **GET** /api/team/of/{username} | Teams of a player
*TeamsApi* | [**teamSearch**](docs/TeamsApi.md#teamsearch) | **GET** /api/team/search | Search teams
*TeamsApi* | [**teamShow**](docs/TeamsApi.md#teamshow) | **GET** /api/team/{teamId} | Get a single team
*UsersApi* | [**apiCrosstable**](docs/UsersApi.md#apicrosstable) | **GET** /api/crosstable/{user1}/{user2} | Get crosstable
*UsersApi* | [**apiUser**](docs/UsersApi.md#apiuser) | **GET** /api/user/{username} | Get user public data
*UsersApi* | [**apiUserActivity**](docs/UsersApi.md#apiuseractivity) | **GET** /api/user/{username}/activity | Get user activity
*UsersApi* | [**apiUserPerf**](docs/UsersApi.md#apiuserperf) | **GET** /api/user/{username}/perf/{perf} | Get performance statistics of a user
*UsersApi* | [**apiUserRatingHistory**](docs/UsersApi.md#apiuserratinghistory) | **GET** /api/user/{username}/rating-history | Get rating history of a user
*UsersApi* | [**apiUsers**](docs/UsersApi.md#apiusers) | **POST** /api/users | Get users by ID
*UsersApi* | [**apiUsersStatus**](docs/UsersApi.md#apiusersstatus) | **GET** /api/users/status | Get real-time users status
*UsersApi* | [**player**](docs/UsersApi.md#player) | **GET** /player | Get all top 10
*UsersApi* | [**playerTopNbPerfType**](docs/UsersApi.md#playertopnbperftype) | **GET** /player/top/{nb}/{perfType} | Get one leaderboard
*UsersApi* | [**streamerLive**](docs/UsersApi.md#streamerlive) | **GET** /streamer/live | Get live streamers
*UsersApi* | [**teamIdUsers**](docs/UsersApi.md#teamidusers) | **GET** /api/team/{teamId}/users | Get members of a team


<a name="documentation-for-models"></a>
## Documentation for Models

 - [org.openapitools.client.models.ApiStreamEvent](docs/ApiStreamEvent.md)
 - [org.openapitools.client.models.ArenaTournaments](docs/ArenaTournaments.md)
 - [org.openapitools.client.models.ChallengeCanceledEvent](docs/ChallengeCanceledEvent.md)
 - [org.openapitools.client.models.ChallengeDeclinedEvent](docs/ChallengeDeclinedEvent.md)
 - [org.openapitools.client.models.ChallengeEvent](docs/ChallengeEvent.md)
 - [org.openapitools.client.models.ChallengeJson](docs/ChallengeJson.md)
 - [org.openapitools.client.models.ChallengeJsonPerf](docs/ChallengeJsonPerf.md)
 - [org.openapitools.client.models.ChallengeUser](docs/ChallengeUser.md)
 - [org.openapitools.client.models.ChatLineEvent](docs/ChatLineEvent.md)
 - [org.openapitools.client.models.Clock](docs/Clock.md)
 - [org.openapitools.client.models.Count](docs/Count.md)
 - [org.openapitools.client.models.Error](docs/Error.md)
 - [org.openapitools.client.models.GameEventInfo](docs/GameEventInfo.md)
 - [org.openapitools.client.models.GameEventInfoCompat](docs/GameEventInfoCompat.md)
 - [org.openapitools.client.models.GameEventPlayer](docs/GameEventPlayer.md)
 - [org.openapitools.client.models.GameFinishEvent](docs/GameFinishEvent.md)
 - [org.openapitools.client.models.GameFullEvent](docs/GameFullEvent.md)
 - [org.openapitools.client.models.GameFullEventPerf](docs/GameFullEventPerf.md)
 - [org.openapitools.client.models.GameJson](docs/GameJson.md)
 - [org.openapitools.client.models.GameJsonAnalysis](docs/GameJsonAnalysis.md)
 - [org.openapitools.client.models.GameJsonClock](docs/GameJsonClock.md)
 - [org.openapitools.client.models.GameJsonJudgment](docs/GameJsonJudgment.md)
 - [org.openapitools.client.models.GameJsonOpening](docs/GameJsonOpening.md)
 - [org.openapitools.client.models.GameJsonPlayers](docs/GameJsonPlayers.md)
 - [org.openapitools.client.models.GameStartEvent](docs/GameStartEvent.md)
 - [org.openapitools.client.models.GameStateEvent](docs/GameStateEvent.md)
 - [org.openapitools.client.models.GameStatus](docs/GameStatus.md)
 - [org.openapitools.client.models.GameStreamEvent](docs/GameStreamEvent.md)
 - [org.openapitools.client.models.GameUser](docs/GameUser.md)
 - [org.openapitools.client.models.GameUserAnalysis](docs/GameUserAnalysis.md)
 - [org.openapitools.client.models.InlineResponse200](docs/InlineResponse200.md)
 - [org.openapitools.client.models.InlineResponse2001](docs/InlineResponse2001.md)
 - [org.openapitools.client.models.InlineResponse2002](docs/InlineResponse2002.md)
 - [org.openapitools.client.models.InlineResponse2003](docs/InlineResponse2003.md)
 - [org.openapitools.client.models.LightUser](docs/LightUser.md)
 - [org.openapitools.client.models.Move](docs/Move.md)
 - [org.openapitools.client.models.NotFound](docs/NotFound.md)
 - [org.openapitools.client.models.Ok](docs/Ok.md)
 - [org.openapitools.client.models.Perf](docs/Perf.md)
 - [org.openapitools.client.models.PerfType](docs/PerfType.md)
 - [org.openapitools.client.models.Perfs](docs/Perfs.md)
 - [org.openapitools.client.models.PlayTime](docs/PlayTime.md)
 - [org.openapitools.client.models.Profile](docs/Profile.md)
 - [org.openapitools.client.models.PuzzleRoundJson](docs/PuzzleRoundJson.md)
 - [org.openapitools.client.models.Speed](docs/Speed.md)
 - [org.openapitools.client.models.StormPerf](docs/StormPerf.md)
 - [org.openapitools.client.models.SwissUnauthorisedEdit](docs/SwissUnauthorisedEdit.md)
 - [org.openapitools.client.models.TablebaseJson](docs/TablebaseJson.md)
 - [org.openapitools.client.models.Team](docs/Team.md)
 - [org.openapitools.client.models.TimeControl](docs/TimeControl.md)
 - [org.openapitools.client.models.TimeControlClock](docs/TimeControlClock.md)
 - [org.openapitools.client.models.TimeControlClockAllOf](docs/TimeControlClockAllOf.md)
 - [org.openapitools.client.models.TimeControlCorrespondence](docs/TimeControlCorrespondence.md)
 - [org.openapitools.client.models.TimeControlCorrespondenceAllOf](docs/TimeControlCorrespondenceAllOf.md)
 - [org.openapitools.client.models.TimeControlUnlimited](docs/TimeControlUnlimited.md)
 - [org.openapitools.client.models.Title](docs/Title.md)
 - [org.openapitools.client.models.User](docs/User.md)
 - [org.openapitools.client.models.UserExtended](docs/UserExtended.md)
 - [org.openapitools.client.models.UserExtendedAllOf](docs/UserExtendedAllOf.md)
 - [org.openapitools.client.models.UserPreferences](docs/UserPreferences.md)
 - [org.openapitools.client.models.Variant](docs/Variant.md)
 - [org.openapitools.client.models.VariantKey](docs/VariantKey.md)


<a name="documentation-for-authorization"></a>
## Documentation for Authorization

<a name="OAuth2"></a>
### OAuth2

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://lichess.org/oauth
- **Scopes**: 
  - preference:read: Read your preferences
  - preference:write: Write your preferences
  - email:read: Read your email address
  - challenge:read: Read incoming challenges
  - challenge:write: Create, accept, decline challenges
  - challenge:bulk: Create, delete, query bulk pairings
  - study:read: Read private studies and broadcasts
  - study:write: Create, update, delete studies and broadcasts
  - tournament:write: Create tournaments
  - puzzle:read: Read puzzle activity
  - team:read: Read private team information
  - team:write: Join, leave, and manage teams
  - follow:write: Follow and unfollow other players
  - msg:write: Send private messages to other players
  - board:play: Play with the Board API
  - bot:play: Play with the Bot API. Only for [Bot accounts](#operation/botAccountUpgrade)
  - web:mod: Use moderator tools (within the bounds of your permissions)

