# ArenaTournamentsApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiTeamArena**](ArenaTournamentsApi.md#apiTeamArena) | **GET** /api/team/{teamId}/arena | Get team Arena tournaments
[**apiTournament**](ArenaTournamentsApi.md#apiTournament) | **GET** /api/tournament | Get current tournaments
[**apiTournamentJoin**](ArenaTournamentsApi.md#apiTournamentJoin) | **POST** /api/tournament/{id}/join | Join an Arena tournament
[**apiTournamentPost**](ArenaTournamentsApi.md#apiTournamentPost) | **POST** /api/tournament | Create a new Arena tournament
[**apiTournamentTeamBattlePost**](ArenaTournamentsApi.md#apiTournamentTeamBattlePost) | **POST** /api/tournament/team-battle/{id} | Update a team battle
[**apiTournamentTerminate**](ArenaTournamentsApi.md#apiTournamentTerminate) | **POST** /api/tournament/{id}/terminate | Terminate an Arena tournament
[**apiTournamentUpdate**](ArenaTournamentsApi.md#apiTournamentUpdate) | **POST** /api/tournament/{id} | Update an Arena tournament
[**apiTournamentWithdraw**](ArenaTournamentsApi.md#apiTournamentWithdraw) | **POST** /api/tournament/{id}/withdraw | Pause of leave an Arena tournament
[**apiUserNameTournamentCreated**](ArenaTournamentsApi.md#apiUserNameTournamentCreated) | **GET** /api/user/{username}/tournament/created | Get tournaments created by a user
[**gamesByTournament**](ArenaTournamentsApi.md#gamesByTournament) | **GET** /api/tournament/{id}/games | Export games of an Arena tournament
[**resultsByTournament**](ArenaTournamentsApi.md#resultsByTournament) | **GET** /api/tournament/{id}/results | Get results of an Arena tournament
[**teamsByTournament**](ArenaTournamentsApi.md#teamsByTournament) | **GET** /api/tournament/{id}/teams | Get team standing of a team battle
[**tournament**](ArenaTournamentsApi.md#tournament) | **GET** /api/tournament/{id} | Get info about an Arena tournament


<a name="apiTeamArena"></a>
# **apiTeamArena**
> kotlin.collections.List&lt;kotlin.Any&gt; apiTeamArena(teamId, max)

Get team Arena tournaments

Get all Arena tournaments relevant to a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = ArenaTournamentsApi()
val teamId : kotlin.String = teamId_example // kotlin.String | ID of the team
val max : kotlin.Int = 56 // kotlin.Int | How many tournaments to download.
try {
    val result : kotlin.collections.List<kotlin.Any> = apiInstance.apiTeamArena(teamId, max)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling ArenaTournamentsApi#apiTeamArena")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling ArenaTournamentsApi#apiTeamArena")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | **kotlin.String**| ID of the team |
 **max** | **kotlin.Int**| How many tournaments to download. | [optional] [default to 100]

### Return type

[**kotlin.collections.List&lt;kotlin.Any&gt;**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="apiTournament"></a>
# **apiTournament**
> ArenaTournaments apiTournament()

Get current tournaments

Get recently finished, ongoing, and upcoming tournaments.  This API is used to display the [Lichess tournament schedule](https://lichess.org/tournament). 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = ArenaTournamentsApi()
try {
    val result : ArenaTournaments = apiInstance.apiTournament()
    println(result)
} catch (e: ClientException) {
    println("4xx response calling ArenaTournamentsApi#apiTournament")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling ArenaTournamentsApi#apiTournament")
    e.printStackTrace()
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**ArenaTournaments**](ArenaTournaments.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="apiTournamentJoin"></a>
# **apiTournamentJoin**
> Ok apiTournamentJoin(id, password, team)

Join an Arena tournament

Join an Arena tournament, possibly with a password and/or a team. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = ArenaTournamentsApi()
val id : kotlin.String = hL7vMrFQ // kotlin.String | The tournament ID.
val password : kotlin.String = password_example // kotlin.String | The tournament password, if one is required
val team : kotlin.String = team_example // kotlin.String | The team to join the tournament with, for team battle tournaments
try {
    val result : Ok = apiInstance.apiTournamentJoin(id, password, team)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling ArenaTournamentsApi#apiTournamentJoin")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling ArenaTournamentsApi#apiTournamentJoin")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **kotlin.String**| The tournament ID. |
 **password** | **kotlin.String**| The tournament password, if one is required | [optional]
 **team** | **kotlin.String**| The team to join the tournament with, for team battle tournaments | [optional]

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

<a name="apiTournamentPost"></a>
# **apiTournamentPost**
> kotlin.Any apiTournamentPost(clockTime, clockIncrement, minutes, name, waitMinutes, startDate, variant, rated, position, berserkable, streakable, hasChat, description, password, teambBattleByTeam, conditionsTeamMemberTeamId, conditionsMinRatingRating, conditionsMaxRatingRating, conditionsNbRatedGameNb)

Create a new Arena tournament

Create a public or private Arena tournament.  This endpoint mirrors the form on &lt;https://lichess.org/tournament/new&gt;.  You can create up to 12 public tournaments per day, or 24 private tournaments.  A team battle can be created by specifying the &#x60;teambBattleByTeam&#x60; argument. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = ArenaTournamentsApi()
val clockTime : java.math.BigDecimal = 8.14 // java.math.BigDecimal | Clock initial time in minutes
val clockIncrement : kotlin.Int = 56 // kotlin.Int | Clock increment in seconds
val minutes : kotlin.Int = 56 // kotlin.Int | How long the tournament lasts, in minutes
val name : kotlin.String = name_example // kotlin.String | The tournament name. Leave empty to get a random Grandmaster name
val waitMinutes : kotlin.Int = 56 // kotlin.Int | How long to wait before starting the tournament, from now, in minutes
val startDate : kotlin.Int = 56 // kotlin.Int | Timestamp to start the tournament at a given date and time. Overrides the `waitMinutes` setting
val variant : VariantKey =  // VariantKey | 
val rated : kotlin.Boolean = true // kotlin.Boolean | Games are rated and impact players ratings
val position : kotlin.String = position_example // kotlin.String | Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960).
val berserkable : kotlin.Boolean = true // kotlin.Boolean | Whether the players can use berserk
val streakable : kotlin.Boolean = true // kotlin.Boolean | After 2 wins, consecutive wins grant 4 points instead of 2.
val hasChat : kotlin.Boolean = true // kotlin.Boolean | Whether the players can discuss in a chat
val description : kotlin.String = description_example // kotlin.String | Anything you want to tell players about the tournament
val password : kotlin.String = password_example // kotlin.String | Make the tournament private, and restrict access with a password
val teambBattleByTeam : kotlin.String = teambBattleByTeam_example // kotlin.String | Set the ID of a team you lead to create a team battle. The other teams can be added using the [team battle edit endpoint](#operation/apiTournamentTeamBattlePost). 
val conditionsTeamMemberTeamId : kotlin.String = conditionsTeamMemberTeamId_example // kotlin.String | Restrict entry to members of a team.  The teamId is the last part of a team URL, e.g. `https://lichess.org/team/coders` has teamId = `coders`.  Leave empty to let everyone join the tournament.  Do not use this to create team battles, use `teamBattleByTeam` instead. 
val conditionsMinRatingRating : kotlin.Int = 56 // kotlin.Int | Minimum rating to join. Leave empty to let everyone join the tournament.
val conditionsMaxRatingRating : kotlin.Int = 56 // kotlin.Int | Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament.
val conditionsNbRatedGameNb : kotlin.Int = 56 // kotlin.Int | Minimum number of rated games required to join.
try {
    val result : kotlin.Any = apiInstance.apiTournamentPost(clockTime, clockIncrement, minutes, name, waitMinutes, startDate, variant, rated, position, berserkable, streakable, hasChat, description, password, teambBattleByTeam, conditionsTeamMemberTeamId, conditionsMinRatingRating, conditionsMaxRatingRating, conditionsNbRatedGameNb)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling ArenaTournamentsApi#apiTournamentPost")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling ArenaTournamentsApi#apiTournamentPost")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **clockTime** | **java.math.BigDecimal**| Clock initial time in minutes | [enum: 0, 0.25, 0.5, 0.75, 1, 1.5, 2, 3, 4, 5, 6, 7, 10, 15, 20, 25, 30, 40, 50, 60]
 **clockIncrement** | **kotlin.Int**| Clock increment in seconds |
 **minutes** | **kotlin.Int**| How long the tournament lasts, in minutes |
 **name** | **kotlin.String**| The tournament name. Leave empty to get a random Grandmaster name | [optional]
 **waitMinutes** | **kotlin.Int**| How long to wait before starting the tournament, from now, in minutes | [optional] [default to 5]
 **startDate** | **kotlin.Int**| Timestamp to start the tournament at a given date and time. Overrides the &#x60;waitMinutes&#x60; setting | [optional]
 **variant** | [**VariantKey**](VariantKey.md)|  | [optional] [default to standard] [enum: standard, chess960, crazyhouse, antichess, atomic, horde, kingOfTheHill, racingKings, threeCheck]
 **rated** | **kotlin.Boolean**| Games are rated and impact players ratings | [optional] [default to true]
 **position** | **kotlin.String**| Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960). | [optional]
 **berserkable** | **kotlin.Boolean**| Whether the players can use berserk | [optional] [default to true]
 **streakable** | **kotlin.Boolean**| After 2 wins, consecutive wins grant 4 points instead of 2. | [optional] [default to true]
 **hasChat** | **kotlin.Boolean**| Whether the players can discuss in a chat | [optional] [default to true]
 **description** | **kotlin.String**| Anything you want to tell players about the tournament | [optional]
 **password** | **kotlin.String**| Make the tournament private, and restrict access with a password | [optional]
 **teambBattleByTeam** | **kotlin.String**| Set the ID of a team you lead to create a team battle. The other teams can be added using the [team battle edit endpoint](#operation/apiTournamentTeamBattlePost).  | [optional]
 **conditionsTeamMemberTeamId** | **kotlin.String**| Restrict entry to members of a team.  The teamId is the last part of a team URL, e.g. &#x60;https://lichess.org/team/coders&#x60; has teamId &#x3D; &#x60;coders&#x60;.  Leave empty to let everyone join the tournament.  Do not use this to create team battles, use &#x60;teamBattleByTeam&#x60; instead.  | [optional]
 **conditionsMinRatingRating** | **kotlin.Int**| Minimum rating to join. Leave empty to let everyone join the tournament. | [optional]
 **conditionsMaxRatingRating** | **kotlin.Int**| Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament. | [optional]
 **conditionsNbRatedGameNb** | **kotlin.Int**| Minimum number of rated games required to join. | [optional]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

<a name="apiTournamentTeamBattlePost"></a>
# **apiTournamentTeamBattlePost**
> kotlin.Any apiTournamentTeamBattlePost(id, teams, nbLeaders)

Update a team battle

Set the teams and number of leaders of a team battle.  To update the other attributes of a team battle, use the [tournament update endpoint](#operation/apiTournamentUpdate). 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = ArenaTournamentsApi()
val id : kotlin.String = id_example // kotlin.String | The tournament ID (8 characters)..
val teams : kotlin.String = teams_example // kotlin.String | All team IDs of the team battle, separated by commas. Make sure to always send the full list. Teams that are not in the list will be removed from the team battle.  Example: `coders,zhigalko_sergei-fan-club,hhSwTKZv` 
val nbLeaders : kotlin.Int = 56 // kotlin.Int | Number team leaders per team.
try {
    val result : kotlin.Any = apiInstance.apiTournamentTeamBattlePost(id, teams, nbLeaders)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling ArenaTournamentsApi#apiTournamentTeamBattlePost")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling ArenaTournamentsApi#apiTournamentTeamBattlePost")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **kotlin.String**| The tournament ID (8 characters).. |
 **teams** | **kotlin.String**| All team IDs of the team battle, separated by commas. Make sure to always send the full list. Teams that are not in the list will be removed from the team battle.  Example: &#x60;coders,zhigalko_sergei-fan-club,hhSwTKZv&#x60;  |
 **nbLeaders** | **kotlin.Int**| Number team leaders per team. |

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

<a name="apiTournamentTerminate"></a>
# **apiTournamentTerminate**
> Ok apiTournamentTerminate(id)

Terminate an Arena tournament

Terminate an Arena tournament 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = ArenaTournamentsApi()
val id : kotlin.String = hL7vMrFQ // kotlin.String | The tournament ID.
try {
    val result : Ok = apiInstance.apiTournamentTerminate(id)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling ArenaTournamentsApi#apiTournamentTerminate")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling ArenaTournamentsApi#apiTournamentTerminate")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **kotlin.String**| The tournament ID. |

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="apiTournamentUpdate"></a>
# **apiTournamentUpdate**
> kotlin.Any apiTournamentUpdate(id, clockTime, clockIncrement, minutes, name, waitMinutes, startDate, variant, rated, position, berserkable, streakable, hasChat, description, password, conditionsMinRatingRating, conditionsMaxRatingRating, conditionsNbRatedGameNb)

Update an Arena tournament

Update an Arena tournament.  Be mindful not to make important changes to ongoing tournaments.  Can be used to update a team battle. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = ArenaTournamentsApi()
val id : kotlin.String = id_example // kotlin.String | The tournament ID.
val clockTime : java.math.BigDecimal = 8.14 // java.math.BigDecimal | Clock initial time in minutes
val clockIncrement : kotlin.Int = 56 // kotlin.Int | Clock increment in seconds
val minutes : kotlin.Int = 56 // kotlin.Int | How long the tournament lasts, in minutes
val name : kotlin.String = name_example // kotlin.String | The tournament name. Leave empty to get a random Grandmaster name
val waitMinutes : kotlin.Int = 56 // kotlin.Int | How long to wait before starting the tournament, from now, in minutes
val startDate : kotlin.Int = 56 // kotlin.Int | Timestamp to start the tournament at a given date and time. Overrides the `waitMinutes` setting
val variant : VariantKey =  // VariantKey | 
val rated : kotlin.Boolean = true // kotlin.Boolean | Games are rated and impact players ratings
val position : kotlin.String = position_example // kotlin.String | Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960).
val berserkable : kotlin.Boolean = true // kotlin.Boolean | Whether the players can use berserk
val streakable : kotlin.Boolean = true // kotlin.Boolean | After 2 wins, consecutive wins grant 4 points instead of 2.
val hasChat : kotlin.Boolean = true // kotlin.Boolean | Whether the players can discuss in a chat
val description : kotlin.String = description_example // kotlin.String | Anything you want to tell players about the tournament
val password : kotlin.String = password_example // kotlin.String | Make the tournament private, and restrict access with a password
val conditionsMinRatingRating : kotlin.Int = 56 // kotlin.Int | Minimum rating to join. Leave empty to let everyone join the tournament.
val conditionsMaxRatingRating : kotlin.Int = 56 // kotlin.Int | Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament.
val conditionsNbRatedGameNb : kotlin.Int = 56 // kotlin.Int | Minimum number of rated games required to join.
try {
    val result : kotlin.Any = apiInstance.apiTournamentUpdate(id, clockTime, clockIncrement, minutes, name, waitMinutes, startDate, variant, rated, position, berserkable, streakable, hasChat, description, password, conditionsMinRatingRating, conditionsMaxRatingRating, conditionsNbRatedGameNb)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling ArenaTournamentsApi#apiTournamentUpdate")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling ArenaTournamentsApi#apiTournamentUpdate")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **kotlin.String**| The tournament ID. |
 **clockTime** | **java.math.BigDecimal**| Clock initial time in minutes | [enum: 0, 0.25, 0.5, 0.75, 1, 1.5, 2, 3, 4, 5, 6, 7, 10, 15, 20, 25, 30, 40, 50, 60]
 **clockIncrement** | **kotlin.Int**| Clock increment in seconds |
 **minutes** | **kotlin.Int**| How long the tournament lasts, in minutes |
 **name** | **kotlin.String**| The tournament name. Leave empty to get a random Grandmaster name | [optional]
 **waitMinutes** | **kotlin.Int**| How long to wait before starting the tournament, from now, in minutes | [optional] [default to 5]
 **startDate** | **kotlin.Int**| Timestamp to start the tournament at a given date and time. Overrides the &#x60;waitMinutes&#x60; setting | [optional]
 **variant** | [**VariantKey**](VariantKey.md)|  | [optional] [default to VariantKey.standard] [enum: standard, chess960, crazyhouse, antichess, atomic, horde, kingOfTheHill, racingKings, threeCheck]
 **rated** | **kotlin.Boolean**| Games are rated and impact players ratings | [optional] [default to true]
 **position** | **kotlin.String**| Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960). | [optional]
 **berserkable** | **kotlin.Boolean**| Whether the players can use berserk | [optional] [default to true]
 **streakable** | **kotlin.Boolean**| After 2 wins, consecutive wins grant 4 points instead of 2. | [optional] [default to true]
 **hasChat** | **kotlin.Boolean**| Whether the players can discuss in a chat | [optional] [default to true]
 **description** | **kotlin.String**| Anything you want to tell players about the tournament | [optional]
 **password** | **kotlin.String**| Make the tournament private, and restrict access with a password | [optional]
 **conditionsMinRatingRating** | **kotlin.Int**| Minimum rating to join. Leave empty to let everyone join the tournament. | [optional]
 **conditionsMaxRatingRating** | **kotlin.Int**| Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament. | [optional]
 **conditionsNbRatedGameNb** | **kotlin.Int**| Minimum number of rated games required to join. | [optional]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

<a name="apiTournamentWithdraw"></a>
# **apiTournamentWithdraw**
> Ok apiTournamentWithdraw(id)

Pause of leave an Arena tournament

Leave a future Arena tournament, or take a break on an ongoing Arena tournament. It&#39;s possible to join again later. Points and streaks are preserved. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = ArenaTournamentsApi()
val id : kotlin.String = hL7vMrFQ // kotlin.String | The tournament ID.
try {
    val result : Ok = apiInstance.apiTournamentWithdraw(id)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling ArenaTournamentsApi#apiTournamentWithdraw")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling ArenaTournamentsApi#apiTournamentWithdraw")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **kotlin.String**| The tournament ID. |

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="apiUserNameTournamentCreated"></a>
# **apiUserNameTournamentCreated**
> kotlin.Any apiUserNameTournamentCreated(username, status)

Get tournaments created by a user

Get all tournaments created by a given user.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = ArenaTournamentsApi()
val username : kotlin.String = username_example // kotlin.String | The user whose created tournaments to fetch
val status : kotlin.Int = 56 // kotlin.Int | Include tournaments in the given status: \"Created\" (10), \"Started\" (20), \"Finished\" (30)  You can add this parameter more than once to include tournaments in different statuses.   Example: `?status=10&status=20` 
try {
    val result : kotlin.Any = apiInstance.apiUserNameTournamentCreated(username, status)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling ArenaTournamentsApi#apiUserNameTournamentCreated")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling ArenaTournamentsApi#apiUserNameTournamentCreated")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **kotlin.String**| The user whose created tournaments to fetch |
 **status** | **kotlin.Int**| Include tournaments in the given status: \&quot;Created\&quot; (10), \&quot;Started\&quot; (20), \&quot;Finished\&quot; (30)  You can add this parameter more than once to include tournaments in different statuses.   Example: &#x60;?status&#x3D;10&amp;status&#x3D;20&#x60;  | [optional] [enum: 10, 20, 30]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

<a name="gamesByTournament"></a>
# **gamesByTournament**
> kotlin.Any gamesByTournament(id, player, moves, pgnInJson, tags, clocks, evals, opening)

Export games of an Arena tournament

Download games of a tournament in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (most recent first) 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = ArenaTournamentsApi()
val id : kotlin.String = id_example // kotlin.String | The tournament ID.
val player : kotlin.String = player_example // kotlin.String | Only games of a particular player. Leave empty to fetch games of all players.
val moves : kotlin.Boolean = true // kotlin.Boolean | Include the PGN moves.
val pgnInJson : kotlin.Boolean = true // kotlin.Boolean | Include the full PGN within the JSON response, in a `pgn` field.
val tags : kotlin.Boolean = true // kotlin.Boolean | Include the PGN tags.
val clocks : kotlin.Boolean = true // kotlin.Boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }` 
val evals : kotlin.Boolean = true // kotlin.Boolean | Include analysis evaluation comments in the PGN, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }` 
val opening : kotlin.Boolean = true // kotlin.Boolean | Include the opening name.  Example: `[Opening \"King's Gambit Accepted, King's Knight Gambit\"]` 
try {
    val result : kotlin.Any = apiInstance.gamesByTournament(id, player, moves, pgnInJson, tags, clocks, evals, opening)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling ArenaTournamentsApi#gamesByTournament")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling ArenaTournamentsApi#gamesByTournament")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **kotlin.String**| The tournament ID. |
 **player** | **kotlin.String**| Only games of a particular player. Leave empty to fetch games of all players. | [optional]
 **moves** | **kotlin.Boolean**| Include the PGN moves. | [optional] [default to true]
 **pgnInJson** | **kotlin.Boolean**| Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. | [optional] [default to false]
 **tags** | **kotlin.Boolean**| Include the PGN tags. | [optional] [default to true]
 **clocks** | **kotlin.Boolean**| Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | [optional] [default to false]
 **evals** | **kotlin.Boolean**| Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  | [optional] [default to false]
 **opening** | **kotlin.Boolean**| Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  | [optional] [default to false]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn, application/x-ndjson

<a name="resultsByTournament"></a>
# **resultsByTournament**
> kotlin.Any resultsByTournament(id, nb)

Get results of an Arena tournament

Players of an Arena tournament, with their score and performance, sorted by rank (best first).  **Players are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON)**, i.e. one JSON object per line.  If called on an ongoing tournament, results can be inconsistent due to ranking changes while the players are being streamed. Use on finished tournaments for guaranteed consistency. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = ArenaTournamentsApi()
val id : kotlin.String = id_example // kotlin.String | The tournament ID.
val nb : kotlin.Int = 56 // kotlin.Int | Max number of players to fetch
try {
    val result : kotlin.Any = apiInstance.resultsByTournament(id, nb)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling ArenaTournamentsApi#resultsByTournament")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling ArenaTournamentsApi#resultsByTournament")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **kotlin.String**| The tournament ID. |
 **nb** | **kotlin.Int**| Max number of players to fetch | [optional]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

<a name="teamsByTournament"></a>
# **teamsByTournament**
> kotlin.Any teamsByTournament(id)

Get team standing of a team battle

Teams of a team battle tournament, with top players, sorted by rank (best first). 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = ArenaTournamentsApi()
val id : kotlin.String = id_example // kotlin.String | The tournament ID.
try {
    val result : kotlin.Any = apiInstance.teamsByTournament(id)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling ArenaTournamentsApi#teamsByTournament")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling ArenaTournamentsApi#teamsByTournament")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **kotlin.String**| The tournament ID. |

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="tournament"></a>
# **tournament**
> kotlin.Any tournament(id, page)

Get info about an Arena tournament

Get detailed info about recently finished, current, or upcoming tournament&#39;s duels, player standings, and other info. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = ArenaTournamentsApi()
val id : kotlin.String = id_example // kotlin.String | The tournament ID.
val page : java.math.BigDecimal = 1 // java.math.BigDecimal | Specify which page of player standings to view.
try {
    val result : kotlin.Any = apiInstance.tournament(id, page)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling ArenaTournamentsApi#tournament")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling ArenaTournamentsApi#tournament")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **kotlin.String**| The tournament ID. |
 **page** | **java.math.BigDecimal**| Specify which page of player standings to view. | [optional] [default to 1]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

