# BoardApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiBoardSeek**](BoardApi.md#apiBoardSeek) | **POST** /api/board/seek | Create a seek
[**apiStreamEvent**](BoardApi.md#apiStreamEvent) | **GET** /api/stream/event | Stream incoming events
[**boardGameAbort**](BoardApi.md#boardGameAbort) | **POST** /api/board/game/{gameId}/abort | Abort a game
[**boardGameChatGet**](BoardApi.md#boardGameChatGet) | **GET** /api/board/game/{gameId}/chat | Fetch the game chat
[**boardGameChatPost**](BoardApi.md#boardGameChatPost) | **POST** /api/board/game/{gameId}/chat | Write in the chat
[**boardGameClaimVictory**](BoardApi.md#boardGameClaimVictory) | **POST** /api/board/game/{gameId}/claim-victory | Claim victory of a game
[**boardGameDraw**](BoardApi.md#boardGameDraw) | **POST** /api/board/game/{gameId}/draw/{accept} | Handle draw offers
[**boardGameMove**](BoardApi.md#boardGameMove) | **POST** /api/board/game/{gameId}/move/{move} | Make a Board move
[**boardGameResign**](BoardApi.md#boardGameResign) | **POST** /api/board/game/{gameId}/resign | Resign a game
[**boardGameStream**](BoardApi.md#boardGameStream) | **GET** /api/board/game/stream/{gameId} | Stream Board game state
[**boardGameTakeback**](BoardApi.md#boardGameTakeback) | **POST** /api/board/game/{gameId}/takeback/{accept} | Handle takeback offers


<a name="apiBoardSeek"></a>
# **apiBoardSeek**
> apiBoardSeek(rated, time, increment, days, variant, color, ratingRange)

Create a seek

   Create a public seek, to start a game with a random player.    ### Real-time seek    Specify the &#x60;time&#x60; and &#x60;increment&#x60; clock values.  The response is streamed but doesn&#39;t contain any information.    **Keep the connection open to keep the seek active**.    If the client closes the connection, the seek is canceled. This way, if the client terminates, the user won&#39;t be paired in a game they wouldn&#39;t play.   When the seek is accepted, or expires, the server closes the connection.    **Make sure to also have an [Event stream](#operation/apiStreamEvent) open**, to be notified when a game starts.   We recommend opening the [Event stream](#operation/apiStreamEvent) first, then the seek stream. This way,   you won&#39;t miss the game event if the seek is accepted immediately.    ### Correspondence seek    Specify the &#x60;days&#x60; per turn value.  The response is not streamed, it immediately completes with the seek ID. The seek remains active on the server until it is joined by someone.

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BoardApi()
val rated : kotlin.Boolean = true // kotlin.Boolean | Whether the game is rated and impacts players ratings.
val time : java.math.BigDecimal = 8.14 // java.math.BigDecimal | Clock initial time in minutes. Required for real-time seeks.
val increment : kotlin.Int = 56 // kotlin.Int | Clock increment in seconds. Required for real-time seeks.
val days : kotlin.Int = 56 // kotlin.Int | Days per turn. Required for correspondence seeks.
val variant : VariantKey =  // VariantKey | 
val color : kotlin.String = color_example // kotlin.String | The color to play. Better left empty to automatically get 50% white.
val ratingRange : kotlin.String = ratingRange_example // kotlin.String | The rating range of potential opponents. Better left empty. Example: 1500-1800 
try {
    apiInstance.apiBoardSeek(rated, time, increment, days, variant, color, ratingRange)
} catch (e: ClientException) {
    println("4xx response calling BoardApi#apiBoardSeek")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BoardApi#apiBoardSeek")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **rated** | **kotlin.Boolean**| Whether the game is rated and impacts players ratings. | [optional] [default to false]
 **time** | **java.math.BigDecimal**| Clock initial time in minutes. Required for real-time seeks. | [optional]
 **increment** | **kotlin.Int**| Clock increment in seconds. Required for real-time seeks. | [optional]
 **days** | **kotlin.Int**| Days per turn. Required for correspondence seeks. | [optional] [enum: 1, 3, 5, 7, 10, 14]
 **variant** | [**VariantKey**](VariantKey.md)|  | [optional] [default to VariantKey.standard] [enum: standard, chess960, crazyhouse, antichess, atomic, horde, kingOfTheHill, racingKings, threeCheck]
 **color** | **kotlin.String**| The color to play. Better left empty to automatically get 50% white. | [optional] [default to random] [enum: random, white, black]
 **ratingRange** | **kotlin.String**| The rating range of potential opponents. Better left empty. Example: 1500-1800  | [optional]

### Return type

null (empty response body)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: text/plain, application/json

<a name="apiStreamEvent"></a>
# **apiStreamEvent**
> ApiStreamEvent apiStreamEvent()

Stream incoming events

   Stream the events reaching a lichess user in real time as [ndjson](#section/Introduction/Streaming-with-ND-JSON).    Each line is a JSON object containing a &#x60;type&#x60; field. Possible values are:   - &#x60;gameStart&#x60; Start of a game   - &#x60;gameFinish&#x60; Completion of a game   - &#x60;challenge&#x60; A player sends you a challenge   - &#x60;challengeCanceled&#x60; A player cancels their challenge to you   - &#x60;challengeDeclined&#x60; The opponent declines your challenge     When the stream opens, all current challenges and games are sent.

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BoardApi()
try {
    val result : ApiStreamEvent = apiInstance.apiStreamEvent()
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BoardApi#apiStreamEvent")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BoardApi#apiStreamEvent")
    e.printStackTrace()
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**ApiStreamEvent**](ApiStreamEvent.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

<a name="boardGameAbort"></a>
# **boardGameAbort**
> Ok boardGameAbort(gameId)

Abort a game

Abort a game being played with the Board API. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BoardApi()
val gameId : kotlin.String = 5IrD6Gzz // kotlin.String | 
try {
    val result : Ok = apiInstance.boardGameAbort(gameId)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BoardApi#boardGameAbort")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BoardApi#boardGameAbort")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **kotlin.String**|  |

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="boardGameChatGet"></a>
# **boardGameChatGet**
> kotlin.Any boardGameChatGet(gameId)

Fetch the game chat

Get the messages posted in the game chat 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BoardApi()
val gameId : kotlin.String = 5IrD6Gzz // kotlin.String | 
try {
    val result : kotlin.Any = apiInstance.boardGameChatGet(gameId)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BoardApi#boardGameChatGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BoardApi#boardGameChatGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **kotlin.String**|  |

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

<a name="boardGameChatPost"></a>
# **boardGameChatPost**
> Ok boardGameChatPost(gameId, room, text)

Write in the chat

Post a message to the player or spectator chat, in a game being played with the Board API. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BoardApi()
val gameId : kotlin.String = 5IrD6Gzz // kotlin.String | 
val room : kotlin.String = room_example // kotlin.String | 
val text : kotlin.String = text_example // kotlin.String | 
try {
    val result : Ok = apiInstance.boardGameChatPost(gameId, room, text)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BoardApi#boardGameChatPost")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BoardApi#boardGameChatPost")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **kotlin.String**|  |
 **room** | **kotlin.String**|  | [enum: player, spectator]
 **text** | **kotlin.String**|  |

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

<a name="boardGameClaimVictory"></a>
# **boardGameClaimVictory**
> Ok boardGameClaimVictory(gameId)

Claim victory of a game

Claim victory when the opponent has left the game for a while. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BoardApi()
val gameId : kotlin.String = 5IrD6Gzz // kotlin.String | 
try {
    val result : Ok = apiInstance.boardGameClaimVictory(gameId)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BoardApi#boardGameClaimVictory")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BoardApi#boardGameClaimVictory")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **kotlin.String**|  |

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="boardGameDraw"></a>
# **boardGameDraw**
> Ok boardGameDraw(gameId, accept)

Handle draw offers

Create/accept/decline draw offers. - &#x60;yes&#x60;: Offer a draw, or accept the opponent&#39;s draw offer. - &#x60;no&#x60;: Decline a draw offer from the opponent. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BoardApi()
val gameId : kotlin.String = 5IrD6Gzz // kotlin.String | 
val accept : kotlin.Boolean = false // kotlin.Boolean | 
try {
    val result : Ok = apiInstance.boardGameDraw(gameId, accept)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BoardApi#boardGameDraw")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BoardApi#boardGameDraw")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **kotlin.String**|  |
 **accept** | **kotlin.Boolean**|  |

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="boardGameMove"></a>
# **boardGameMove**
> Ok boardGameMove(gameId, move, offeringDraw)

Make a Board move

Make a move in a game being played with the Board API.  The move can also contain a draw offer/agreement. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BoardApi()
val gameId : kotlin.String = 5IrD6Gzz // kotlin.String | 
val move : kotlin.String = e2e4 // kotlin.String | The move to play, in UCI format
val offeringDraw : kotlin.Boolean = true // kotlin.Boolean | Whether to offer (or agree to) a draw
try {
    val result : Ok = apiInstance.boardGameMove(gameId, move, offeringDraw)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BoardApi#boardGameMove")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BoardApi#boardGameMove")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **kotlin.String**|  |
 **move** | **kotlin.String**| The move to play, in UCI format |
 **offeringDraw** | **kotlin.Boolean**| Whether to offer (or agree to) a draw | [optional]

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="boardGameResign"></a>
# **boardGameResign**
> Ok boardGameResign(gameId)

Resign a game

Resign a game being played with the Board API. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BoardApi()
val gameId : kotlin.String = 5IrD6Gzz // kotlin.String | 
try {
    val result : Ok = apiInstance.boardGameResign(gameId)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BoardApi#boardGameResign")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BoardApi#boardGameResign")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **kotlin.String**|  |

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="boardGameStream"></a>
# **boardGameStream**
> GameStreamEvent boardGameStream(gameId)

Stream Board game state

 Stream the state of a game being played with the Board API, as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  Use this endpoint to get updates about the game in real-time, with a single request.  Each line is a JSON object containing a &#x60;type&#x60; field. Possible values are:   - &#x60;gameFull&#x60; Full game data. All values are immutable, except for the &#x60;state&#x60; field.   - &#x60;gameState&#x60; Current state of the game. Immutable values not included. Sent when a move is played, a draw is offered, or when the game ends.   - &#x60;chatLine&#x60; Chat message sent by a user in the &#x60;room&#x60; \&quot;player\&quot; or \&quot;spectator\&quot;.    The first line is always of type &#x60;gameFull&#x60;.

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BoardApi()
val gameId : kotlin.String = 5IrD6Gzz // kotlin.String | 
try {
    val result : GameStreamEvent = apiInstance.boardGameStream(gameId)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BoardApi#boardGameStream")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BoardApi#boardGameStream")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **kotlin.String**|  |

### Return type

[**GameStreamEvent**](GameStreamEvent.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson, application/json

<a name="boardGameTakeback"></a>
# **boardGameTakeback**
> Ok boardGameTakeback(gameId, accept)

Handle takeback offers

Create/accept/decline takebacks. - &#x60;yes&#x60;: Propose a takeback, or accept the opponent&#39;s takeback offer. - &#x60;no&#x60;: Decline a takeback offer from the opponent. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BoardApi()
val gameId : kotlin.String = 5IrD6Gzz // kotlin.String | 
val accept : kotlin.Boolean = false // kotlin.Boolean | 
try {
    val result : Ok = apiInstance.boardGameTakeback(gameId, accept)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BoardApi#boardGameTakeback")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BoardApi#boardGameTakeback")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **kotlin.String**|  |
 **accept** | **kotlin.Boolean**|  |

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

