# BotApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiBotOnline**](BotApi.md#apiBotOnline) | **GET** /api/bot/online | Get online bots
[**apiStreamEvent**](BotApi.md#apiStreamEvent) | **GET** /api/stream/event | Stream incoming events
[**botAccountUpgrade**](BotApi.md#botAccountUpgrade) | **POST** /api/bot/account/upgrade | Upgrade to Bot account
[**botGameAbort**](BotApi.md#botGameAbort) | **POST** /api/bot/game/{gameId}/abort | Abort a game
[**botGameChat**](BotApi.md#botGameChat) | **POST** /api/bot/game/{gameId}/chat | Write in the chat
[**botGameMove**](BotApi.md#botGameMove) | **POST** /api/bot/game/{gameId}/move/{move} | Make a Bot move
[**botGameResign**](BotApi.md#botGameResign) | **POST** /api/bot/game/{gameId}/resign | Resign a game
[**botGameStream**](BotApi.md#botGameStream) | **GET** /api/bot/game/stream/{gameId} | Stream Bot game state


<a name="apiBotOnline"></a>
# **apiBotOnline**
> User apiBotOnline(nb)

Get online bots

Stream the [online bot users](https://lichess.org/player/bots), as [ndjson](#section/Introduction/Streaming-with-ND-JSON). Throttled to 50 bot users per second.

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BotApi()
val nb : kotlin.Int = 20 // kotlin.Int | How many bot users to fetch
try {
    val result : User = apiInstance.apiBotOnline(nb)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BotApi#apiBotOnline")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BotApi#apiBotOnline")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nb** | **kotlin.Int**| How many bot users to fetch | [optional]

### Return type

[**User**](User.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

<a name="apiStreamEvent"></a>
# **apiStreamEvent**
> ApiStreamEvent apiStreamEvent()

Stream incoming events

   Stream the events reaching a lichess user in real time as [ndjson](#section/Introduction/Streaming-with-ND-JSON).    Each line is a JSON object containing a &#x60;type&#x60; field. Possible values are:   - &#x60;gameStart&#x60; Start of a game   - &#x60;gameFinish&#x60; Completion of a game   - &#x60;challenge&#x60; A player sends you a challenge   - &#x60;challengeCanceled&#x60; A player cancels their challenge to you   - &#x60;challengeDeclined&#x60; The opponent declines your challenge     When the stream opens, all current challenges and games are sent.

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BotApi()
try {
    val result : ApiStreamEvent = apiInstance.apiStreamEvent()
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BotApi#apiStreamEvent")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BotApi#apiStreamEvent")
    e.printStackTrace()
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**ApiStreamEvent**](ApiStreamEvent.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

<a name="botAccountUpgrade"></a>
# **botAccountUpgrade**
> Ok botAccountUpgrade()

Upgrade to Bot account

Upgrade a lichess player account into a Bot account. Only Bot accounts can use the Bot API.  The account **cannot have played any game** before becoming a Bot account. The upgrade is **irreversible**. The account will only be able to play as a Bot.  To upgrade an account to Bot, use the [official lichess-bot client](https://github.com/careless25/lichess-bot), or follow these steps: - Create an [API access token](https://lichess.org/account/oauth/token/create?scopes[]&#x3D;bot:play) with \&quot;Play bot moves\&quot; permission. - &#x60;curl -d &#39;&#39; https://lichess.org/api/bot/account/upgrade -H \&quot;Authorization: Bearer &lt;yourTokenHere&gt;\&quot;&#x60;  To know if an account has already been upgraded, use the [Get my profile API](#operation/accountMe): the &#x60;title&#x60; field should be set to &#x60;BOT&#x60;. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BotApi()
try {
    val result : Ok = apiInstance.botAccountUpgrade()
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BotApi#botAccountUpgrade")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BotApi#botAccountUpgrade")
    e.printStackTrace()
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="botGameAbort"></a>
# **botGameAbort**
> Ok botGameAbort(gameId)

Abort a game

Abort a game being played with the Bot API. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BotApi()
val gameId : kotlin.String = 5IrD6Gzz // kotlin.String | 
try {
    val result : Ok = apiInstance.botGameAbort(gameId)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BotApi#botGameAbort")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BotApi#botGameAbort")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **kotlin.String**|  |

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="botGameChat"></a>
# **botGameChat**
> Ok botGameChat(gameId, room, text)

Write in the chat

Post a message to the player or spectator chat, in a game being played with the Bot API. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BotApi()
val gameId : kotlin.String = 5IrD6Gzz // kotlin.String | 
val room : kotlin.String = room_example // kotlin.String | 
val text : kotlin.String = text_example // kotlin.String | 
try {
    val result : Ok = apiInstance.botGameChat(gameId, room, text)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BotApi#botGameChat")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BotApi#botGameChat")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **kotlin.String**|  |
 **room** | **kotlin.String**|  | [enum: player, spectator]
 **text** | **kotlin.String**|  |

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

<a name="botGameMove"></a>
# **botGameMove**
> Ok botGameMove(gameId, move, offeringDraw)

Make a Bot move

Make a move in a game being played with the Bot API.  The move can also contain a draw offer/agreement. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BotApi()
val gameId : kotlin.String = 5IrD6Gzz // kotlin.String | 
val move : kotlin.String = e2e4 // kotlin.String | The move to play, in UCI format
val offeringDraw : kotlin.Boolean = true // kotlin.Boolean | Whether to offer (or agree to) a draw
try {
    val result : Ok = apiInstance.botGameMove(gameId, move, offeringDraw)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BotApi#botGameMove")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BotApi#botGameMove")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **kotlin.String**|  |
 **move** | **kotlin.String**| The move to play, in UCI format |
 **offeringDraw** | **kotlin.Boolean**| Whether to offer (or agree to) a draw | [optional]

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="botGameResign"></a>
# **botGameResign**
> Ok botGameResign(gameId)

Resign a game

Resign a game being played with the Bot API. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BotApi()
val gameId : kotlin.String = 5IrD6Gzz // kotlin.String | 
try {
    val result : Ok = apiInstance.botGameResign(gameId)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BotApi#botGameResign")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BotApi#botGameResign")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **kotlin.String**|  |

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="botGameStream"></a>
# **botGameStream**
> GameStreamEvent botGameStream(gameId)

Stream Bot game state

 Stream the state of a game being played with the Bot API, as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  Use this endpoint to get updates about the game in real-time, with a single request.  Each line is a JSON object containing a &#x60;type&#x60; field. Possible values are:   - &#x60;gameFull&#x60; Full game data. All values are immutable, except for the &#x60;state&#x60; field.   - &#x60;gameState&#x60; Current state of the game. Immutable values not included.   - &#x60;chatLine&#x60; Chat message sent by a user (or the bot itself) in the &#x60;room&#x60; \&quot;player\&quot; or \&quot;spectator\&quot;.    The first line is always of type &#x60;gameFull&#x60;.

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BotApi()
val gameId : kotlin.String = 5IrD6Gzz // kotlin.String | 
try {
    val result : GameStreamEvent = apiInstance.botGameStream(gameId)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BotApi#botGameStream")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BotApi#botGameStream")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **kotlin.String**|  |

### Return type

[**GameStreamEvent**](GameStreamEvent.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson, application/json

