# BroadcastsApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**broadcastAllRoundsPgn**](BroadcastsApi.md#broadcastAllRoundsPgn) | **GET** /api/broadcast/{broadcastTournamentId}.pgn | Export all rounds as PGN
[**broadcastIndex**](BroadcastsApi.md#broadcastIndex) | **GET** /api/broadcast | Get official broadcasts
[**broadcastPush**](BroadcastsApi.md#broadcastPush) | **POST** /broadcast/round/{broadcastRoundId}/push | Push PGN to your broadcast round
[**broadcastRoundCreate**](BroadcastsApi.md#broadcastRoundCreate) | **POST** /broadcast/{broadcastTournamentId}/new | Create a broadcast round
[**broadcastRoundGet**](BroadcastsApi.md#broadcastRoundGet) | **GET** /broadcast/{broadcastTournamentSlug}/{broadcastRoundSlug}/{broadcastRoundId} | Get your broadcast round
[**broadcastRoundPgn**](BroadcastsApi.md#broadcastRoundPgn) | **GET** /api/broadcast/round/{broadcastRoundId}.pgn | Export one round as PGN
[**broadcastRoundUpdate**](BroadcastsApi.md#broadcastRoundUpdate) | **POST** /broadcast/round/{broadcastRoundId}/edit | Update your broadcast round
[**broadcastStreamRoundPgn**](BroadcastsApi.md#broadcastStreamRoundPgn) | **GET** /api/stream/broadcast/round/{broadcastRoundId}.pgn | Stream an ongoing broadcast tournament as PGN
[**broadcastTourCreate**](BroadcastsApi.md#broadcastTourCreate) | **POST** /broadcast/new | Create a broadcast tournament
[**broadcastTourGet**](BroadcastsApi.md#broadcastTourGet) | **GET** /broadcast/{slug}/{broadcastTournamentId} | Get your broadcast tournament
[**broadcastTourUpdate**](BroadcastsApi.md#broadcastTourUpdate) | **POST** /broadcast/{broadcastTournamentId}/edit | Update your broadcast tournament


<a name="broadcastAllRoundsPgn"></a>
# **broadcastAllRoundsPgn**
> kotlin.Any broadcastAllRoundsPgn(broadcastTournamentId)

Export all rounds as PGN

Download all games of all rounds of a broadcast in PGN format.  You may want to [download only the games of a single round](#operation/broadcastRoundPgn) instead. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BroadcastsApi()
val broadcastTournamentId : kotlin.String = broadcastTournamentId_example // kotlin.String | The broadcast tournament ID (8 characters).
try {
    val result : kotlin.Any = apiInstance.broadcastAllRoundsPgn(broadcastTournamentId)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BroadcastsApi#broadcastAllRoundsPgn")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BroadcastsApi#broadcastAllRoundsPgn")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **broadcastTournamentId** | **kotlin.String**| The broadcast tournament ID (8 characters). |

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn

<a name="broadcastIndex"></a>
# **broadcastIndex**
> kotlin.collections.List&lt;kotlin.Any&gt; broadcastIndex(nb)

Get official broadcasts

Get all incoming, ongoing, and finished official broadcasts. The broadcasts are sorted by start date, most recent first.  Broadcasts are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BroadcastsApi()
val nb : kotlin.Int = 56 // kotlin.Int | Max number of broadcasts to fetch
try {
    val result : kotlin.collections.List<kotlin.Any> = apiInstance.broadcastIndex(nb)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BroadcastsApi#broadcastIndex")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BroadcastsApi#broadcastIndex")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nb** | **kotlin.Int**| Max number of broadcasts to fetch | [optional] [default to 20]

### Return type

[**kotlin.collections.List&lt;kotlin.Any&gt;**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="broadcastPush"></a>
# **broadcastPush**
> kotlin.collections.List&lt;Ok&gt; broadcastPush(broadcastRoundId, body)

Push PGN to your broadcast round

Update your broadcast with new PGN. Only for broadcast without a source URL. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BroadcastsApi()
val broadcastRoundId : kotlin.String = broadcastRoundId_example // kotlin.String | The broadcast round ID (8 characters).
val body : kotlin.String = body_example // kotlin.String | The PGN. It can contain up to 64 games, separated by a double new line.
try {
    val result : kotlin.collections.List<Ok> = apiInstance.broadcastPush(broadcastRoundId, body)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BroadcastsApi#broadcastPush")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BroadcastsApi#broadcastPush")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **broadcastRoundId** | **kotlin.String**| The broadcast round ID (8 characters). |
 **body** | **kotlin.String**| The PGN. It can contain up to 64 games, separated by a double new line. |

### Return type

[**kotlin.collections.List&lt;Ok&gt;**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: text/plain
 - **Accept**: application/json

<a name="broadcastRoundCreate"></a>
# **broadcastRoundCreate**
> kotlin.Any broadcastRoundCreate(broadcastTournamentId, name, syncUrl, startsAt)

Create a broadcast round

Create a new broadcast round to relay external games. This endpoint accepts the same form data as the web form. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BroadcastsApi()
val broadcastTournamentId : kotlin.String = broadcastTournamentId_example // kotlin.String | The broadcast tournament ID (8 characters).
val name : kotlin.String = name_example // kotlin.String | Name of the broadcast round. Length must be between 3 and 80 characters.  Example: `Round 1` 
val syncUrl : kotlin.String = syncUrl_example // kotlin.String | URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: `https://myserver.org/myevent/round-10/games.pgn`  If the syncUrl is missing, then the broadcast needs to be fed by [pushing PGN to it](#operation/broadcastPush). 
val startsAt : kotlin.Int = 56 // kotlin.Int | Timestamp in milliseconds of broadcast round start. Leave empty to manually start the broadcast round.  Example: `1356998400070` 
try {
    val result : kotlin.Any = apiInstance.broadcastRoundCreate(broadcastTournamentId, name, syncUrl, startsAt)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BroadcastsApi#broadcastRoundCreate")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BroadcastsApi#broadcastRoundCreate")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **broadcastTournamentId** | **kotlin.String**| The broadcast tournament ID (8 characters). |
 **name** | **kotlin.String**| Name of the broadcast round. Length must be between 3 and 80 characters.  Example: &#x60;Round 1&#x60;  |
 **syncUrl** | **kotlin.String**| URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: &#x60;https://myserver.org/myevent/round-10/games.pgn&#x60;  If the syncUrl is missing, then the broadcast needs to be fed by [pushing PGN to it](#operation/broadcastPush).  | [optional]
 **startsAt** | **kotlin.Int**| Timestamp in milliseconds of broadcast round start. Leave empty to manually start the broadcast round.  Example: &#x60;1356998400070&#x60;  | [optional]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

<a name="broadcastRoundGet"></a>
# **broadcastRoundGet**
> kotlin.collections.List&lt;kotlin.Any&gt; broadcastRoundGet(broadcastTournamentSlug, broadcastRoundSlug, broadcastRoundId)

Get your broadcast round

Get information about a broadcast round that you created. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BroadcastsApi()
val broadcastTournamentSlug : kotlin.String = broadcastTournamentSlug_example // kotlin.String | The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by `-`. Only the `broadcastRoundId` is actually used.
val broadcastRoundSlug : kotlin.String = broadcastRoundSlug_example // kotlin.String | The broadcast round slug. Only used for SEO, the slug can be safely replaced by `-`. Only the `broadcastRoundId` is actually used.
val broadcastRoundId : kotlin.String = broadcastRoundId_example // kotlin.String | The broadcast Round ID (8 characters).
try {
    val result : kotlin.collections.List<kotlin.Any> = apiInstance.broadcastRoundGet(broadcastTournamentSlug, broadcastRoundSlug, broadcastRoundId)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BroadcastsApi#broadcastRoundGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BroadcastsApi#broadcastRoundGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **broadcastTournamentSlug** | **kotlin.String**| The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastRoundId&#x60; is actually used. |
 **broadcastRoundSlug** | **kotlin.String**| The broadcast round slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastRoundId&#x60; is actually used. |
 **broadcastRoundId** | **kotlin.String**| The broadcast Round ID (8 characters). |

### Return type

[**kotlin.collections.List&lt;kotlin.Any&gt;**](kotlin.Any.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="broadcastRoundPgn"></a>
# **broadcastRoundPgn**
> kotlin.Any broadcastRoundPgn(broadcastRoundId)

Export one round as PGN

Download all games of a single round of a broadcast tournament in PGN format.  You *could* poll this endpoint to get updates about a tournament, but it would be slow, and very inneficient.  Instead, consider [streaming the tournament](#operation/broadcastStreamRoundPgn) to get a new PGN every time a game is updated, in real-time. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BroadcastsApi()
val broadcastRoundId : kotlin.String = broadcastRoundId_example // kotlin.String | The round ID (8 characters).
try {
    val result : kotlin.Any = apiInstance.broadcastRoundPgn(broadcastRoundId)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BroadcastsApi#broadcastRoundPgn")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BroadcastsApi#broadcastRoundPgn")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **broadcastRoundId** | **kotlin.String**| The round ID (8 characters). |

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn

<a name="broadcastRoundUpdate"></a>
# **broadcastRoundUpdate**
> Ok broadcastRoundUpdate(broadcastRoundId, name, syncUrl, startsAt)

Update your broadcast round

Update information about a broadcast round that you created. This endpoint accepts the same form data as the web form. All fields must be populated with data. Missing fields will override the broadcast with empty data. For instance, if you omit &#x60;startDate&#x60;, then any pre-existing start date will be removed. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BroadcastsApi()
val broadcastRoundId : kotlin.String = broadcastRoundId_example // kotlin.String | The broadcast round ID (8 characters).
val name : kotlin.String = name_example // kotlin.String | Name of the broadcast round. Length must be between 3 and 80 characters.  Example: `Round 10` 
val syncUrl : kotlin.String = syncUrl_example // kotlin.String | URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: `https://myserver.org/myevent/round-10/games.pgn` 
val startsAt : kotlin.Int = 56 // kotlin.Int | Timestamp in milliseconds of broadcast start. Leave empty to manually start the broadcast.  Example: `1356998400070` 
try {
    val result : Ok = apiInstance.broadcastRoundUpdate(broadcastRoundId, name, syncUrl, startsAt)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BroadcastsApi#broadcastRoundUpdate")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BroadcastsApi#broadcastRoundUpdate")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **broadcastRoundId** | **kotlin.String**| The broadcast round ID (8 characters). |
 **name** | **kotlin.String**| Name of the broadcast round. Length must be between 3 and 80 characters.  Example: &#x60;Round 10&#x60;  |
 **syncUrl** | **kotlin.String**| URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: &#x60;https://myserver.org/myevent/round-10/games.pgn&#x60;  | [optional]
 **startsAt** | **kotlin.Int**| Timestamp in milliseconds of broadcast start. Leave empty to manually start the broadcast.  Example: &#x60;1356998400070&#x60;  | [optional]

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

<a name="broadcastStreamRoundPgn"></a>
# **broadcastStreamRoundPgn**
> kotlin.Any broadcastStreamRoundPgn(broadcastRoundId)

Stream an ongoing broadcast tournament as PGN

This streaming endpoint first sends all games of a broadcast tournament in PGN format.  Then, it waits for new moves to be played. As soon as it happens, the entire PGN of the game is sent to the stream.  The stream will also send PGNs when games are added to the tournament.  This is the best way to get updates about an ongoing tournament. Streaming means no polling, and no pollings means no latency, and minimum impact on the server. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BroadcastsApi()
val broadcastRoundId : kotlin.String = broadcastRoundId_example // kotlin.String | The broadcast round ID (8 characters).
try {
    val result : kotlin.Any = apiInstance.broadcastStreamRoundPgn(broadcastRoundId)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BroadcastsApi#broadcastStreamRoundPgn")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BroadcastsApi#broadcastStreamRoundPgn")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **broadcastRoundId** | **kotlin.String**| The broadcast round ID (8 characters). |

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn

<a name="broadcastTourCreate"></a>
# **broadcastTourCreate**
> kotlin.Any broadcastTourCreate(name, description, markup, official)

Create a broadcast tournament

Create a new broadcast tournament to relay external games. This endpoint accepts the same form data as the [web form](https://lichess.org/broadcast/new). 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BroadcastsApi()
val name : kotlin.String = name_example // kotlin.String | Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: `Sinquefield Cup` 
val description : kotlin.String = description_example // kotlin.String | Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: `An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.` 
val markup : kotlin.String = markup_example // kotlin.String | Optional long description of the broadcast. Markdown is supported. Length must be less than 20,000 characters.
val official : kotlin.Boolean = true // kotlin.Boolean | For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police.
try {
    val result : kotlin.Any = apiInstance.broadcastTourCreate(name, description, markup, official)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BroadcastsApi#broadcastTourCreate")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BroadcastsApi#broadcastTourCreate")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **name** | **kotlin.String**| Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: &#x60;Sinquefield Cup&#x60;  |
 **description** | **kotlin.String**| Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: &#x60;An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.&#x60;  |
 **markup** | **kotlin.String**| Optional long description of the broadcast. Markdown is supported. Length must be less than 20,000 characters. | [optional]
 **official** | **kotlin.Boolean**| For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police. | [optional]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

<a name="broadcastTourGet"></a>
# **broadcastTourGet**
> kotlin.collections.List&lt;kotlin.Any&gt; broadcastTourGet(slug, broadcastTournamentId)

Get your broadcast tournament

Get information about a broadcast tournament that you created. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BroadcastsApi()
val slug : kotlin.String = slug_example // kotlin.String | The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by `-`. Only the `broadcastTournamentId` is actually used.
val broadcastTournamentId : kotlin.String = broadcastTournamentId_example // kotlin.String | The broadcast tournament ID (8 characters).
try {
    val result : kotlin.collections.List<kotlin.Any> = apiInstance.broadcastTourGet(slug, broadcastTournamentId)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BroadcastsApi#broadcastTourGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BroadcastsApi#broadcastTourGet")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **slug** | **kotlin.String**| The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastTournamentId&#x60; is actually used. |
 **broadcastTournamentId** | **kotlin.String**| The broadcast tournament ID (8 characters). |

### Return type

[**kotlin.collections.List&lt;kotlin.Any&gt;**](kotlin.Any.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="broadcastTourUpdate"></a>
# **broadcastTourUpdate**
> Ok broadcastTourUpdate(broadcastTournamentId, name, description, markup, official)

Update your broadcast tournament

Update information about a broadcast tournament that you created. This endpoint accepts the same form data as the web form. All fields must be populated with data. Missing fields will override the broadcast with empty data. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BroadcastsApi()
val broadcastTournamentId : kotlin.String = broadcastTournamentId_example // kotlin.String | The broadcast ID (8 characters).
val name : kotlin.String = name_example // kotlin.String | Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: `Sinquefield Cup` 
val description : kotlin.String = description_example // kotlin.String | Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: `An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.` 
val markup : kotlin.String = markup_example // kotlin.String | Optional long description of the broadcast tournament. Markdown is supported. Length must be less than 20,000 characters.
val official : kotlin.Boolean = true // kotlin.Boolean | For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police.
try {
    val result : Ok = apiInstance.broadcastTourUpdate(broadcastTournamentId, name, description, markup, official)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BroadcastsApi#broadcastTourUpdate")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BroadcastsApi#broadcastTourUpdate")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **broadcastTournamentId** | **kotlin.String**| The broadcast ID (8 characters). |
 **name** | **kotlin.String**| Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: &#x60;Sinquefield Cup&#x60;  |
 **description** | **kotlin.String**| Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: &#x60;An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.&#x60;  |
 **markup** | **kotlin.String**| Optional long description of the broadcast tournament. Markdown is supported. Length must be less than 20,000 characters. | [optional]
 **official** | **kotlin.Boolean**| For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police. | [optional]

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

