# BulkPairingsApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**bulkPairingCreate**](BulkPairingsApi.md#bulkPairingCreate) | **POST** /api/bulk-pairing | Create a bulk pairing
[**bulkPairingDelete**](BulkPairingsApi.md#bulkPairingDelete) | **DELETE** /api/bulk-pairing/{id} | Cancel a bulk pairing
[**bulkPairingGet**](BulkPairingsApi.md#bulkPairingGet) | **GET** /api/bulk-pairing | View upcoming bulk pairings
[**bulkPairingStartClocks**](BulkPairingsApi.md#bulkPairingStartClocks) | **POST** /api/bulk-pairing/{id}/start-clocks | Manually start clocks


<a name="bulkPairingCreate"></a>
# **bulkPairingCreate**
> kotlin.Any bulkPairingCreate(players, clockLimit, clockIncrement, pairAt, startClocksAt, rated, variant, message)

Create a bulk pairing

Schedule many games at once, up to 24h in advance.  OAuth tokens are required for all paired players, with the &#x60;challenge:write&#x60; scope.  You can schedule up to 500 games every 10 minutes. [Contact us](mailto:contact@lichess.org) if you need higher limits.  The entire bulk is rejected if:   - a token is missing   - a token is present more than once   - a token lacks the &#x60;challenge:write&#x60; scope   - a player account is closed   - a player is paired more than once   - a bulk is already scheduled to start at the same time with the same player   - you have 10 scheduled bulks   - you have 1000 scheduled games  Partial bulks are never created. Either it all fails, or it all succeeds. When it fails, it does so with an error message explaining the issue. Failed bulks are not counted in the rate limiting, they are free. Fix the issues, manually or programmatically, then retry to schedule the bulk.  A successful bulk creation returns a JSON bulk document. Its ID can be used for further operations. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BulkPairingsApi()
val players : kotlin.String = players_example // kotlin.String | OAuth tokens of all the players to pair, with the syntax `tokenOfWhitePlayerInGame1:tokenOfBlackPlayerInGame1,tokenOfWhitePlayerInGame2:tokenOfBlackPlayerInGame2,...`.  The 2 tokens of the players of a game are separated with `:`. The first token gets the white pieces. Games are separated with `,`.  Up to 1000 tokens can be sent, for a max of 500 games.  Each token must be included at most once.  Example: `token1:token2,token3:token4,token5:token6` 
val clockLimit : java.math.BigDecimal = 8.14 // java.math.BigDecimal | Clock initial time in seconds. Example: `600` 
val clockIncrement : kotlin.Int = 56 // kotlin.Int | Clock increment in seconds. Example: `5` 
val pairAt : kotlin.Int = 56 // kotlin.Int | Date at which the games will be created. Up to 24h in the future. Omit, or set to current date and time, to start the games immediately. Example: `1612289869919` 
val startClocksAt : kotlin.Int = 56 // kotlin.Int | Date at which the clocks will be automatically started. Up to 24h in the future. Note that the clocks can start earlier than specified, if players start making moves in the game. If omitted, the clocks will not start automatically. Example: `1612289869919` 
val rated : kotlin.Boolean = true // kotlin.Boolean | Game is rated and impacts players ratings
val variant : VariantKey =  // VariantKey | 
val message : kotlin.String = message_example // kotlin.String | Message that will be sent to each player, when the game is created.  It is sent from your user account.  `{opponent}` and `{game}` are placeholders that will be replaced with the opponent and the game URLs.  You can omit this field to send the default message, but if you set your own message, it must at least contain the `{game}` placeholder. 
try {
    val result : kotlin.Any = apiInstance.bulkPairingCreate(players, clockLimit, clockIncrement, pairAt, startClocksAt, rated, variant, message)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BulkPairingsApi#bulkPairingCreate")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BulkPairingsApi#bulkPairingCreate")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **players** | **kotlin.String**| OAuth tokens of all the players to pair, with the syntax &#x60;tokenOfWhitePlayerInGame1:tokenOfBlackPlayerInGame1,tokenOfWhitePlayerInGame2:tokenOfBlackPlayerInGame2,...&#x60;.  The 2 tokens of the players of a game are separated with &#x60;:&#x60;. The first token gets the white pieces. Games are separated with &#x60;,&#x60;.  Up to 1000 tokens can be sent, for a max of 500 games.  Each token must be included at most once.  Example: &#x60;token1:token2,token3:token4,token5:token6&#x60;  | [optional]
 **clockLimit** | **java.math.BigDecimal**| Clock initial time in seconds. Example: &#x60;600&#x60;  | [optional]
 **clockIncrement** | **kotlin.Int**| Clock increment in seconds. Example: &#x60;5&#x60;  | [optional]
 **pairAt** | **kotlin.Int**| Date at which the games will be created. Up to 24h in the future. Omit, or set to current date and time, to start the games immediately. Example: &#x60;1612289869919&#x60;  | [optional]
 **startClocksAt** | **kotlin.Int**| Date at which the clocks will be automatically started. Up to 24h in the future. Note that the clocks can start earlier than specified, if players start making moves in the game. If omitted, the clocks will not start automatically. Example: &#x60;1612289869919&#x60;  | [optional]
 **rated** | **kotlin.Boolean**| Game is rated and impacts players ratings | [optional]
 **variant** | [**VariantKey**](VariantKey.md)|  | [optional] [default to VariantKey.standard] [enum: standard, chess960, crazyhouse, antichess, atomic, horde, kingOfTheHill, racingKings, threeCheck]
 **message** | **kotlin.String**| Message that will be sent to each player, when the game is created.  It is sent from your user account.  &#x60;{opponent}&#x60; and &#x60;{game}&#x60; are placeholders that will be replaced with the opponent and the game URLs.  You can omit this field to send the default message, but if you set your own message, it must at least contain the &#x60;{game}&#x60; placeholder.  | [optional] [default to &quot;Your game with {opponent} is ready: {game}.&quot;]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

<a name="bulkPairingDelete"></a>
# **bulkPairingDelete**
> Ok bulkPairingDelete(id)

Cancel a bulk pairing

Cancel and delete a bulk pairing that is scheduled in the future.  If the games have already been created, then this does nothing.  Canceling a bulk pairing does not refund the rate limit cost of that bulk pairing. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BulkPairingsApi()
val id : kotlin.String = 5IrD6Gzz // kotlin.String | 
try {
    val result : Ok = apiInstance.bulkPairingDelete(id)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BulkPairingsApi#bulkPairingDelete")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BulkPairingsApi#bulkPairingDelete")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **kotlin.String**|  |

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="bulkPairingGet"></a>
# **bulkPairingGet**
> kotlin.collections.List&lt;kotlin.Any&gt; bulkPairingGet()

View upcoming bulk pairings

Get a list of upcoming bulk pairings you created.  Only bulk pairings that are scheduled in the future, or that have a clock start scheduled in the future, are listed.  Bulk pairings are deleted from the server after the pairings are done and the clocks have started. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BulkPairingsApi()
try {
    val result : kotlin.collections.List<kotlin.Any> = apiInstance.bulkPairingGet()
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BulkPairingsApi#bulkPairingGet")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BulkPairingsApi#bulkPairingGet")
    e.printStackTrace()
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**kotlin.collections.List&lt;kotlin.Any&gt;**](kotlin.Any.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="bulkPairingStartClocks"></a>
# **bulkPairingStartClocks**
> Ok bulkPairingStartClocks(id)

Manually start clocks

Immediately start all clocks of the games of a bulk pairing.  This overrides the &#x60;startClocksAt&#x60; value of an existing bulk pairing.  If the games have not yet been created (&#x60;bulk.pairAt&#x60; is in the future), then this does nothing.  If the clocks have already started (&#x60;bulk.startClocksAt&#x60; is in the past), then this does nothing. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = BulkPairingsApi()
val id : kotlin.String = 5IrD6Gzz // kotlin.String | 
try {
    val result : Ok = apiInstance.bulkPairingStartClocks(id)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling BulkPairingsApi#bulkPairingStartClocks")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling BulkPairingsApi#bulkPairingStartClocks")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **kotlin.String**|  |

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

