# ChallengesApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**adminChallengeTokens**](ChallengesApi.md#adminChallengeTokens) | **POST** /api/token/admin-challenge | Admin challenge tokens
[**challengeAccept**](ChallengesApi.md#challengeAccept) | **POST** /api/challenge/{challengeId}/accept | Accept a challenge
[**challengeAi**](ChallengesApi.md#challengeAi) | **POST** /api/challenge/ai | Challenge the AI
[**challengeCancel**](ChallengesApi.md#challengeCancel) | **POST** /api/challenge/{challengeId}/cancel | Cancel a challenge
[**challengeCreate**](ChallengesApi.md#challengeCreate) | **POST** /api/challenge/{username} | Create a challenge
[**challengeDecline**](ChallengesApi.md#challengeDecline) | **POST** /api/challenge/{challengeId}/decline | Decline a challenge
[**challengeList**](ChallengesApi.md#challengeList) | **GET** /api/challenge | List your challenges
[**challengeOpen**](ChallengesApi.md#challengeOpen) | **POST** /api/challenge/open | Open-ended challenge
[**challengeStartClocks**](ChallengesApi.md#challengeStartClocks) | **POST** /api/challenge/{gameId}/start-clocks | Start clocks of a game
[**roundAddTime**](ChallengesApi.md#roundAddTime) | **POST** /api/round/{gameId}/add-time/{seconds} | Add time to the opponent clock


<a name="adminChallengeTokens"></a>
# **adminChallengeTokens**
> adminChallengeTokens(users, description)

Admin challenge tokens

**For administrators only. You are not allowed to use this endpoint.**  Create and obtain &#x60;challenge:write&#x60; tokens for multiple users.  If a similar token already exists for a user, it is reused. This endpoint is idempotent. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = ChallengesApi()
val users : kotlin.String = users_example // kotlin.String | Usernames separated with commas
val description : kotlin.String = description_example // kotlin.String | User visible description of the token
try {
    apiInstance.adminChallengeTokens(users, description)
} catch (e: ClientException) {
    println("4xx response calling ChallengesApi#adminChallengeTokens")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling ChallengesApi#adminChallengeTokens")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **users** | **kotlin.String**| Usernames separated with commas |
 **description** | **kotlin.String**| User visible description of the token |

### Return type

null (empty response body)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

<a name="challengeAccept"></a>
# **challengeAccept**
> Ok challengeAccept(challengeId)

Accept a challenge

Accept an incoming challenge.  You should receive a &#x60;gameStart&#x60; event on the [incoming events stream](#operation/apiStreamEvent). 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = ChallengesApi()
val challengeId : kotlin.String = 5IrD6Gzz // kotlin.String | 
try {
    val result : Ok = apiInstance.challengeAccept(challengeId)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling ChallengesApi#challengeAccept")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling ChallengesApi#challengeAccept")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **challengeId** | **kotlin.String**|  |

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="challengeAi"></a>
# **challengeAi**
> GameJson challengeAi(level, clockLimit, clockIncrement, days, color, variant, fen)

Challenge the AI

Start a game with Lichess AI.  You will be notified on the [event stream](#operation/apiStreamEvent) that a new game has started. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = ChallengesApi()
val level : java.math.BigDecimal = 8.14 // java.math.BigDecimal | AI strength
val clockLimit : java.math.BigDecimal = 8.14 // java.math.BigDecimal | Clock initial time in seconds. If empty, a correspondence game is created.
val clockIncrement : kotlin.Int = 56 // kotlin.Int | Clock increment in seconds. If empty, a correspondence game is created.
val days : kotlin.Int = 56 // kotlin.Int | Days per move, for correspondence games. Clock settings must be omitted.
val color : kotlin.String = color_example // kotlin.String | Which color you get to play
val variant : VariantKey =  // VariantKey | 
val fen : kotlin.String = fen_example // kotlin.String | Custom initial position (in FEN). Variant must be standard, and the game cannot be rated.
try {
    val result : GameJson = apiInstance.challengeAi(level, clockLimit, clockIncrement, days, color, variant, fen)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling ChallengesApi#challengeAi")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling ChallengesApi#challengeAi")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **level** | **java.math.BigDecimal**| AI strength | [optional]
 **clockLimit** | **java.math.BigDecimal**| Clock initial time in seconds. If empty, a correspondence game is created. | [optional]
 **clockIncrement** | **kotlin.Int**| Clock increment in seconds. If empty, a correspondence game is created. | [optional]
 **days** | **kotlin.Int**| Days per move, for correspondence games. Clock settings must be omitted. | [optional]
 **color** | **kotlin.String**| Which color you get to play | [optional] [default to Color.random] [enum: random, white, black]
 **variant** | [**VariantKey**](VariantKey.md)|  | [optional] [default to VariantKey.standard] [enum: standard, chess960, crazyhouse, antichess, atomic, horde, kingOfTheHill, racingKings, threeCheck]
 **fen** | **kotlin.String**| Custom initial position (in FEN). Variant must be standard, and the game cannot be rated. | [optional] [default to &quot;rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1&quot;]

### Return type

[**GameJson**](GameJson.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

<a name="challengeCancel"></a>
# **challengeCancel**
> Ok challengeCancel(challengeId, opponentToken)

Cancel a challenge

Cancel a challenge you sent, or aborts the game if the challenge was accepted, but the game was not yet played. Note that the ID of a game is the same as the ID of the challenge that created it. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = ChallengesApi()
val challengeId : kotlin.String = 5IrD6Gzz // kotlin.String | 
val opponentToken : kotlin.String = opponentToken_example // kotlin.String | Optional `challenge:write` token of the opponent. If set, the game can be canceled even if both players have moved.
try {
    val result : Ok = apiInstance.challengeCancel(challengeId, opponentToken)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling ChallengesApi#challengeCancel")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling ChallengesApi#challengeCancel")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **challengeId** | **kotlin.String**|  |
 **opponentToken** | **kotlin.String**| Optional &#x60;challenge:write&#x60; token of the opponent. If set, the game can be canceled even if both players have moved. | [optional]

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="challengeCreate"></a>
# **challengeCreate**
> ChallengeJson challengeCreate(username, rated, clockLimit, clockIncrement, days, color, variant, fen, keepAliveStream, acceptByToken, message)

Create a challenge

Challenge someone to play. The targeted player can choose to accept or decline.  If the challenge is accepted, you will be notified on the [event stream](#operation/apiStreamEvent) that a new game has started. The game ID will be the same as the challenge ID.  If you also have an OAuth token with &#x60;challenge:write&#x60; scope for the receiving user, you can make them accept the challenge immediately by setting the &#x60;acceptByToken&#x60; field.  Challenges for realtime games (not correspondence) expire after 20s if not accepted. To prevent that, use the &#x60;keepAliveStream&#x60; flag described below. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = ChallengesApi()
val username : kotlin.String = LeelaChess // kotlin.String | 
val rated : kotlin.Boolean = true // kotlin.Boolean | Game is rated and impacts players ratings
val clockLimit : java.math.BigDecimal = 8.14 // java.math.BigDecimal | Clock initial time in seconds. If empty, a correspondence game is created.
val clockIncrement : kotlin.Int = 56 // kotlin.Int | Clock increment in seconds. If empty, a correspondence game is created.
val days : kotlin.Int = 56 // kotlin.Int | Days per move, for correspondence games. Clock settings must be omitted.
val color : kotlin.String = color_example // kotlin.String | Which color you get to play
val variant : VariantKey =  // VariantKey | 
val fen : kotlin.String = fen_example // kotlin.String | Custom initial position (in FEN). Variant must be standard, and the game cannot be rated. Castling moves will use UCI_Chess960 notation, for example e1h1 instead of e1g1.
val keepAliveStream : kotlin.Boolean = true // kotlin.Boolean | If set, the response is streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). The challenge is kept alive until the connection is closed by the client. When the challenge is accepted, declined or canceled, a message of the form `{\\\"done\\\":\\\"accepted\\\"}` is sent, then the connection is closed by the server. If not set, the response is not streamed, and the challenge expires after 20s if not accepted. 
val acceptByToken : kotlin.String = acceptByToken_example // kotlin.String | Immediately accept the challenge and create the game. Pass in an OAuth token (with the `challenge:write` scope) for the receiving user. On success, the response will contain a `game` field instead of a `challenge` field.  Alternatively, consider the [bulk pairing API](#operation/bulkPairingCreate). 
val message : kotlin.String = message_example // kotlin.String | **Only if `acceptByToken` is set.**  Message that is sent to each player, when the game is created. It is sent from your user account.  `{opponent}`, `{player}` and `{game}` are placeholders that will be replaced with the opponent name, player name, and the game URLs.  You can omit this field to send the default message, but if you set your own message, it must at least contain the `{game}` placeholder. 
try {
    val result : ChallengeJson = apiInstance.challengeCreate(username, rated, clockLimit, clockIncrement, days, color, variant, fen, keepAliveStream, acceptByToken, message)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling ChallengesApi#challengeCreate")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling ChallengesApi#challengeCreate")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **kotlin.String**|  |
 **rated** | **kotlin.Boolean**| Game is rated and impacts players ratings | [optional]
 **clockLimit** | **java.math.BigDecimal**| Clock initial time in seconds. If empty, a correspondence game is created. | [optional]
 **clockIncrement** | **kotlin.Int**| Clock increment in seconds. If empty, a correspondence game is created. | [optional]
 **days** | **kotlin.Int**| Days per move, for correspondence games. Clock settings must be omitted. | [optional]
 **color** | **kotlin.String**| Which color you get to play | [optional] [default to random] [enum: random, white, black]
 **variant** | [**VariantKey**](VariantKey.md)|  | [optional] [default to VariantKey.standard] [enum: standard, chess960, crazyhouse, antichess, atomic, horde, kingOfTheHill, racingKings, threeCheck]
 **fen** | **kotlin.String**| Custom initial position (in FEN). Variant must be standard, and the game cannot be rated. Castling moves will use UCI_Chess960 notation, for example e1h1 instead of e1g1. | [optional] [default to &quot;rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1&quot;]
 **keepAliveStream** | **kotlin.Boolean**| If set, the response is streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). The challenge is kept alive until the connection is closed by the client. When the challenge is accepted, declined or canceled, a message of the form &#x60;{\\\&quot;done\\\&quot;:\\\&quot;accepted\\\&quot;}&#x60; is sent, then the connection is closed by the server. If not set, the response is not streamed, and the challenge expires after 20s if not accepted.  | [optional]
 **acceptByToken** | **kotlin.String**| Immediately accept the challenge and create the game. Pass in an OAuth token (with the &#x60;challenge:write&#x60; scope) for the receiving user. On success, the response will contain a &#x60;game&#x60; field instead of a &#x60;challenge&#x60; field.  Alternatively, consider the [bulk pairing API](#operation/bulkPairingCreate).  | [optional]
 **message** | **kotlin.String**| **Only if &#x60;acceptByToken&#x60; is set.**  Message that is sent to each player, when the game is created. It is sent from your user account.  &#x60;{opponent}&#x60;, &#x60;{player}&#x60; and &#x60;{game}&#x60; are placeholders that will be replaced with the opponent name, player name, and the game URLs.  You can omit this field to send the default message, but if you set your own message, it must at least contain the &#x60;{game}&#x60; placeholder.  | [optional] [default to &quot;Your game with {opponent} is ready: {game}.&quot;]

### Return type

[**ChallengeJson**](ChallengeJson.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

<a name="challengeDecline"></a>
# **challengeDecline**
> Ok challengeDecline(challengeId, reason)

Decline a challenge

Decline an incoming challenge. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = ChallengesApi()
val challengeId : kotlin.String = 5IrD6Gzz // kotlin.String | 
val reason : kotlin.String = reason_example // kotlin.String | Reason challenge was declined. It will be translated to the player's language. See [the full list in the translation file](https://github.com/ornicar/lila/blob/43fbd61029ff3960a21fbd213944bed66325696d/translation/source/challenge.xml#L14).
try {
    val result : Ok = apiInstance.challengeDecline(challengeId, reason)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling ChallengesApi#challengeDecline")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling ChallengesApi#challengeDecline")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **challengeId** | **kotlin.String**|  |
 **reason** | **kotlin.String**| Reason challenge was declined. It will be translated to the player&#39;s language. See [the full list in the translation file](https://github.com/ornicar/lila/blob/43fbd61029ff3960a21fbd213944bed66325696d/translation/source/challenge.xml#L14). | [optional] [enum: generic, later, tooFast, tooSlow, timeControl, rated, casual, standard, variant, noBot, onlyBot]

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

<a name="challengeList"></a>
# **challengeList**
> InlineResponse2003 challengeList()

List your challenges

Get a list of challenges created by or targeted at you. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = ChallengesApi()
try {
    val result : InlineResponse2003 = apiInstance.challengeList()
    println(result)
} catch (e: ClientException) {
    println("4xx response calling ChallengesApi#challengeList")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling ChallengesApi#challengeList")
    e.printStackTrace()
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**InlineResponse2003**](InlineResponse2003.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="challengeOpen"></a>
# **challengeOpen**
> kotlin.Any challengeOpen(rated, clockLimit, clockIncrement, variant, fen, name)

Open-ended challenge

Create a challenge that any 2 players can join.  Share the URL of the challenge. the first 2 players to click it will be paired for a game.  The response body also contains &#x60;whiteUrl&#x60; and &#x60;blackUrl&#x60;. You can control which color each player gets by giving them these URLs, instead of the main challenge URL.  Open challenges expire after 24h.  To directly pair 2 known players, use [this endpoint](#operation/challengeCreate) instead, with the &#x60;acceptByToken&#x60; parameter. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = ChallengesApi()
val rated : kotlin.Boolean = true // kotlin.Boolean | Game is rated and impacts players ratings
val clockLimit : java.math.BigDecimal = 8.14 // java.math.BigDecimal | Clock initial time in seconds. If empty, a correspondence game is created.
val clockIncrement : kotlin.Int = 56 // kotlin.Int | Clock increment in seconds. If empty, a correspondence game is created.
val variant : VariantKey =  // VariantKey | 
val fen : kotlin.String = fen_example // kotlin.String | Custom initial position (in FEN). Variant must be standard, and the game cannot be rated.
val name : kotlin.String = name_example // kotlin.String | Optional name for the challenge, that players will see on the challenge page.
try {
    val result : kotlin.Any = apiInstance.challengeOpen(rated, clockLimit, clockIncrement, variant, fen, name)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling ChallengesApi#challengeOpen")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling ChallengesApi#challengeOpen")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **rated** | **kotlin.Boolean**| Game is rated and impacts players ratings | [optional]
 **clockLimit** | **java.math.BigDecimal**| Clock initial time in seconds. If empty, a correspondence game is created. | [optional]
 **clockIncrement** | **kotlin.Int**| Clock increment in seconds. If empty, a correspondence game is created. | [optional]
 **variant** | [**VariantKey**](VariantKey.md)|  | [optional] [default to VariantKey.standard] [enum: standard, chess960, crazyhouse, antichess, atomic, horde, kingOfTheHill, racingKings, threeCheck]
 **fen** | **kotlin.String**| Custom initial position (in FEN). Variant must be standard, and the game cannot be rated. | [optional] [default to &quot;rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1&quot;]
 **name** | **kotlin.String**| Optional name for the challenge, that players will see on the challenge page. | [optional]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

<a name="challengeStartClocks"></a>
# **challengeStartClocks**
> Ok challengeStartClocks(gameId, token1, token2)

Start clocks of a game

Start the clocks of a game immediately, even if a player has not yet made a move.  Requires the OAuth tokens of both players with &#x60;challenge:write&#x60; scope.  If the clocks have already started, the call will have no effect. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = ChallengesApi()
val gameId : kotlin.String = gameId_example // kotlin.String | 
val token1 : kotlin.String = token1_example // kotlin.String | OAuth token of a player
val token2 : kotlin.String = token2_example // kotlin.String | OAuth token of the other player
try {
    val result : Ok = apiInstance.challengeStartClocks(gameId, token1, token2)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling ChallengesApi#challengeStartClocks")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling ChallengesApi#challengeStartClocks")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **kotlin.String**|  |
 **token1** | **kotlin.String**| OAuth token of a player | [optional]
 **token2** | **kotlin.String**| OAuth token of the other player | [optional]

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="roundAddTime"></a>
# **roundAddTime**
> Ok roundAddTime(gameId, seconds)

Add time to the opponent clock

Add seconds to the opponent&#39;s clock. Can be used to create games with time odds. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = ChallengesApi()
val gameId : kotlin.String = gameId_example // kotlin.String | 
val seconds : kotlin.String = seconds_example // kotlin.String | How many seconds to give
try {
    val result : Ok = apiInstance.roundAddTime(gameId, seconds)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling ChallengesApi#roundAddTime")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling ChallengesApi#roundAddTime")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **kotlin.String**|  |
 **seconds** | **kotlin.String**| How many seconds to give |

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

