# GamesApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiAccountPlaying**](GamesApi.md#apiAccountPlaying) | **GET** /api/account/playing | Get my ongoing games
[**apiGamesUser**](GamesApi.md#apiGamesUser) | **GET** /api/games/user/{username} | Export games of a user
[**apiUserCurrentGame**](GamesApi.md#apiUserCurrentGame) | **GET** /api/user/{username}/current-game | Export ongoing game of a user
[**gameImport**](GamesApi.md#gameImport) | **POST** /api/import | Import one game
[**gamePgn**](GamesApi.md#gamePgn) | **GET** /game/export/{gameId} | Export one game
[**gamesByUsers**](GamesApi.md#gamesByUsers) | **POST** /api/stream/games-by-users | Stream games of users
[**gamesExportIds**](GamesApi.md#gamesExportIds) | **POST** /games/export/_ids | Export games by IDs
[**streamGame**](GamesApi.md#streamGame) | **GET** /api/stream/game/{id} | Stream moves of a game


<a name="apiAccountPlaying"></a>
# **apiAccountPlaying**
> kotlin.Any apiAccountPlaying(nb)

Get my ongoing games

Get the ongoing games of the current user. Real-time and correspondence games are included. The most urgent games are listed first. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = GamesApi()
val nb : kotlin.Int = 56 // kotlin.Int | Max number of games to fetch
try {
    val result : kotlin.Any = apiInstance.apiAccountPlaying(nb)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling GamesApi#apiAccountPlaying")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling GamesApi#apiAccountPlaying")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nb** | **kotlin.Int**| Max number of games to fetch | [optional] [default to 9]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="apiGamesUser"></a>
# **apiGamesUser**
> kotlin.Any apiGamesUser(username, since, until, max, vs, rated, perfType, color, analysed, moves, pgnInJson, tags, clocks, evals, opening, ongoing, finished, players, sort)

Export games of a user

Download all games of any user in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (most recent first)  We recommend streaming the response, for it can be very long. &lt;https://lichess.org/@/german11&gt; for instance has more than 320,000 games.  The game stream is throttled, depending on who is making the request:   - Anonymous request: 20 games per second   - [OAuth2 authenticated](#section/Authentication) request: 30 games per second   - Authenticated, downloading your own games: 60 games per second 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = GamesApi()
val username : kotlin.String = username_example // kotlin.String | The user name.
val since : kotlin.Int = 56 // kotlin.Int | Download games played since this timestamp.
val until : kotlin.Int = 56 // kotlin.Int | Download games played until this timestamp.
val max : kotlin.Int = 56 // kotlin.Int | How many games to download. Leave empty to download all games.
val vs : kotlin.String = vs_example // kotlin.String | [Filter] Only games played against this opponent
val rated : kotlin.Boolean = true // kotlin.Boolean | [Filter] Only rated (`true`) or casual (`false`) games
val perfType : PerfType =  // PerfType | [Filter] Only games in these speeds or variants.   Multiple perf types can be specified, separated by a comma.   Example: blitz,rapid,classical
val color : kotlin.String = color_example // kotlin.String | [Filter] Only games played as this color.
val analysed : kotlin.Boolean = true // kotlin.Boolean | [Filter] Only games with or without a computer analysis available
val moves : kotlin.Boolean = true // kotlin.Boolean | Include the PGN moves.
val pgnInJson : kotlin.Boolean = true // kotlin.Boolean | Include the full PGN within the JSON response, in a `pgn` field. The response type must be set to `application/x-ndjson` by the request `Accept` header.
val tags : kotlin.Boolean = true // kotlin.Boolean | Include the PGN tags.
val clocks : kotlin.Boolean = true // kotlin.Boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }` 
val evals : kotlin.Boolean = true // kotlin.Boolean | Include analysis evaluation comments in the PGN, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }` 
val opening : kotlin.Boolean = true // kotlin.Boolean | Include the opening name.  Example: `[Opening \"King's Gambit Accepted, King's Knight Gambit\"]` 
val ongoing : kotlin.Boolean = true // kotlin.Boolean | Include ongoing games. The last 3 moves will be omitted.
val finished : kotlin.Boolean = true // kotlin.Boolean | Include finished games. Set to `false` to only get ongoing games.
val players : kotlin.String = players_example // kotlin.String | URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: <https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt> 
val sort : kotlin.String = sort_example // kotlin.String | Sort order of the games.
try {
    val result : kotlin.Any = apiInstance.apiGamesUser(username, since, until, max, vs, rated, perfType, color, analysed, moves, pgnInJson, tags, clocks, evals, opening, ongoing, finished, players, sort)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling GamesApi#apiGamesUser")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling GamesApi#apiGamesUser")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **kotlin.String**| The user name. |
 **since** | **kotlin.Int**| Download games played since this timestamp. | [optional]
 **until** | **kotlin.Int**| Download games played until this timestamp. | [optional]
 **max** | **kotlin.Int**| How many games to download. Leave empty to download all games. | [optional]
 **vs** | **kotlin.String**| [Filter] Only games played against this opponent | [optional]
 **rated** | **kotlin.Boolean**| [Filter] Only rated (&#x60;true&#x60;) or casual (&#x60;false&#x60;) games | [optional]
 **perfType** | [**PerfType**](.md)| [Filter] Only games in these speeds or variants.   Multiple perf types can be specified, separated by a comma.   Example: blitz,rapid,classical | [optional]
 **color** | **kotlin.String**| [Filter] Only games played as this color. | [optional] [default to null] [enum: white, black]
 **analysed** | **kotlin.Boolean**| [Filter] Only games with or without a computer analysis available | [optional]
 **moves** | **kotlin.Boolean**| Include the PGN moves. | [optional] [default to true]
 **pgnInJson** | **kotlin.Boolean**| Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. The response type must be set to &#x60;application/x-ndjson&#x60; by the request &#x60;Accept&#x60; header. | [optional] [default to false]
 **tags** | **kotlin.Boolean**| Include the PGN tags. | [optional] [default to true]
 **clocks** | **kotlin.Boolean**| Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | [optional] [default to false]
 **evals** | **kotlin.Boolean**| Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  | [optional] [default to false]
 **opening** | **kotlin.Boolean**| Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  | [optional] [default to false]
 **ongoing** | **kotlin.Boolean**| Include ongoing games. The last 3 moves will be omitted. | [optional] [default to false]
 **finished** | **kotlin.Boolean**| Include finished games. Set to &#x60;false&#x60; to only get ongoing games. | [optional] [default to true]
 **players** | **kotlin.String**| URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt;  | [optional]
 **sort** | **kotlin.String**| Sort order of the games. | [optional] [default to dateDesc] [enum: dateAsc, dateDesc]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn, application/x-ndjson

<a name="apiUserCurrentGame"></a>
# **apiUserCurrentGame**
> kotlin.Any apiUserCurrentGame(username, moves, pgnInJson, tags, clocks, evals, opening, literate, players)

Export ongoing game of a user

Download the ongoing game, or the last game played, of a user. Available in either PGN or JSON format. If the game is ongoing, the 3 last moves are omitted. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = GamesApi()
val username : kotlin.String = username_example // kotlin.String | 
val moves : kotlin.Boolean = true // kotlin.Boolean | Include the PGN moves.
val pgnInJson : kotlin.Boolean = true // kotlin.Boolean | Include the full PGN within the JSON response, in a `pgn` field.
val tags : kotlin.Boolean = true // kotlin.Boolean | Include the PGN tags.
val clocks : kotlin.Boolean = true // kotlin.Boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }` 
val evals : kotlin.Boolean = true // kotlin.Boolean | Include analysis evaluation comments in the PGN, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }` 
val opening : kotlin.Boolean = true // kotlin.Boolean | Include the opening name.  Example: `[Opening \"King's Gambit Accepted, King's Knight Gambit\"]` 
val literate : kotlin.Boolean = true // kotlin.Boolean | Insert textual annotations in the PGN about the opening, analysis variations, mistakes, and game termination.  Example: `5... g4? { (-0.98 → 0.60) Mistake. Best move was h6. } (5... h6 6. d4 Ne7 7. g3 d5 8. exd5 fxg3 9. hxg3 c6 10. dxc6)` 
val players : kotlin.String = players_example // kotlin.String | URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: <https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt> 
try {
    val result : kotlin.Any = apiInstance.apiUserCurrentGame(username, moves, pgnInJson, tags, clocks, evals, opening, literate, players)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling GamesApi#apiUserCurrentGame")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling GamesApi#apiUserCurrentGame")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **kotlin.String**|  |
 **moves** | **kotlin.Boolean**| Include the PGN moves. | [optional] [default to true]
 **pgnInJson** | **kotlin.Boolean**| Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. | [optional] [default to false]
 **tags** | **kotlin.Boolean**| Include the PGN tags. | [optional] [default to true]
 **clocks** | **kotlin.Boolean**| Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | [optional] [default to true]
 **evals** | **kotlin.Boolean**| Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  | [optional] [default to true]
 **opening** | **kotlin.Boolean**| Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  | [optional] [default to true]
 **literate** | **kotlin.Boolean**| Insert textual annotations in the PGN about the opening, analysis variations, mistakes, and game termination.  Example: &#x60;5... g4? { (-0.98 → 0.60) Mistake. Best move was h6. } (5... h6 6. d4 Ne7 7. g3 d5 8. exd5 fxg3 9. hxg3 c6 10. dxc6)&#x60;  | [optional] [default to false]
 **players** | **kotlin.String**| URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt;  | [optional]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn, application/json

<a name="gameImport"></a>
# **gameImport**
> kotlin.Any gameImport(pgn)

Import one game

Import a game from PGN. See &lt;https://lichess.org/paste&gt;.  Rate limiting: 200 games per hour for OAuth requests, 100 games per hour for anonymous requests.  To broadcast ongoing games, consider [pushing to a broadcast instead](#operation/broadcastPush). 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = GamesApi()
val pgn : kotlin.String = pgn_example // kotlin.String | The PGN. It can contain only one game. Most standard tags are supported.
try {
    val result : kotlin.Any = apiInstance.gameImport(pgn)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling GamesApi#gameImport")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling GamesApi#gameImport")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **pgn** | **kotlin.String**| The PGN. It can contain only one game. Most standard tags are supported. | [optional]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

<a name="gamePgn"></a>
# **gamePgn**
> kotlin.Any gamePgn(gameId, moves, pgnInJson, tags, clocks, evals, opening, literate, players)

Export one game

Download one game in either PGN or JSON format.  Ongoing games have their last 3 moves omitted, after move 5. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = GamesApi()
val gameId : kotlin.String = gameId_example // kotlin.String | The game ID (8 characters).
val moves : kotlin.Boolean = true // kotlin.Boolean | Include the PGN moves.
val pgnInJson : kotlin.Boolean = true // kotlin.Boolean | Include the full PGN within the JSON response, in a `pgn` field.
val tags : kotlin.Boolean = true // kotlin.Boolean | Include the PGN tags.
val clocks : kotlin.Boolean = true // kotlin.Boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }` 
val evals : kotlin.Boolean = true // kotlin.Boolean | Include analysis evaluation comments in the PGN, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }` 
val opening : kotlin.Boolean = true // kotlin.Boolean | Include the opening name.  Example: `[Opening \"King's Gambit Accepted, King's Knight Gambit\"]` 
val literate : kotlin.Boolean = true // kotlin.Boolean | Insert textual annotations in the PGN about the opening, analysis variations, mistakes, and game termination.  Example: `5... g4? { (-0.98 → 0.60) Mistake. Best move was h6. } (5... h6 6. d4 Ne7 7. g3 d5 8. exd5 fxg3 9. hxg3 c6 10. dxc6)` 
val players : kotlin.String = players_example // kotlin.String | URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: <https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt> 
try {
    val result : kotlin.Any = apiInstance.gamePgn(gameId, moves, pgnInJson, tags, clocks, evals, opening, literate, players)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling GamesApi#gamePgn")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling GamesApi#gamePgn")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **kotlin.String**| The game ID (8 characters). |
 **moves** | **kotlin.Boolean**| Include the PGN moves. | [optional] [default to true]
 **pgnInJson** | **kotlin.Boolean**| Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. | [optional] [default to false]
 **tags** | **kotlin.Boolean**| Include the PGN tags. | [optional] [default to true]
 **clocks** | **kotlin.Boolean**| Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | [optional] [default to true]
 **evals** | **kotlin.Boolean**| Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  | [optional] [default to true]
 **opening** | **kotlin.Boolean**| Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  | [optional] [default to true]
 **literate** | **kotlin.Boolean**| Insert textual annotations in the PGN about the opening, analysis variations, mistakes, and game termination.  Example: &#x60;5... g4? { (-0.98 → 0.60) Mistake. Best move was h6. } (5... h6 6. d4 Ne7 7. g3 d5 8. exd5 fxg3 9. hxg3 c6 10. dxc6)&#x60;  | [optional] [default to false]
 **players** | **kotlin.String**| URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt;  | [optional]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn, application/json

<a name="gamesByUsers"></a>
# **gamesByUsers**
> kotlin.Any gamesByUsers(body, withCurrentGames)

Stream games of users

Stream the games played between a list of users, in real time. Only games where **both players** are part of the list are included.  By default, games are only sent to the stream when they start. To also get all ongoing games at the beginning of the stream, use the &#x60;withCurrentGames&#x60; flag.  Maximum number of users: 300.  Games are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  The method is &#x60;POST&#x60; so a longer list of IDs can be sent in the request body. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = GamesApi()
val body : kotlin.String = aliquantus,chess-network,lovlas // kotlin.String | Up to 300 user IDs separated by commas.
val withCurrentGames : kotlin.Boolean = true // kotlin.Boolean | Include the already started games at the beginning of the stream.
try {
    val result : kotlin.Any = apiInstance.gamesByUsers(body, withCurrentGames)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling GamesApi#gamesByUsers")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling GamesApi#gamesByUsers")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | **kotlin.String**| Up to 300 user IDs separated by commas. |
 **withCurrentGames** | **kotlin.Boolean**| Include the already started games at the beginning of the stream. | [optional] [default to false]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: text/plain
 - **Accept**: application/x-ndjson

<a name="gamesExportIds"></a>
# **gamesExportIds**
> kotlin.Any gamesExportIds(body, moves, pgnInJson, tags, clocks, evals, opening, players)

Export games by IDs

Download games by IDs in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format, depending on the request Accept header.  Games are sorted by reverse chronological order (most recent first)  The method is &#x60;POST&#x60; so a longer list of IDs can be sent in the request body.  300 IDs can be submitted.  Ongoing games have their last 3 moves omitted, after move 5. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = GamesApi()
val body : kotlin.String = TJxUmbWK,4OtIh2oh,ILwozzRZ // kotlin.String | Game IDs separated by commas. Up to 300.
val moves : kotlin.Boolean = true // kotlin.Boolean | Include the PGN moves.
val pgnInJson : kotlin.Boolean = true // kotlin.Boolean | Include the full PGN within the JSON response, in a `pgn` field.
val tags : kotlin.Boolean = true // kotlin.Boolean | Include the PGN tags.
val clocks : kotlin.Boolean = true // kotlin.Boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }` 
val evals : kotlin.Boolean = true // kotlin.Boolean | Include analysis evaluation comments in the PGN, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }` 
val opening : kotlin.Boolean = true // kotlin.Boolean | Include the opening name.  Example: `[Opening \"King's Gambit Accepted, King's Knight Gambit\"]` 
val players : kotlin.String = players_example // kotlin.String | URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: <https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt> 
try {
    val result : kotlin.Any = apiInstance.gamesExportIds(body, moves, pgnInJson, tags, clocks, evals, opening, players)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling GamesApi#gamesExportIds")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling GamesApi#gamesExportIds")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | **kotlin.String**| Game IDs separated by commas. Up to 300. |
 **moves** | **kotlin.Boolean**| Include the PGN moves. | [optional] [default to true]
 **pgnInJson** | **kotlin.Boolean**| Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. | [optional] [default to false]
 **tags** | **kotlin.Boolean**| Include the PGN tags. | [optional] [default to true]
 **clocks** | **kotlin.Boolean**| Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | [optional] [default to false]
 **evals** | **kotlin.Boolean**| Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  | [optional] [default to false]
 **opening** | **kotlin.Boolean**| Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  | [optional] [default to false]
 **players** | **kotlin.String**| URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt;  | [optional]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: text/plain
 - **Accept**: application/x-chess-pgn, application/x-ndjson

<a name="streamGame"></a>
# **streamGame**
> kotlin.Any streamGame(id)

Stream moves of a game

Stream positions and moves of any ongoing game, in [ndjson](#section/Introduction/Streaming-with-ND-JSON).  A description of the game is sent as a first message. Then a message is sent each time a move is played. Finally a description of the game is sent when it finishes, and the stream is closed.  After move 5, the stream intentionally remains 3 moves behind the game status, as to prevent cheat bots from using this API.  No more than 8 game streams can be opened at the same time from the same IP address. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = GamesApi()
val id : kotlin.String = LuGQwhBb // kotlin.String | 
try {
    val result : kotlin.Any = apiInstance.streamGame(id)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling GamesApi#streamGame")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling GamesApi#streamGame")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **kotlin.String**|  |

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

