# OAuthApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiToken**](OAuthApi.md#apiToken) | **POST** /api/token | Obtain access token
[**apiTokenDelete**](OAuthApi.md#apiTokenDelete) | **DELETE** /api/token | Revoke access token
[**oauth**](OAuthApi.md#oauth) | **GET** /oauth | Request authorization code


<a name="apiToken"></a>
# **apiToken**
> apiToken(grantType, code, codeVerifier, redirectUri, clientId)

Obtain access token

OAuth2 token endpoint. Exchanges an authorization code for an access token. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = OAuthApi()
val grantType : kotlin.String = grantType_example // kotlin.String | Must be `authorization_code`.
val code : kotlin.String = code_example // kotlin.String | The authorization code that was sent in the `code` parameter to your `redirect_uri`.
val codeVerifier : kotlin.String = codeVerifier_example // kotlin.String | A `code_challenge` was used to request the authorization code. This must be the `code_verifier` it was derived from.
val redirectUri : kotlin.String = redirectUri_example // kotlin.String | Must match the `redirect_uri` used to request the authorization code.
val clientId : kotlin.String = clientId_example // kotlin.String | Must match the `client_id` used to request the authorization code.
try {
    apiInstance.apiToken(grantType, code, codeVerifier, redirectUri, clientId)
} catch (e: ClientException) {
    println("4xx response calling OAuthApi#apiToken")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling OAuthApi#apiToken")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **grantType** | **kotlin.String**| Must be &#x60;authorization_code&#x60;. | [optional]
 **code** | **kotlin.String**| The authorization code that was sent in the &#x60;code&#x60; parameter to your &#x60;redirect_uri&#x60;. | [optional]
 **codeVerifier** | **kotlin.String**| A &#x60;code_challenge&#x60; was used to request the authorization code. This must be the &#x60;code_verifier&#x60; it was derived from. | [optional]
 **redirectUri** | **kotlin.String**| Must match the &#x60;redirect_uri&#x60; used to request the authorization code. | [optional]
 **clientId** | **kotlin.String**| Must match the &#x60;client_id&#x60; used to request the authorization code. | [optional]

### Return type

null (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

<a name="apiTokenDelete"></a>
# **apiTokenDelete**
> apiTokenDelete()

Revoke access token

Revokes the access token sent as Bearer for this request.

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = OAuthApi()
try {
    apiInstance.apiTokenDelete()
} catch (e: ClientException) {
    println("4xx response calling OAuthApi#apiTokenDelete")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling OAuthApi#apiTokenDelete")
    e.printStackTrace()
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

null (empty response body)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

<a name="oauth"></a>
# **oauth**
> oauth(responseType, clientId, redirectUri, codeChallengeMethod, codeChallenge, scope, state)

Request authorization code

OAuth2 authorization endpoint.  Start the OAuth2 Authorization Code Flow with PKCE by securely generating two random strings unique to each authorization request: * &#x60;code_verifier&#x60; * &#x60;state&#x60;  Store these in session storage. Make sure not to reveal &#x60;code_verifier&#x60; to eavesdroppers. Do not show it in URLs, do not abuse &#x60;state&#x60; to store it, do not send it over insecure connections. However it is fine if the user themselves can extract &#x60;code_verifier&#x60;, which will always be possible for fully client-side apps.  Then send the user to this endpoint. They will be prompted to grant authorization and then be redirected back to the given &#x60;redirect_uri&#x60;.  If the authorization failed, the following query string parameters will be appended to the redirection: * &#x60;error&#x60;, in particular with value &#x60;access_denied&#x60; if the user    cancelled authorization * &#x60;error_description&#x60; to aid debugging * &#x60;state&#x60;, exactly as passed in the &#x60;state&#x60; parameter  If the authorization succeeded, the following query string parameters will be appended to the redirection: * &#x60;code&#x60;, containing a fresh short-lived authorization code * &#x60;state&#x60;, exactly as passed in the &#x60;state&#x60; parameter  Next, to defend against cross site request forgery, check that the returned &#x60;state&#x60; matches the &#x60;state&#x60; you originally generated.  Finally, continue by using the authorization code to [obtain an access token](#operation/apiToken). 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = OAuthApi()
val responseType : kotlin.String = responseType_example // kotlin.String | Must be `code`.
val clientId : kotlin.String = example.com // kotlin.String | Arbitrary identifier that uniquely identifies your application.
val redirectUri : kotlin.String = redirectUri_example // kotlin.String | The absolute URL that the user should be redirected to with the authorization result.
val codeChallengeMethod : kotlin.String = codeChallengeMethod_example // kotlin.String | Must be `S256`.
val codeChallenge : kotlin.String = codeChallenge_example // kotlin.String | Compute `BASE64URL(SHA256(code_verifier))`.
val scope : kotlin.String = scope_example // kotlin.String | Space separated list of requested OAuth scopes, if any.
val state : kotlin.String = state_example // kotlin.String | Arbitrary state that will be returned verbatim with the authorization result.
try {
    apiInstance.oauth(responseType, clientId, redirectUri, codeChallengeMethod, codeChallenge, scope, state)
} catch (e: ClientException) {
    println("4xx response calling OAuthApi#oauth")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling OAuthApi#oauth")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **responseType** | **kotlin.String**| Must be &#x60;code&#x60;. |
 **clientId** | **kotlin.String**| Arbitrary identifier that uniquely identifies your application. |
 **redirectUri** | **kotlin.String**| The absolute URL that the user should be redirected to with the authorization result. |
 **codeChallengeMethod** | **kotlin.String**| Must be &#x60;S256&#x60;. |
 **codeChallenge** | **kotlin.String**| Compute &#x60;BASE64URL(SHA256(code_verifier))&#x60;. |
 **scope** | **kotlin.String**| Space separated list of requested OAuth scopes, if any. | [optional]
 **state** | **kotlin.String**| Arbitrary state that will be returned verbatim with the authorization result. | [optional]

### Return type

null (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: Not defined

