# OpeningExplorerApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**openingExplorerLichess**](OpeningExplorerApi.md#openingExplorerLichess) | **GET** /lichess | Lichess games
[**openingExplorerMaster**](OpeningExplorerApi.md#openingExplorerMaster) | **GET** /masters | Masters database
[**openingExplorerMasterGame**](OpeningExplorerApi.md#openingExplorerMasterGame) | **GET** /master/pgn/{gameId} | OTB master game
[**openingExplorerPlayer**](OpeningExplorerApi.md#openingExplorerPlayer) | **GET** /player? | Player games


<a name="openingExplorerLichess"></a>
# **openingExplorerLichess**
> kotlin.Any openingExplorerLichess(variant, fen, play, speeds, ratings, since, until, moves, topGames, recentGames)

Lichess games

**Endpoint: &lt;https://explorer.lichess.ovh/lichess&gt;**  Games sampled from all Lichess players.  Example: &#x60;curl https://explorer.lichess.ovh/lichess?variant&#x3D;standard&amp;speeds&#x3D;blitz,rapid,classical&amp;ratings&#x3D;2200,2500&amp;fen&#x3D;rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR%20w%20KQkq%20-%200%201&#x60; 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = OpeningExplorerApi()
val variant : VariantKey =  // VariantKey | Variant
val fen : kotlin.String = rnbqkbnr/ppp1pppp/8/3pP3/8/8/PPPP1PPP/RNBQKBNR b KQkq - 0 2 // kotlin.String | FEN of the root position
val play : kotlin.String = e2e4,e7e5,c2c4,c7c6,c4e5 // kotlin.String | Comma separated sequence of legal moves in UCI notation. Play additional moves starting from `fen`. Required to find an opening name, if `fen` is not an exact match for a named position. 
val speeds : kotlin.collections.List<Speed> =  // kotlin.collections.List<Speed> | Comma separated list of game speeds to look for
val ratings : kotlin.collections.List<java.math.BigDecimal> =  // kotlin.collections.List<java.math.BigDecimal> | Comma separated list of rating groups, ranging from their value to the next higher group
val since : kotlin.String = since_example // kotlin.String | Include only games from this month or later
val until : kotlin.String = until_example // kotlin.String | Include only games from this month or earlier
val moves : java.math.BigDecimal = 8.14 // java.math.BigDecimal | Number of most common moves to display
val topGames : java.math.BigDecimal = 8.14 // java.math.BigDecimal | Number of top games to display
val recentGames : java.math.BigDecimal = 8.14 // java.math.BigDecimal | Number of recent games to display
try {
    val result : kotlin.Any = apiInstance.openingExplorerLichess(variant, fen, play, speeds, ratings, since, until, moves, topGames, recentGames)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling OpeningExplorerApi#openingExplorerLichess")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling OpeningExplorerApi#openingExplorerLichess")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **variant** | [**VariantKey**](.md)| Variant | [optional] [default to standard] [enum: standard, chess960, crazyhouse, antichess, atomic, horde, kingOfTheHill, racingKings, threeCheck]
 **fen** | **kotlin.String**| FEN of the root position | [optional]
 **play** | **kotlin.String**| Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  | [optional] [default to &quot;&quot;]
 **speeds** | [**kotlin.collections.List&lt;Speed&gt;**](Speed.md)| Comma separated list of game speeds to look for | [optional]
 **ratings** | [**kotlin.collections.List&lt;java.math.BigDecimal&gt;**](java.math.BigDecimal.md)| Comma separated list of rating groups, ranging from their value to the next higher group | [optional] [enum: 1600, 1800, 2000, 2200, 2500]
 **since** | **kotlin.String**| Include only games from this month or later | [optional] [default to &quot;0000-01&quot;]
 **until** | **kotlin.String**| Include only games from this month or earlier | [optional] [default to &quot;3000-12&quot;]
 **moves** | **java.math.BigDecimal**| Number of most common moves to display | [optional] [default to 12]
 **topGames** | **java.math.BigDecimal**| Number of top games to display | [optional] [default to 4]
 **recentGames** | **java.math.BigDecimal**| Number of recent games to display | [optional] [default to 4]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="openingExplorerMaster"></a>
# **openingExplorerMaster**
> kotlin.Any openingExplorerMaster(fen, play, since, until, moves, topGames)

Masters database

**Endpoint: &lt;https://explorer.lichess.ovh/masters&gt;**  Example: &#x60;curl https://explorer.lichess.ovh/masters?play&#x3D;d2d4,d7d5,c2c4,c7c6,c4d5&#x60; 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = OpeningExplorerApi()
val fen : kotlin.String = rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1 // kotlin.String | FEN of the root position
val play : kotlin.String = e2e4,e7e5,c2c4,c7c6,c4e5 // kotlin.String | Comma separated sequence of legal moves in UCI notation. Play additional moves starting from `fen`. Required to find an opening name, if `fen` is not an exact match for a named position. 
val since : java.math.BigDecimal = 8.14 // java.math.BigDecimal | Include only games from this year or later
val until : java.math.BigDecimal = 8.14 // java.math.BigDecimal | Include only games from thi year or earlier
val moves : java.math.BigDecimal = 8.14 // java.math.BigDecimal | Number of most common moves to display
val topGames : java.math.BigDecimal = 8.14 // java.math.BigDecimal | Number of top games to display
try {
    val result : kotlin.Any = apiInstance.openingExplorerMaster(fen, play, since, until, moves, topGames)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling OpeningExplorerApi#openingExplorerMaster")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling OpeningExplorerApi#openingExplorerMaster")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **fen** | **kotlin.String**| FEN of the root position | [optional]
 **play** | **kotlin.String**| Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  | [optional] [default to &quot;&quot;]
 **since** | **java.math.BigDecimal**| Include only games from this year or later | [optional] [default to 1952]
 **until** | **java.math.BigDecimal**| Include only games from thi year or earlier | [optional]
 **moves** | **java.math.BigDecimal**| Number of most common moves to display | [optional] [default to 12]
 **topGames** | **java.math.BigDecimal**| Number of top games to display | [optional] [default to 15]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="openingExplorerMasterGame"></a>
# **openingExplorerMasterGame**
> kotlin.Any openingExplorerMasterGame(gameId)

OTB master game

**Endpoint: &#x60;https://explorer.lichess.ovh/masters/pgn/{gameId}&#x60;**  Example: &#x60;curl https://explorer.lichess.ovh/masters/pgn/aAbqI4ey&#x60; 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = OpeningExplorerApi()
val gameId : kotlin.String = gameId_example // kotlin.String | 
try {
    val result : kotlin.Any = apiInstance.openingExplorerMasterGame(gameId)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling OpeningExplorerApi#openingExplorerMasterGame")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling OpeningExplorerApi#openingExplorerMasterGame")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gameId** | **kotlin.String**|  |

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn

<a name="openingExplorerPlayer"></a>
# **openingExplorerPlayer**
> kotlin.Any openingExplorerPlayer(variant, fen, play, speeds, modes, since, until, moves, recentGames)

Player games

**Endpoint: &lt;https://explorer.lichess.ovh/player&gt;**  Games of a Lichess player.  Responds with a stream of newline delimited JSON. Will start indexing on demand, immediately respond with the current results, and stream more updates until indexing is complete. The stream is throttled and deduplicated. Empty lines may be sent to avoid timeouts.  Will index new games at most once per minute, and revisit previously ongoing games at most once every day.  Example: &#x60;curl https://explorer.lichess.ovh/player?player&#x3D;revoof&amp;color&#x3D;white&amp;play&#x3D;d2d4,d7d5&amp;recentGames&#x3D;1&#x60; 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = OpeningExplorerApi()
val variant : VariantKey =  // VariantKey | Variant
val fen : kotlin.String = rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1 // kotlin.String | FEN of the root position
val play : kotlin.String = d2d4,d7d5 // kotlin.String | Comma separated sequence of legal moves in UCI notation. Play additional moves starting from `fen`. Required to find an opening name, if `fen` is not an exact match for a named position. 
val speeds : kotlin.collections.List<Speed> =  // kotlin.collections.List<Speed> | Comma separated list of game speeds to look for
val modes : kotlin.collections.List<kotlin.String> =  // kotlin.collections.List<kotlin.String> | Comma separated list of modes
val since : kotlin.String = since_example // kotlin.String | Include only games from this month or later
val until : kotlin.String = until_example // kotlin.String | Include only games from this month or earlier
val moves : java.math.BigDecimal = 8.14 // java.math.BigDecimal | Number of most common moves to display
val recentGames : java.math.BigDecimal = 8.14 // java.math.BigDecimal | Number of recent games to display
try {
    val result : kotlin.Any = apiInstance.openingExplorerPlayer(variant, fen, play, speeds, modes, since, until, moves, recentGames)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling OpeningExplorerApi#openingExplorerPlayer")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling OpeningExplorerApi#openingExplorerPlayer")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **variant** | [**VariantKey**](.md)| Variant | [optional] [default to standard] [enum: standard, chess960, crazyhouse, antichess, atomic, horde, kingOfTheHill, racingKings, threeCheck]
 **fen** | **kotlin.String**| FEN of the root position | [optional]
 **play** | **kotlin.String**| Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  | [optional] [default to &quot;&quot;]
 **speeds** | [**kotlin.collections.List&lt;Speed&gt;**](Speed.md)| Comma separated list of game speeds to look for | [optional]
 **modes** | [**kotlin.collections.List&lt;kotlin.String&gt;**](kotlin.String.md)| Comma separated list of modes | [optional] [enum: casual, rated]
 **since** | **kotlin.String**| Include only games from this month or later | [optional] [default to &quot;0000-01&quot;]
 **until** | **kotlin.String**| Include only games from this month or earlier | [optional] [default to &quot;3000-12&quot;]
 **moves** | **java.math.BigDecimal**| Number of most common moves to display | [optional]
 **recentGames** | **java.math.BigDecimal**| Number of recent games to display | [optional] [default to 4]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/nd-json

