# PuzzlesApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiPuzzleActivity**](PuzzlesApi.md#apiPuzzleActivity) | **GET** /api/puzzle/activity | Get your puzzle activity
[**apiPuzzleDaily**](PuzzlesApi.md#apiPuzzleDaily) | **GET** /api/puzzle/daily | Get the daily puzzle
[**apiPuzzleDashboard**](PuzzlesApi.md#apiPuzzleDashboard) | **GET** /api/puzzle/dashboard/{days} | Get your puzzle dashboard
[**apiStormDashboard**](PuzzlesApi.md#apiStormDashboard) | **GET** /api/storm/dashboard/{username} | Get the storm dashboard of a player


<a name="apiPuzzleActivity"></a>
# **apiPuzzleActivity**
> PuzzleRoundJson apiPuzzleActivity(max)

Get your puzzle activity

Download your puzzle activity in [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Puzzle activity is sorted by reverse chronological order (most recent first)  We recommend streaming the response, for it can be very long. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = PuzzlesApi()
val max : kotlin.Int = 56 // kotlin.Int | How many entries to download. Leave empty to download all activity.
try {
    val result : PuzzleRoundJson = apiInstance.apiPuzzleActivity(max)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling PuzzlesApi#apiPuzzleActivity")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling PuzzlesApi#apiPuzzleActivity")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **max** | **kotlin.Int**| How many entries to download. Leave empty to download all activity. | [optional]

### Return type

[**PuzzleRoundJson**](PuzzleRoundJson.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

<a name="apiPuzzleDaily"></a>
# **apiPuzzleDaily**
> kotlin.Any apiPuzzleDaily()

Get the daily puzzle

Get the daily Lichess puzzle in JSON format.  Alternatively, you can [post it in your slack workspace](https://lichess.org/daily-puzzle-slack). 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = PuzzlesApi()
try {
    val result : kotlin.Any = apiInstance.apiPuzzleDaily()
    println(result)
} catch (e: ClientException) {
    println("4xx response calling PuzzlesApi#apiPuzzleDaily")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling PuzzlesApi#apiPuzzleDaily")
    e.printStackTrace()
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

<a name="apiPuzzleDashboard"></a>
# **apiPuzzleDashboard**
> kotlin.Any apiPuzzleDashboard(days)

Get your puzzle dashboard

Download your [puzzle dashboard](https://lichess.org/training/dashboard/30/dashboard) as JSON.  Also includes all puzzle themes played, with aggregated results.  Allows re-creating the [improvement/strengths](https://lichess.org/training/dashboard/30/improvementAreas) interfaces. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = PuzzlesApi()
val days : kotlin.Int = 56 // kotlin.Int | How many days to look back when aggregating puzzle results. 30 is sensible.
try {
    val result : kotlin.Any = apiInstance.apiPuzzleDashboard(days)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling PuzzlesApi#apiPuzzleDashboard")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling PuzzlesApi#apiPuzzleDashboard")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **days** | **kotlin.Int**| How many days to look back when aggregating puzzle results. 30 is sensible. |

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="apiStormDashboard"></a>
# **apiStormDashboard**
> kotlin.Any apiStormDashboard(username, days)

Get the storm dashboard of a player

Download the [storm dashboard](https://lichess.org/storm/dashboard/mrbasso) of any player as JSON.  Contains the aggregated highscores, and the history of storm runs aggregated by days.  Use &#x60;?days&#x3D;0&#x60; if you only care about the highscores. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = PuzzlesApi()
val username : kotlin.String = username_example // kotlin.String | Username of the player
val days : kotlin.Int = 56 // kotlin.Int | How many days of history to return
try {
    val result : kotlin.Any = apiInstance.apiStormDashboard(username, days)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling PuzzlesApi#apiStormDashboard")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling PuzzlesApi#apiStormDashboard")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **kotlin.String**| Username of the player |
 **days** | **kotlin.Int**| How many days of history to return | [optional] [default to 30]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

