# StudiesApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**studyAllChaptersPgn**](StudiesApi.md#studyAllChaptersPgn) | **GET** /api/study/{studyId}.pgn | Export all chapters
[**studyChapterPgn**](StudiesApi.md#studyChapterPgn) | **GET** /study/{studyId}/{chapterId}.pgn | Export one study chapter
[**studyExportAllPgn**](StudiesApi.md#studyExportAllPgn) | **GET** /study/by/{username}/export.pgn | Export all studies of a user


<a name="studyAllChaptersPgn"></a>
# **studyAllChaptersPgn**
> kotlin.Any studyAllChaptersPgn(studyId, clocks, comments, variations)

Export all chapters

Download all chapters of a study in PGN format. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = StudiesApi()
val studyId : kotlin.String = studyId_example // kotlin.String | The study ID (8 characters).
val clocks : kotlin.Boolean = true // kotlin.Boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }` 
val comments : kotlin.Boolean = true // kotlin.Boolean | Include analysis and annotator comments in the PGN moves, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }` 
val variations : kotlin.Boolean = true // kotlin.Boolean | Include non-mainline moves, when available.  Example: `4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2` 
try {
    val result : kotlin.Any = apiInstance.studyAllChaptersPgn(studyId, clocks, comments, variations)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling StudiesApi#studyAllChaptersPgn")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling StudiesApi#studyAllChaptersPgn")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **studyId** | **kotlin.String**| The study ID (8 characters). |
 **clocks** | **kotlin.Boolean**| Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | [optional] [default to true]
 **comments** | **kotlin.Boolean**| Include analysis and annotator comments in the PGN moves, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }&#x60;  | [optional] [default to true]
 **variations** | **kotlin.Boolean**| Include non-mainline moves, when available.  Example: &#x60;4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2&#x60;  | [optional] [default to true]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn

<a name="studyChapterPgn"></a>
# **studyChapterPgn**
> kotlin.Any studyChapterPgn(studyId, chapterId, clocks, comments, variations)

Export one study chapter

Download one study chapter in PGN format. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = StudiesApi()
val studyId : kotlin.String = studyId_example // kotlin.String | The study ID (8 characters).
val chapterId : kotlin.String = chapterId_example // kotlin.String | The chapter ID (8 characters).
val clocks : kotlin.Boolean = true // kotlin.Boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }` 
val comments : kotlin.Boolean = true // kotlin.Boolean | Include analysis and annotator comments in the PGN moves, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }` 
val variations : kotlin.Boolean = true // kotlin.Boolean | Include non-mainline moves, when available.  Example: `4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2` 
try {
    val result : kotlin.Any = apiInstance.studyChapterPgn(studyId, chapterId, clocks, comments, variations)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling StudiesApi#studyChapterPgn")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling StudiesApi#studyChapterPgn")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **studyId** | **kotlin.String**| The study ID (8 characters). |
 **chapterId** | **kotlin.String**| The chapter ID (8 characters). |
 **clocks** | **kotlin.Boolean**| Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | [optional] [default to true]
 **comments** | **kotlin.Boolean**| Include analysis and annotator comments in the PGN moves, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }&#x60;  | [optional] [default to true]
 **variations** | **kotlin.Boolean**| Include non-mainline moves, when available.  Example: &#x60;4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2&#x60;  | [optional] [default to true]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn

<a name="studyExportAllPgn"></a>
# **studyExportAllPgn**
> kotlin.Any studyExportAllPgn(username, clocks, comments, variations)

Export all studies of a user

Download all chapters of all studies of a user in PGN format.  If authenticated, then all public, unlisted, and private studies are included.  If not, only public, listed studies are included. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = StudiesApi()
val username : kotlin.String = username_example // kotlin.String | The user whose studies we export
val clocks : kotlin.Boolean = true // kotlin.Boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }` 
val comments : kotlin.Boolean = true // kotlin.Boolean | Include analysis and annotator comments in the PGN moves, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }` 
val variations : kotlin.Boolean = true // kotlin.Boolean | Include non-mainline moves, when available.  Example: `4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2` 
try {
    val result : kotlin.Any = apiInstance.studyExportAllPgn(username, clocks, comments, variations)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling StudiesApi#studyExportAllPgn")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling StudiesApi#studyExportAllPgn")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **kotlin.String**| The user whose studies we export |
 **clocks** | **kotlin.Boolean**| Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | [optional] [default to true]
 **comments** | **kotlin.Boolean**| Include analysis and annotator comments in the PGN moves, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { White is in a pickle. }&#x60;  | [optional] [default to true]
 **variations** | **kotlin.Boolean**| Include non-mainline moves, when available.  Example: &#x60;4. d4 Bb4+ (4... Nc6 5. Nf3 Bb4+ 6. Bd2 (6. Nbd2 O-O 7. O-O) 6... Bd6) 5. Nd2&#x60;  | [optional] [default to true]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn

