# SwissTournamentsApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiSwissJoin**](SwissTournamentsApi.md#apiSwissJoin) | **POST** /api/swiss/{id}/join | Join a Swiss tournament
[**apiSwissNew**](SwissTournamentsApi.md#apiSwissNew) | **POST** /api/swiss/new/{teamId} | Create a new Swiss tournament
[**apiSwissTerminate**](SwissTournamentsApi.md#apiSwissTerminate) | **POST** /api/swiss/{id}/terminate | Terminate a Swiss tournament
[**apiSwissUpdate**](SwissTournamentsApi.md#apiSwissUpdate) | **POST** /api/swiss/{id}/edit | Update a Swiss tournament.
[**apiTeamSwiss**](SwissTournamentsApi.md#apiTeamSwiss) | **GET** /api/team/{teamId}/swiss | Get team swiss tournaments
[**gamesBySwiss**](SwissTournamentsApi.md#gamesBySwiss) | **GET** /api/swiss/{id}/games | Export games of a Swiss tournament
[**resultsBySwiss**](SwissTournamentsApi.md#resultsBySwiss) | **GET** /api/swiss/{id}/results | Get results of a swiss tournament
[**swissTrf**](SwissTournamentsApi.md#swissTrf) | **GET** /swiss/{id}.trf | Export TRF of a Swiss tournament


<a name="apiSwissJoin"></a>
# **apiSwissJoin**
> Ok apiSwissJoin(id, password)

Join a Swiss tournament

Join a Swiss tournament, possibly with a password. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = SwissTournamentsApi()
val id : kotlin.String = hL7vMrFQ // kotlin.String | The tournament ID.
val password : kotlin.String = password_example // kotlin.String | The tournament password, if one is required
try {
    val result : Ok = apiInstance.apiSwissJoin(id, password)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling SwissTournamentsApi#apiSwissJoin")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling SwissTournamentsApi#apiSwissJoin")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **kotlin.String**| The tournament ID. |
 **password** | **kotlin.String**| The tournament password, if one is required | [optional]

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

<a name="apiSwissNew"></a>
# **apiSwissNew**
> kotlin.Any apiSwissNew(teamId, clockLimit, clockIncrement, nbRounds, name, startsAt, roundInterval, variant, description, rated, chatFor)

Create a new Swiss tournament

Create a Swiss tournament for your team.  This endpoint mirrors the Swiss tournament form from your team pagee.  You can create up to 12 tournaments per day. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = SwissTournamentsApi()
val teamId : kotlin.String = teamId_example // kotlin.String | ID of the team
val clockLimit : java.math.BigDecimal = 8.14 // java.math.BigDecimal | Clock initial time in seconds
val clockIncrement : kotlin.Int = 56 // kotlin.Int | Clock increment in seconds
val nbRounds : kotlin.Int = 56 // kotlin.Int | Maximum number of rounds to play
val name : kotlin.String = name_example // kotlin.String | The tournament name. Leave empty to get a random Grandmaster name
val startsAt : kotlin.Int = 56 // kotlin.Int | Timestamp in milliseconds to start the tournament at a given date and time. By default, it starts 10 minutes after creation.
val roundInterval : kotlin.Int = 56 // kotlin.Int | How long to wait between each round, in seconds.  Set to 99999999 to manually schedule each round from the tournament UI. 
val variant : VariantKey =  // VariantKey | 
val description : kotlin.String = description_example // kotlin.String | Anything you want to tell players about the tournament
val rated : kotlin.Boolean = true // kotlin.Boolean | Games are rated and impact players ratings
val chatFor : java.math.BigDecimal = 8.14 // java.math.BigDecimal | Who can read and write in the chat. - 0  = No-one - 10 = Only team leaders - 20 = Only team members - 30 = All Lichess players 
try {
    val result : kotlin.Any = apiInstance.apiSwissNew(teamId, clockLimit, clockIncrement, nbRounds, name, startsAt, roundInterval, variant, description, rated, chatFor)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling SwissTournamentsApi#apiSwissNew")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling SwissTournamentsApi#apiSwissNew")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | **kotlin.String**| ID of the team |
 **clockLimit** | **java.math.BigDecimal**| Clock initial time in seconds |
 **clockIncrement** | **kotlin.Int**| Clock increment in seconds |
 **nbRounds** | **kotlin.Int**| Maximum number of rounds to play | [default to 8]
 **name** | **kotlin.String**| The tournament name. Leave empty to get a random Grandmaster name | [optional]
 **startsAt** | **kotlin.Int**| Timestamp in milliseconds to start the tournament at a given date and time. By default, it starts 10 minutes after creation. | [optional]
 **roundInterval** | **kotlin.Int**| How long to wait between each round, in seconds.  Set to 99999999 to manually schedule each round from the tournament UI.  | [optional]
 **variant** | [**VariantKey**](VariantKey.md)|  | [optional] [default to VariantKey.standard] [enum: standard, chess960, crazyhouse, antichess, atomic, horde, kingOfTheHill, racingKings, threeCheck]
 **description** | **kotlin.String**| Anything you want to tell players about the tournament | [optional]
 **rated** | **kotlin.Boolean**| Games are rated and impact players ratings | [optional] [default to true]
 **chatFor** | **java.math.BigDecimal**| Who can read and write in the chat. - 0  &#x3D; No-one - 10 &#x3D; Only team leaders - 20 &#x3D; Only team members - 30 &#x3D; All Lichess players  | [optional] [default to 20]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

<a name="apiSwissTerminate"></a>
# **apiSwissTerminate**
> Ok apiSwissTerminate(id)

Terminate a Swiss tournament

Terminate a Swiss tournament 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = SwissTournamentsApi()
val id : kotlin.String = W5FrxusN // kotlin.String | The Swiss tournament ID.
try {
    val result : Ok = apiInstance.apiSwissTerminate(id)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling SwissTournamentsApi#apiSwissTerminate")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling SwissTournamentsApi#apiSwissTerminate")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **kotlin.String**| The Swiss tournament ID. |

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="apiSwissUpdate"></a>
# **apiSwissUpdate**
> kotlin.Any apiSwissUpdate(id, clockLimit, clockIncrement, nbRounds, name, startsAt, roundInterval, variant, description, rated, chatFor)

Update a Swiss tournament.

Update a Swiss tournament.  Be mindful not to make important changes to ongoing tournaments. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = SwissTournamentsApi()
val id : kotlin.String = hL7vMrFQ // kotlin.String | The tournament ID.
val clockLimit : java.math.BigDecimal = 8.14 // java.math.BigDecimal | Clock initial time in seconds
val clockIncrement : kotlin.Int = 56 // kotlin.Int | Clock increment in seconds
val nbRounds : kotlin.Int = 56 // kotlin.Int | Maximum number of rounds to play
val name : kotlin.String = name_example // kotlin.String | The tournament name. Leave empty to get a random Grandmaster name
val startsAt : kotlin.Int = 56 // kotlin.Int | Timestamp in milliseconds to start the tournament at a given date and time. By default, it starts 10 minutes after creation.
val roundInterval : kotlin.Int = 56 // kotlin.Int | How long to wait between each round, in seconds.  Set to 99999999 to manually schedule each round from the tournament UI. 
val variant : VariantKey =  // VariantKey | 
val description : kotlin.String = description_example // kotlin.String | Anything you want to tell players about the tournament
val rated : kotlin.Boolean = true // kotlin.Boolean | Games are rated and impact players ratings
val chatFor : java.math.BigDecimal = 8.14 // java.math.BigDecimal | Who can read and write in the chat. - 0  = No-one - 10 = Only team leaders - 20 = Only team members - 30 = All Lichess players 
try {
    val result : kotlin.Any = apiInstance.apiSwissUpdate(id, clockLimit, clockIncrement, nbRounds, name, startsAt, roundInterval, variant, description, rated, chatFor)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling SwissTournamentsApi#apiSwissUpdate")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling SwissTournamentsApi#apiSwissUpdate")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **kotlin.String**| The tournament ID. |
 **clockLimit** | **java.math.BigDecimal**| Clock initial time in seconds |
 **clockIncrement** | **kotlin.Int**| Clock increment in seconds |
 **nbRounds** | **kotlin.Int**| Maximum number of rounds to play | [default to 8]
 **name** | **kotlin.String**| The tournament name. Leave empty to get a random Grandmaster name | [optional]
 **startsAt** | **kotlin.Int**| Timestamp in milliseconds to start the tournament at a given date and time. By default, it starts 10 minutes after creation. | [optional]
 **roundInterval** | **kotlin.Int**| How long to wait between each round, in seconds.  Set to 99999999 to manually schedule each round from the tournament UI.  | [optional]
 **variant** | [**VariantKey**](VariantKey.md)|  | [optional] [default to VariantKey.standard] [enum: standard, chess960, crazyhouse, antichess, atomic, horde, kingOfTheHill, racingKings, threeCheck]
 **description** | **kotlin.String**| Anything you want to tell players about the tournament | [optional]
 **rated** | **kotlin.Boolean**| Games are rated and impact players ratings | [optional] [default to true]
 **chatFor** | **java.math.BigDecimal**| Who can read and write in the chat. - 0  &#x3D; No-one - 10 &#x3D; Only team leaders - 20 &#x3D; Only team members - 30 &#x3D; All Lichess players  | [optional] [default to 20]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

<a name="apiTeamSwiss"></a>
# **apiTeamSwiss**
> kotlin.collections.List&lt;kotlin.Any&gt; apiTeamSwiss(teamId, max)

Get team swiss tournaments

Get all swiss tournaments of a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = SwissTournamentsApi()
val teamId : kotlin.String = coders // kotlin.String | 
val max : kotlin.Int = 56 // kotlin.Int | How many tournaments to download.
try {
    val result : kotlin.collections.List<kotlin.Any> = apiInstance.apiTeamSwiss(teamId, max)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling SwissTournamentsApi#apiTeamSwiss")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling SwissTournamentsApi#apiTeamSwiss")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | **kotlin.String**|  |
 **max** | **kotlin.Int**| How many tournaments to download. | [optional] [default to 100]

### Return type

[**kotlin.collections.List&lt;kotlin.Any&gt;**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="gamesBySwiss"></a>
# **gamesBySwiss**
> kotlin.Any gamesBySwiss(id, moves, pgnInJson, tags, clocks, evals, opening)

Export games of a Swiss tournament

Download games of a swiss tournament in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (last round first) 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = SwissTournamentsApi()
val id : kotlin.String = id_example // kotlin.String | The tournament ID.
val moves : kotlin.Boolean = true // kotlin.Boolean | Include the PGN moves.
val pgnInJson : kotlin.Boolean = true // kotlin.Boolean | Include the full PGN within the JSON response, in a `pgn` field.
val tags : kotlin.Boolean = true // kotlin.Boolean | Include the PGN tags.
val clocks : kotlin.Boolean = true // kotlin.Boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }` 
val evals : kotlin.Boolean = true // kotlin.Boolean | Include analysis evaluation comments in the PGN, when available.  Example: `12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }` 
val opening : kotlin.Boolean = true // kotlin.Boolean | Include the opening name.  Example: `[Opening \"King's Gambit Accepted, King's Knight Gambit\"]` 
try {
    val result : kotlin.Any = apiInstance.gamesBySwiss(id, moves, pgnInJson, tags, clocks, evals, opening)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling SwissTournamentsApi#gamesBySwiss")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling SwissTournamentsApi#gamesBySwiss")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **kotlin.String**| The tournament ID. |
 **moves** | **kotlin.Boolean**| Include the PGN moves. | [optional] [default to true]
 **pgnInJson** | **kotlin.Boolean**| Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. | [optional] [default to false]
 **tags** | **kotlin.Boolean**| Include the PGN tags. | [optional] [default to true]
 **clocks** | **kotlin.Boolean**| Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | [optional] [default to false]
 **evals** | **kotlin.Boolean**| Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  | [optional] [default to false]
 **opening** | **kotlin.Boolean**| Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  | [optional] [default to false]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn, application/x-ndjson

<a name="resultsBySwiss"></a>
# **resultsBySwiss**
> kotlin.Any resultsBySwiss(id, nb)

Get results of a swiss tournament

Players of a swiss tournament, with their score and performance, sorted by rank (best first).  Players are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  If called on an ongoing tournament, results can be inconsistent due to ranking changes while the players are being streamed. Use on finished tournaments for guaranteed consistency. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = SwissTournamentsApi()
val id : kotlin.String = id_example // kotlin.String | The tournament ID.
val nb : kotlin.Int = 56 // kotlin.Int | Max number of players to fetch
try {
    val result : kotlin.Any = apiInstance.resultsBySwiss(id, nb)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling SwissTournamentsApi#resultsBySwiss")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling SwissTournamentsApi#resultsBySwiss")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **kotlin.String**| The tournament ID. |
 **nb** | **kotlin.Int**| Max number of players to fetch | [optional]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

<a name="swissTrf"></a>
# **swissTrf**
> kotlin.String swissTrf(id)

Export TRF of a Swiss tournament

Download a tournament in the Tournament Report File format, the FIDE standard.  Documentation: &lt;https://www.fide.com/FIDE/handbook/C04Annex2_TRF16.pdf&gt;  Example: &lt;https://lichess.org/swiss/j8rtJ5GL.trf&gt; 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = SwissTournamentsApi()
val id : kotlin.String = id_example // kotlin.String | The tournament ID.
try {
    val result : kotlin.String = apiInstance.swissTrf(id)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling SwissTournamentsApi#swissTrf")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling SwissTournamentsApi#swissTrf")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **kotlin.String**| The tournament ID. |

### Return type

**kotlin.String**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: text/plain

