# TVApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**tvChannelGames**](TVApi.md#tvChannelGames) | **GET** /api/tv/{channel} | Get best ongoing games of a TV channel
[**tvChannels**](TVApi.md#tvChannels) | **GET** /api/tv/channels | Get current TV games
[**tvFeed**](TVApi.md#tvFeed) | **GET** /api/tv/feed | Stream current TV game


<a name="tvChannelGames"></a>
# **tvChannelGames**
> kotlin.Any tvChannelGames(channel, nb, moves, pgnInJson, tags, clocks, opening)

Get best ongoing games of a TV channel

Get a list of ongoing games for a given TV channel. Similar to [lichess.org/games](https://lichess.org/games).  Available in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format, depending on the request Accept header. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = TVApi()
val channel : kotlin.String = channel_example // kotlin.String | The name of the channel in lowercase.
val nb : java.math.BigDecimal = 8.14 // java.math.BigDecimal | Number of games to fetch.
val moves : kotlin.Boolean = true // kotlin.Boolean | Include the PGN moves.
val pgnInJson : kotlin.Boolean = true // kotlin.Boolean | Include the full PGN within the JSON response, in a `pgn` field.
val tags : kotlin.Boolean = true // kotlin.Boolean | Include the PGN tags.
val clocks : kotlin.Boolean = true // kotlin.Boolean | Include clock comments in the PGN moves, when available.  Example: `2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }` 
val opening : kotlin.Boolean = true // kotlin.Boolean | Include the opening name.  Example: `[Opening \"King's Gambit Accepted, King's Knight Gambit\"]` 
try {
    val result : kotlin.Any = apiInstance.tvChannelGames(channel, nb, moves, pgnInJson, tags, clocks, opening)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling TVApi#tvChannelGames")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling TVApi#tvChannelGames")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **channel** | **kotlin.String**| The name of the channel in lowercase. |
 **nb** | **java.math.BigDecimal**| Number of games to fetch. | [optional] [default to 10]
 **moves** | **kotlin.Boolean**| Include the PGN moves. | [optional] [default to true]
 **pgnInJson** | **kotlin.Boolean**| Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. | [optional] [default to false]
 **tags** | **kotlin.Boolean**| Include the PGN tags. | [optional] [default to true]
 **clocks** | **kotlin.Boolean**| Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  | [optional] [default to false]
 **opening** | **kotlin.Boolean**| Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  | [optional] [default to false]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-chess-pgn, application/x-ndjson

<a name="tvChannels"></a>
# **tvChannels**
> kotlin.Any tvChannels()

Get current TV games

Get basic info about the best games being played for each speed and variant, but also computer games and bot games.  See [lichess.org/tv](https://lichess.org/tv). 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = TVApi()
try {
    val result : kotlin.Any = apiInstance.tvChannels()
    println(result)
} catch (e: ClientException) {
    println("4xx response calling TVApi#tvChannels")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling TVApi#tvChannels")
    e.printStackTrace()
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="tvFeed"></a>
# **tvFeed**
> kotlin.Any tvFeed()

Stream current TV game

Stream positions and moves of the current [TV game](https://lichess.org/tv) in [ndjson](#section/Introduction/Streaming-with-ND-JSON). A summary of the game is sent as a first message, and when the featured game changes.  Try it with &#x60;curl https://lichess.org/api/tv/feed&#x60;. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = TVApi()
try {
    val result : kotlin.Any = apiInstance.tvFeed()
    println(result)
} catch (e: ClientException) {
    println("4xx response calling TVApi#tvFeed")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling TVApi#tvFeed")
    e.printStackTrace()
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

