# TeamsApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiTeamArena**](TeamsApi.md#apiTeamArena) | **GET** /api/team/{teamId}/arena | Get team Arena tournaments
[**apiTeamSwiss**](TeamsApi.md#apiTeamSwiss) | **GET** /api/team/{teamId}/swiss | Get team swiss tournaments
[**teamAll**](TeamsApi.md#teamAll) | **GET** /api/team/all | Get popular teams
[**teamIdJoin**](TeamsApi.md#teamIdJoin) | **POST** /team/{teamId}/join | Join a team
[**teamIdKickUserId**](TeamsApi.md#teamIdKickUserId) | **POST** /team/{teamId}/kick/{userId} | Kick a user from your team
[**teamIdPmAll**](TeamsApi.md#teamIdPmAll) | **POST** /team/{teamId}/pm-all | Message all members
[**teamIdQuit**](TeamsApi.md#teamIdQuit) | **POST** /team/{teamId}/quit | Leave a team
[**teamIdUsers**](TeamsApi.md#teamIdUsers) | **GET** /api/team/{teamId}/users | Get members of a team
[**teamOfUsername**](TeamsApi.md#teamOfUsername) | **GET** /api/team/of/{username} | Teams of a player
[**teamSearch**](TeamsApi.md#teamSearch) | **GET** /api/team/search | Search teams
[**teamShow**](TeamsApi.md#teamShow) | **GET** /api/team/{teamId} | Get a single team


<a name="apiTeamArena"></a>
# **apiTeamArena**
> kotlin.collections.List&lt;kotlin.Any&gt; apiTeamArena(teamId, max)

Get team Arena tournaments

Get all Arena tournaments relevant to a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = TeamsApi()
val teamId : kotlin.String = teamId_example // kotlin.String | ID of the team
val max : kotlin.Int = 56 // kotlin.Int | How many tournaments to download.
try {
    val result : kotlin.collections.List<kotlin.Any> = apiInstance.apiTeamArena(teamId, max)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling TeamsApi#apiTeamArena")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling TeamsApi#apiTeamArena")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | **kotlin.String**| ID of the team |
 **max** | **kotlin.Int**| How many tournaments to download. | [optional] [default to 100]

### Return type

[**kotlin.collections.List&lt;kotlin.Any&gt;**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="apiTeamSwiss"></a>
# **apiTeamSwiss**
> kotlin.collections.List&lt;kotlin.Any&gt; apiTeamSwiss(teamId, max)

Get team swiss tournaments

Get all swiss tournaments of a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = TeamsApi()
val teamId : kotlin.String = coders // kotlin.String | 
val max : kotlin.Int = 56 // kotlin.Int | How many tournaments to download.
try {
    val result : kotlin.collections.List<kotlin.Any> = apiInstance.apiTeamSwiss(teamId, max)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling TeamsApi#apiTeamSwiss")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling TeamsApi#apiTeamSwiss")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | **kotlin.String**|  |
 **max** | **kotlin.Int**| How many tournaments to download. | [optional] [default to 100]

### Return type

[**kotlin.collections.List&lt;kotlin.Any&gt;**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="teamAll"></a>
# **teamAll**
> InlineResponse2001 teamAll(page)

Get popular teams

Paginator of the most popular teams. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = TeamsApi()
val page : java.math.BigDecimal = 1 // java.math.BigDecimal | 
try {
    val result : InlineResponse2001 = apiInstance.teamAll(page)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling TeamsApi#teamAll")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling TeamsApi#teamAll")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **page** | **java.math.BigDecimal**|  | [optional] [default to 1]

### Return type

[**InlineResponse2001**](InlineResponse2001.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="teamIdJoin"></a>
# **teamIdJoin**
> Ok teamIdJoin(teamId, message, password)

Join a team

Join a team. If the team requires a password but the &#x60;password&#x60; field is incorrect, then the call fails with &#x60;403 Forbidden&#x60;. Similarly, if the team join policy requires a confirmation but the &#x60;message&#x60; parameter is not given, then the call fails with &#x60;403 Forbidden&#x60;. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = TeamsApi()
val teamId : kotlin.String = coders // kotlin.String | 
val message : kotlin.String = message_example // kotlin.String | Optional request message, if the team requires one.
val password : kotlin.String = password_example // kotlin.String | Optional password, if the team requires one.
try {
    val result : Ok = apiInstance.teamIdJoin(teamId, message, password)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling TeamsApi#teamIdJoin")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling TeamsApi#teamIdJoin")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | **kotlin.String**|  |
 **message** | **kotlin.String**| Optional request message, if the team requires one. | [optional]
 **password** | **kotlin.String**| Optional password, if the team requires one. | [optional]

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

<a name="teamIdKickUserId"></a>
# **teamIdKickUserId**
> Ok teamIdKickUserId(teamId, userId)

Kick a user from your team

Kick a member out of one of your teams. - &lt;https://lichess.org/team&gt; 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = TeamsApi()
val teamId : kotlin.String = coders // kotlin.String | 
val userId : kotlin.String = neio // kotlin.String | 
try {
    val result : Ok = apiInstance.teamIdKickUserId(teamId, userId)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling TeamsApi#teamIdKickUserId")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling TeamsApi#teamIdKickUserId")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | **kotlin.String**|  |
 **userId** | **kotlin.String**|  |

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="teamIdPmAll"></a>
# **teamIdPmAll**
> Ok teamIdPmAll(teamId, message)

Message all members

Send a private message to all members of a team. You must own the team. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = TeamsApi()
val teamId : kotlin.String = coders // kotlin.String | 
val message : kotlin.String = message_example // kotlin.String | The message to send to all your team members.
try {
    val result : Ok = apiInstance.teamIdPmAll(teamId, message)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling TeamsApi#teamIdPmAll")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling TeamsApi#teamIdPmAll")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | **kotlin.String**|  |
 **message** | **kotlin.String**| The message to send to all your team members. | [optional]

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: application/x-www-form-urlencoded
 - **Accept**: application/json

<a name="teamIdQuit"></a>
# **teamIdQuit**
> Ok teamIdQuit(teamId)

Leave a team

Leave a team. - &lt;https://lichess.org/team&gt; 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = TeamsApi()
val teamId : kotlin.String = coders // kotlin.String | 
try {
    val result : Ok = apiInstance.teamIdQuit(teamId)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling TeamsApi#teamIdQuit")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling TeamsApi#teamIdQuit")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | **kotlin.String**|  |

### Return type

[**Ok**](Ok.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="teamIdUsers"></a>
# **teamIdUsers**
> UserExtended teamIdUsers(teamId)

Get members of a team

Members are sorted by reverse chronological order of joining the team (most recent first). OAuth only required if the list of members is private.  Members are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = TeamsApi()
val teamId : kotlin.String = coders // kotlin.String | 
try {
    val result : UserExtended = apiInstance.teamIdUsers(teamId)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling TeamsApi#teamIdUsers")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling TeamsApi#teamIdUsers")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | **kotlin.String**|  |

### Return type

[**UserExtended**](UserExtended.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

<a name="teamOfUsername"></a>
# **teamOfUsername**
> kotlin.collections.List&lt;Team&gt; teamOfUsername(username)

Teams of a player

All the teams a player is a member of. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = TeamsApi()
val username : kotlin.String = thibault // kotlin.String | 
try {
    val result : kotlin.collections.List<Team> = apiInstance.teamOfUsername(username)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling TeamsApi#teamOfUsername")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling TeamsApi#teamOfUsername")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **kotlin.String**|  |

### Return type

[**kotlin.collections.List&lt;Team&gt;**](Team.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="teamSearch"></a>
# **teamSearch**
> kotlin.collections.List&lt;Team&gt; teamSearch(text, page)

Search teams

Paginator of team search results for a keyword. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = TeamsApi()
val text : kotlin.String = coders // kotlin.String | 
val page : java.math.BigDecimal = 1 // java.math.BigDecimal | 
try {
    val result : kotlin.collections.List<Team> = apiInstance.teamSearch(text, page)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling TeamsApi#teamSearch")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling TeamsApi#teamSearch")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **text** | **kotlin.String**|  | [optional]
 **page** | **java.math.BigDecimal**|  | [optional] [default to 1]

### Return type

[**kotlin.collections.List&lt;Team&gt;**](Team.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="teamShow"></a>
# **teamShow**
> Team teamShow(teamId)

Get a single team

Infos about a team

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = TeamsApi()
val teamId : kotlin.String = teamId_example // kotlin.String | 
try {
    val result : Team = apiInstance.teamShow(teamId)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling TeamsApi#teamShow")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling TeamsApi#teamShow")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | **kotlin.String**|  |

### Return type

[**Team**](Team.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

