# UsersApi

All URIs are relative to *https://lichess.org*

Method | HTTP request | Description
------------- | ------------- | -------------
[**apiCrosstable**](UsersApi.md#apiCrosstable) | **GET** /api/crosstable/{user1}/{user2} | Get crosstable
[**apiUser**](UsersApi.md#apiUser) | **GET** /api/user/{username} | Get user public data
[**apiUserActivity**](UsersApi.md#apiUserActivity) | **GET** /api/user/{username}/activity | Get user activity
[**apiUserPerf**](UsersApi.md#apiUserPerf) | **GET** /api/user/{username}/perf/{perf} | Get performance statistics of a user
[**apiUserRatingHistory**](UsersApi.md#apiUserRatingHistory) | **GET** /api/user/{username}/rating-history | Get rating history of a user
[**apiUsers**](UsersApi.md#apiUsers) | **POST** /api/users | Get users by ID
[**apiUsersStatus**](UsersApi.md#apiUsersStatus) | **GET** /api/users/status | Get real-time users status
[**player**](UsersApi.md#player) | **GET** /player | Get all top 10
[**playerTopNbPerfType**](UsersApi.md#playerTopNbPerfType) | **GET** /player/top/{nb}/{perfType} | Get one leaderboard
[**streamerLive**](UsersApi.md#streamerLive) | **GET** /streamer/live | Get live streamers
[**teamIdUsers**](UsersApi.md#teamIdUsers) | **GET** /api/team/{teamId}/users | Get members of a team


<a name="apiCrosstable"></a>
# **apiCrosstable**
> kotlin.Any apiCrosstable(user1, user2, matchup)

Get crosstable

Get total number of games, and current score, of any two users.  If the &#x60;matchup&#x60; flag is provided, and the users are currently playing, also gets the current match game number and scores. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = UsersApi()
val user1 : kotlin.String = user1_example // kotlin.String | 
val user2 : kotlin.String = user2_example // kotlin.String | 
val matchup : kotlin.Boolean = true // kotlin.Boolean | Whether to get the current match data, if any
try {
    val result : kotlin.Any = apiInstance.apiCrosstable(user1, user2, matchup)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling UsersApi#apiCrosstable")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling UsersApi#apiCrosstable")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **user1** | **kotlin.String**|  |
 **user2** | **kotlin.String**|  |
 **matchup** | **kotlin.Boolean**| Whether to get the current match data, if any | [optional]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="apiUser"></a>
# **apiUser**
> UserExtended apiUser(username)

Get user public data

Read public data of a user. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = UsersApi()
val username : kotlin.String = username_example // kotlin.String | 
try {
    val result : UserExtended = apiInstance.apiUser(username)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling UsersApi#apiUser")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling UsersApi#apiUser")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **kotlin.String**|  |

### Return type

[**UserExtended**](UserExtended.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="apiUserActivity"></a>
# **apiUserActivity**
> apiUserActivity(username)

Get user activity

Read data to generate the activity feed of a user. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = UsersApi()
val username : kotlin.String = username_example // kotlin.String | 
try {
    apiInstance.apiUserActivity(username)
} catch (e: ClientException) {
    println("4xx response calling UsersApi#apiUserActivity")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling UsersApi#apiUserActivity")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **kotlin.String**|  |

### Return type

null (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="apiUserPerf"></a>
# **apiUserPerf**
> kotlin.Any apiUserPerf(username, perf)

Get performance statistics of a user

Read performance statistics of a user, for a single performance. Similar to the [performance pages on the website](https://lichess.org/@/thibault/perf/bullet). 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = UsersApi()
val username : kotlin.String = username_example // kotlin.String | 
val perf : PerfType =  // PerfType | 
try {
    val result : kotlin.Any = apiInstance.apiUserPerf(username, perf)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling UsersApi#apiUserPerf")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling UsersApi#apiUserPerf")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **kotlin.String**|  |
 **perf** | [**PerfType**](.md)|  | [enum: ultraBullet, bullet, blitz, rapid, classical, correspondence, chess960, crazyhouse, antichess, atomic, horde, kingOfTheHill, racingKings, threeCheck]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="apiUserRatingHistory"></a>
# **apiUserRatingHistory**
> kotlin.Any apiUserRatingHistory(username)

Get rating history of a user

Read rating history of a user, for all perf types. There is at most one entry per day. Format of an entry is &#x60;[year, month, day, rating]&#x60;. &#x60;month&#x60; starts at zero (January). 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = UsersApi()
val username : kotlin.String = username_example // kotlin.String | 
try {
    val result : kotlin.Any = apiInstance.apiUserRatingHistory(username)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling UsersApi#apiUserRatingHistory")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling UsersApi#apiUserRatingHistory")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **username** | **kotlin.String**|  |

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="apiUsers"></a>
# **apiUsers**
> kotlin.collections.List&lt;User&gt; apiUsers(body)

Get users by ID

Get up to 300 users by their IDs. Users are returned in the same order as the IDs.  The method is &#x60;POST&#x60; so a longer list of IDs can be sent in the request body. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = UsersApi()
val body : kotlin.String = aliquantus,chess-network,lovlas // kotlin.String | User IDs separated by commas.
try {
    val result : kotlin.collections.List<User> = apiInstance.apiUsers(body)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling UsersApi#apiUsers")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling UsersApi#apiUsers")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | **kotlin.String**| User IDs separated by commas. |

### Return type

[**kotlin.collections.List&lt;User&gt;**](User.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: text/plain
 - **Accept**: application/json

<a name="apiUsersStatus"></a>
# **apiUsersStatus**
> kotlin.collections.List&lt;InlineResponse200&gt; apiUsersStatus(ids)

Get real-time users status

Read the &#x60;online&#x60;, &#x60;playing&#x60; and &#x60;streaming&#x60; flags of several users.  This API is very fast and cheap on lichess side. So you can call it quite often (like once every 5 seconds).  Use it to track players and know when they&#39;re connected on lichess and playing games. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = UsersApi()
val ids : kotlin.String = aliquantus,chess-network,lovlas // kotlin.String | User IDs separated by commas. Up to 100 IDs.
try {
    val result : kotlin.collections.List<InlineResponse200> = apiInstance.apiUsersStatus(ids)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling UsersApi#apiUsersStatus")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling UsersApi#apiUsersStatus")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **ids** | **kotlin.String**| User IDs separated by commas. Up to 100 IDs. |

### Return type

[**kotlin.collections.List&lt;InlineResponse200&gt;**](InlineResponse200.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="player"></a>
# **player**
> kotlin.Any player()

Get all top 10

Get the top 10 players for each speed and variant.  See &lt;https://lichess.org/player&gt;. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = UsersApi()
try {
    val result : kotlin.Any = apiInstance.player()
    println(result)
} catch (e: ClientException) {
    println("4xx response calling UsersApi#player")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling UsersApi#player")
    e.printStackTrace()
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/vnd.lichess.v3+json

<a name="playerTopNbPerfType"></a>
# **playerTopNbPerfType**
> kotlin.Any playerTopNbPerfType(nb, perfType)

Get one leaderboard

Get the leaderboard for a single speed or variant (a.k.a. &#x60;perfType&#x60;). There is no leaderboard for correspondence or puzzles.  See &lt;https://lichess.org/player/top/200/bullet&gt;. 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = UsersApi()
val nb : kotlin.Int = 100 // kotlin.Int | How many users to fetch
val perfType : kotlin.String = bullet // kotlin.String | The speed or variant
try {
    val result : kotlin.Any = apiInstance.playerTopNbPerfType(nb, perfType)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling UsersApi#playerTopNbPerfType")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling UsersApi#playerTopNbPerfType")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **nb** | **kotlin.Int**| How many users to fetch |
 **perfType** | **kotlin.String**| The speed or variant | [enum: ultraBullet, bullet, blitz, rapid, classical, chess960, crazyhouse, antichess, atomic, horde, kingOfTheHill, racingKings, threeCheck]

### Return type

[**kotlin.Any**](kotlin.Any.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/vnd.lichess.v3+json

<a name="streamerLive"></a>
# **streamerLive**
> kotlin.collections.List&lt;InlineResponse2002&gt; streamerLive()

Get live streamers

Get basic info about currently streaming users.  This API is very fast and cheap on lichess side. So you can call it quite often (like once every 5 seconds). 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = UsersApi()
try {
    val result : kotlin.collections.List<InlineResponse2002> = apiInstance.streamerLive()
    println(result)
} catch (e: ClientException) {
    println("4xx response calling UsersApi#streamerLive")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling UsersApi#streamerLive")
    e.printStackTrace()
}
```

### Parameters
This endpoint does not need any parameter.

### Return type

[**kotlin.collections.List&lt;InlineResponse2002&gt;**](InlineResponse2002.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="teamIdUsers"></a>
# **teamIdUsers**
> UserExtended teamIdUsers(teamId)

Get members of a team

Members are sorted by reverse chronological order of joining the team (most recent first). OAuth only required if the list of members is private.  Members are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 

### Example
```kotlin
// Import classes:
//import org.openapitools.client.infrastructure.*
//import org.openapitools.client.models.*

val apiInstance = UsersApi()
val teamId : kotlin.String = coders // kotlin.String | 
try {
    val result : UserExtended = apiInstance.teamIdUsers(teamId)
    println(result)
} catch (e: ClientException) {
    println("4xx response calling UsersApi#teamIdUsers")
    e.printStackTrace()
} catch (e: ServerException) {
    println("5xx response calling UsersApi#teamIdUsers")
    e.printStackTrace()
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **teamId** | **kotlin.String**|  |

### Return type

[**UserExtended**](UserExtended.md)

### Authorization


Configure OAuth2:
    ApiClient.accessToken = ""

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/x-ndjson

