/**
 * Lichess.org API reference
 *
 * # Introduction Welcome to the reference for the Lichess API! Lichess is free/libre, open-source chess server powered by volunteers and donations. - Get help in the [Lichess Discord channel](https://discord.gg/lichess) - [Contribute to this documentation on Github](https://github.com/lichess-org/api) - Check out [Lichess widgets to embed in your website](https://lichess.org/developers) - [Download all Lichess rated games](https://database.lichess.org/) - [Download all Lichess puzzles with themes, ratings and votes](https://database.lichess.org/#puzzles)  ## Endpoint All requests go to `https://lichess.org` (unless otherwise specified).  ## Clients - [Python general API](https://github.com/ZackClements/berserk) - [MicroPython general API](https://github.com/mkomon/uberserk) - [Python general API - async](https://pypi.org/project/async-lichess-sdk) - [Python Lichess Bot](https://github.com/careless25/lichess-bot) - [Python Board API for Certabo](https://github.com/haklein/certabo-lichess) - [Java general API](https://github.com/tors42/chariot)  ## Rate limiting All requests are rate limited using various strategies, to ensure the API remains responsive for everyone. Only make one request at a time. If you receive an HTTP response with a [429 status](https://en.wikipedia.org/wiki/List_of_HTTP_status_codes#429), please wait a full minute before resuming API usage.  ## Streaming with ND-JSON Some API endpoints stream their responses as [Newline Delimited JSON a.k.a. **nd-json**](http://ndjson.org/), with one JSON object per line.  Here's a [JavaScript utility function](https://gist.github.com/ornicar/a097406810939cf7be1df8ea30e94f3e) to help reading NDJSON streamed responses. 
 *
 * The version of the OpenAPI document: 2.0.0
 * 
 *
 * Please note:
 * This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * Do not edit this file manually.
 */

@file:Suppress(
    "ArrayInDataClass",
    "EnumEntryName",
    "RemoveRedundantQualifierName",
    "UnusedImport"
)

package org.openapitools.client.apis

import org.openapitools.client.models.ArenaTournaments
import org.openapitools.client.models.Error
import org.openapitools.client.models.Ok
import org.openapitools.client.models.VariantKey

import org.openapitools.client.infrastructure.ApiClient
import org.openapitools.client.infrastructure.ClientException
import org.openapitools.client.infrastructure.ClientError
import org.openapitools.client.infrastructure.ServerException
import org.openapitools.client.infrastructure.ServerError
import org.openapitools.client.infrastructure.MultiValueMap
import org.openapitools.client.infrastructure.RequestConfig
import org.openapitools.client.infrastructure.RequestMethod
import org.openapitools.client.infrastructure.ResponseType
import org.openapitools.client.infrastructure.Success
import org.openapitools.client.infrastructure.toMultiValue

class ArenaTournamentsApi(basePath: kotlin.String = defaultBasePath) : ApiClient(basePath) {
    companion object {
        @JvmStatic
        val defaultBasePath: String by lazy {
            System.getProperties().getProperty("org.openapitools.client.baseUrl", "https://lichess.org")
        }
    }

    /**
    * Get team Arena tournaments
    * Get all Arena tournaments relevant to a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
    * @param teamId ID of the team 
    * @param max How many tournaments to download. (optional, default to 100)
    * @return kotlin.collections.List<kotlin.Any>
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun apiTeamArena(teamId: kotlin.String, max: kotlin.Int?) : kotlin.collections.List<kotlin.Any> {
        val localVariableConfig = apiTeamArenaRequestConfig(teamId = teamId, max = max)

        val localVarResponse = request<Unit, kotlin.collections.List<kotlin.Any>>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.collections.List<kotlin.Any>
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation apiTeamArena
    *
    * @param teamId ID of the team 
    * @param max How many tournaments to download. (optional, default to 100)
    * @return RequestConfig
    */
    fun apiTeamArenaRequestConfig(teamId: kotlin.String, max: kotlin.Int?) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf<kotlin.String, List<kotlin.String>>()
            .apply {
                if (max != null) {
                    put("max", listOf(max.toString()))
                }
            }
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/api/team/{teamId}/arena".replace("{"+"teamId"+"}", "$teamId"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Get current tournaments
    * Get recently finished, ongoing, and upcoming tournaments.  This API is used to display the [Lichess tournament schedule](https://lichess.org/tournament). 
    * @return ArenaTournaments
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun apiTournament() : ArenaTournaments {
        val localVariableConfig = apiTournamentRequestConfig()

        val localVarResponse = request<Unit, ArenaTournaments>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as ArenaTournaments
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation apiTournament
    *
    * @return RequestConfig
    */
    fun apiTournamentRequestConfig() : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/api/tournament",
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Join an Arena tournament
    * Join an Arena tournament, possibly with a password and/or a team. 
    * @param id The tournament ID. 
    * @param password The tournament password, if one is required (optional)
    * @param team The team to join the tournament with, for team battle tournaments (optional)
    * @return Ok
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun apiTournamentJoin(id: kotlin.String, password: kotlin.String?, team: kotlin.String?) : Ok {
        val localVariableConfig = apiTournamentJoinRequestConfig(id = id, password = password, team = team)

        val localVarResponse = request<Map<String, Any?>, Ok>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as Ok
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation apiTournamentJoin
    *
    * @param id The tournament ID. 
    * @param password The tournament password, if one is required (optional)
    * @param team The team to join the tournament with, for team battle tournaments (optional)
    * @return RequestConfig
    */
    fun apiTournamentJoinRequestConfig(id: kotlin.String, password: kotlin.String?, team: kotlin.String?) : RequestConfig<Map<String, Any?>> {
        val localVariableBody = mapOf("password" to password, "team" to team)
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf("Content-Type" to "application/x-www-form-urlencoded")

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/tournament/{id}/join".replace("{"+"id"+"}", "$id"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Create a new Arena tournament
    * Create a public or private Arena tournament.  This endpoint mirrors the form on &lt;https://lichess.org/tournament/new&gt;.  You can create up to 12 public tournaments per day, or 24 private tournaments.  A team battle can be created by specifying the &#x60;teambBattleByTeam&#x60; argument. 
    * @param clockTime Clock initial time in minutes 
    * @param clockIncrement Clock increment in seconds 
    * @param minutes How long the tournament lasts, in minutes 
    * @param name The tournament name. Leave empty to get a random Grandmaster name (optional)
    * @param waitMinutes How long to wait before starting the tournament, from now, in minutes (optional, default to 5)
    * @param startDate Timestamp to start the tournament at a given date and time. Overrides the &#x60;waitMinutes&#x60; setting (optional)
    * @param variant  (optional, default to standard)
    * @param rated Games are rated and impact players ratings (optional, default to true)
    * @param position Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960). (optional)
    * @param berserkable Whether the players can use berserk (optional, default to true)
    * @param streakable After 2 wins, consecutive wins grant 4 points instead of 2. (optional, default to true)
    * @param hasChat Whether the players can discuss in a chat (optional, default to true)
    * @param description Anything you want to tell players about the tournament (optional)
    * @param password Make the tournament private, and restrict access with a password (optional)
    * @param teambBattleByTeam Set the ID of a team you lead to create a team battle. The other teams can be added using the [team battle edit endpoint](#operation/apiTournamentTeamBattlePost).  (optional)
    * @param conditionsTeamMemberTeamId Restrict entry to members of a team.  The teamId is the last part of a team URL, e.g. &#x60;https://lichess.org/team/coders&#x60; has teamId &#x3D; &#x60;coders&#x60;.  Leave empty to let everyone join the tournament.  Do not use this to create team battles, use &#x60;teamBattleByTeam&#x60; instead.  (optional)
    * @param conditionsMinRatingRating Minimum rating to join. Leave empty to let everyone join the tournament. (optional)
    * @param conditionsMaxRatingRating Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament. (optional)
    * @param conditionsNbRatedGameNb Minimum number of rated games required to join. (optional)
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun apiTournamentPost(clockTime: java.math.BigDecimal, clockIncrement: kotlin.Int, minutes: kotlin.Int, name: kotlin.String?, waitMinutes: kotlin.Int?, startDate: kotlin.Int?, variant: VariantKey?, rated: kotlin.Boolean?, position: kotlin.String?, berserkable: kotlin.Boolean?, streakable: kotlin.Boolean?, hasChat: kotlin.Boolean?, description: kotlin.String?, password: kotlin.String?, teambBattleByTeam: kotlin.String?, conditionsTeamMemberTeamId: kotlin.String?, conditionsMinRatingRating: kotlin.Int?, conditionsMaxRatingRating: kotlin.Int?, conditionsNbRatedGameNb: kotlin.Int?) : kotlin.Any {
        val localVariableConfig = apiTournamentPostRequestConfig(clockTime = clockTime, clockIncrement = clockIncrement, minutes = minutes, name = name, waitMinutes = waitMinutes, startDate = startDate, variant = variant, rated = rated, position = position, berserkable = berserkable, streakable = streakable, hasChat = hasChat, description = description, password = password, teambBattleByTeam = teambBattleByTeam, conditionsTeamMemberTeamId = conditionsTeamMemberTeamId, conditionsMinRatingRating = conditionsMinRatingRating, conditionsMaxRatingRating = conditionsMaxRatingRating, conditionsNbRatedGameNb = conditionsNbRatedGameNb)

        val localVarResponse = request<Map<String, Any?>, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation apiTournamentPost
    *
    * @param clockTime Clock initial time in minutes 
    * @param clockIncrement Clock increment in seconds 
    * @param minutes How long the tournament lasts, in minutes 
    * @param name The tournament name. Leave empty to get a random Grandmaster name (optional)
    * @param waitMinutes How long to wait before starting the tournament, from now, in minutes (optional, default to 5)
    * @param startDate Timestamp to start the tournament at a given date and time. Overrides the &#x60;waitMinutes&#x60; setting (optional)
    * @param variant  (optional, default to standard)
    * @param rated Games are rated and impact players ratings (optional, default to true)
    * @param position Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960). (optional)
    * @param berserkable Whether the players can use berserk (optional, default to true)
    * @param streakable After 2 wins, consecutive wins grant 4 points instead of 2. (optional, default to true)
    * @param hasChat Whether the players can discuss in a chat (optional, default to true)
    * @param description Anything you want to tell players about the tournament (optional)
    * @param password Make the tournament private, and restrict access with a password (optional)
    * @param teambBattleByTeam Set the ID of a team you lead to create a team battle. The other teams can be added using the [team battle edit endpoint](#operation/apiTournamentTeamBattlePost).  (optional)
    * @param conditionsTeamMemberTeamId Restrict entry to members of a team.  The teamId is the last part of a team URL, e.g. &#x60;https://lichess.org/team/coders&#x60; has teamId &#x3D; &#x60;coders&#x60;.  Leave empty to let everyone join the tournament.  Do not use this to create team battles, use &#x60;teamBattleByTeam&#x60; instead.  (optional)
    * @param conditionsMinRatingRating Minimum rating to join. Leave empty to let everyone join the tournament. (optional)
    * @param conditionsMaxRatingRating Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament. (optional)
    * @param conditionsNbRatedGameNb Minimum number of rated games required to join. (optional)
    * @return RequestConfig
    */
    fun apiTournamentPostRequestConfig(clockTime: java.math.BigDecimal, clockIncrement: kotlin.Int, minutes: kotlin.Int, name: kotlin.String?, waitMinutes: kotlin.Int?, startDate: kotlin.Int?, variant: VariantKey?, rated: kotlin.Boolean?, position: kotlin.String?, berserkable: kotlin.Boolean?, streakable: kotlin.Boolean?, hasChat: kotlin.Boolean?, description: kotlin.String?, password: kotlin.String?, teambBattleByTeam: kotlin.String?, conditionsTeamMemberTeamId: kotlin.String?, conditionsMinRatingRating: kotlin.Int?, conditionsMaxRatingRating: kotlin.Int?, conditionsNbRatedGameNb: kotlin.Int?) : RequestConfig<Map<String, Any?>> {
        val localVariableBody = mapOf("name" to name, "clockTime" to clockTime, "clockIncrement" to clockIncrement, "minutes" to minutes, "waitMinutes" to waitMinutes, "startDate" to startDate, "variant" to variant, "rated" to rated, "position" to position, "berserkable" to berserkable, "streakable" to streakable, "hasChat" to hasChat, "description" to description, "password" to password, "teambBattleByTeam" to teambBattleByTeam, "conditions.teamMember.teamId" to conditionsTeamMemberTeamId, "conditions.minRating.rating" to conditionsMinRatingRating, "conditions.maxRating.rating" to conditionsMaxRatingRating, "conditions.nbRatedGame.nb" to conditionsNbRatedGameNb)
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf("Content-Type" to "application/x-www-form-urlencoded")

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/tournament",
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Update a team battle
    * Set the teams and number of leaders of a team battle.  To update the other attributes of a team battle, use the [tournament update endpoint](#operation/apiTournamentUpdate). 
    * @param id The tournament ID (8 characters).. 
    * @param teams All team IDs of the team battle, separated by commas. Make sure to always send the full list. Teams that are not in the list will be removed from the team battle.  Example: &#x60;coders,zhigalko_sergei-fan-club,hhSwTKZv&#x60;  
    * @param nbLeaders Number team leaders per team. 
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun apiTournamentTeamBattlePost(id: kotlin.String, teams: kotlin.String, nbLeaders: kotlin.Int) : kotlin.Any {
        val localVariableConfig = apiTournamentTeamBattlePostRequestConfig(id = id, teams = teams, nbLeaders = nbLeaders)

        val localVarResponse = request<Map<String, Any?>, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation apiTournamentTeamBattlePost
    *
    * @param id The tournament ID (8 characters).. 
    * @param teams All team IDs of the team battle, separated by commas. Make sure to always send the full list. Teams that are not in the list will be removed from the team battle.  Example: &#x60;coders,zhigalko_sergei-fan-club,hhSwTKZv&#x60;  
    * @param nbLeaders Number team leaders per team. 
    * @return RequestConfig
    */
    fun apiTournamentTeamBattlePostRequestConfig(id: kotlin.String, teams: kotlin.String, nbLeaders: kotlin.Int) : RequestConfig<Map<String, Any?>> {
        val localVariableBody = mapOf("teams" to teams, "nbLeaders" to nbLeaders)
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf("Content-Type" to "application/x-www-form-urlencoded")

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/tournament/team-battle/{id}".replace("{"+"id"+"}", "$id"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Terminate an Arena tournament
    * Terminate an Arena tournament 
    * @param id The tournament ID. 
    * @return Ok
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun apiTournamentTerminate(id: kotlin.String) : Ok {
        val localVariableConfig = apiTournamentTerminateRequestConfig(id = id)

        val localVarResponse = request<Unit, Ok>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as Ok
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation apiTournamentTerminate
    *
    * @param id The tournament ID. 
    * @return RequestConfig
    */
    fun apiTournamentTerminateRequestConfig(id: kotlin.String) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/tournament/{id}/terminate".replace("{"+"id"+"}", "$id"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Update an Arena tournament
    * Update an Arena tournament.  Be mindful not to make important changes to ongoing tournaments.  Can be used to update a team battle. 
    * @param id The tournament ID. 
    * @param clockTime Clock initial time in minutes 
    * @param clockIncrement Clock increment in seconds 
    * @param minutes How long the tournament lasts, in minutes 
    * @param name The tournament name. Leave empty to get a random Grandmaster name (optional)
    * @param waitMinutes How long to wait before starting the tournament, from now, in minutes (optional, default to 5)
    * @param startDate Timestamp to start the tournament at a given date and time. Overrides the &#x60;waitMinutes&#x60; setting (optional)
    * @param variant  (optional, default to VariantKey.standard)
    * @param rated Games are rated and impact players ratings (optional, default to true)
    * @param position Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960). (optional)
    * @param berserkable Whether the players can use berserk (optional, default to true)
    * @param streakable After 2 wins, consecutive wins grant 4 points instead of 2. (optional, default to true)
    * @param hasChat Whether the players can discuss in a chat (optional, default to true)
    * @param description Anything you want to tell players about the tournament (optional)
    * @param password Make the tournament private, and restrict access with a password (optional)
    * @param conditionsMinRatingRating Minimum rating to join. Leave empty to let everyone join the tournament. (optional)
    * @param conditionsMaxRatingRating Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament. (optional)
    * @param conditionsNbRatedGameNb Minimum number of rated games required to join. (optional)
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun apiTournamentUpdate(id: kotlin.String, clockTime: java.math.BigDecimal, clockIncrement: kotlin.Int, minutes: kotlin.Int, name: kotlin.String?, waitMinutes: kotlin.Int?, startDate: kotlin.Int?, variant: VariantKey?, rated: kotlin.Boolean?, position: kotlin.String?, berserkable: kotlin.Boolean?, streakable: kotlin.Boolean?, hasChat: kotlin.Boolean?, description: kotlin.String?, password: kotlin.String?, conditionsMinRatingRating: kotlin.Int?, conditionsMaxRatingRating: kotlin.Int?, conditionsNbRatedGameNb: kotlin.Int?) : kotlin.Any {
        val localVariableConfig = apiTournamentUpdateRequestConfig(id = id, clockTime = clockTime, clockIncrement = clockIncrement, minutes = minutes, name = name, waitMinutes = waitMinutes, startDate = startDate, variant = variant, rated = rated, position = position, berserkable = berserkable, streakable = streakable, hasChat = hasChat, description = description, password = password, conditionsMinRatingRating = conditionsMinRatingRating, conditionsMaxRatingRating = conditionsMaxRatingRating, conditionsNbRatedGameNb = conditionsNbRatedGameNb)

        val localVarResponse = request<Map<String, Any?>, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation apiTournamentUpdate
    *
    * @param id The tournament ID. 
    * @param clockTime Clock initial time in minutes 
    * @param clockIncrement Clock increment in seconds 
    * @param minutes How long the tournament lasts, in minutes 
    * @param name The tournament name. Leave empty to get a random Grandmaster name (optional)
    * @param waitMinutes How long to wait before starting the tournament, from now, in minutes (optional, default to 5)
    * @param startDate Timestamp to start the tournament at a given date and time. Overrides the &#x60;waitMinutes&#x60; setting (optional)
    * @param variant  (optional, default to VariantKey.standard)
    * @param rated Games are rated and impact players ratings (optional, default to true)
    * @param position Custom initial position (in FEN) for all games of the tournament. Must be a legal chess position. Only works with standard chess, not variants (except Chess960). (optional)
    * @param berserkable Whether the players can use berserk (optional, default to true)
    * @param streakable After 2 wins, consecutive wins grant 4 points instead of 2. (optional, default to true)
    * @param hasChat Whether the players can discuss in a chat (optional, default to true)
    * @param description Anything you want to tell players about the tournament (optional)
    * @param password Make the tournament private, and restrict access with a password (optional)
    * @param conditionsMinRatingRating Minimum rating to join. Leave empty to let everyone join the tournament. (optional)
    * @param conditionsMaxRatingRating Maximum rating to join. Based on best rating reached in the last 7 days. Leave empty to let everyone join the tournament. (optional)
    * @param conditionsNbRatedGameNb Minimum number of rated games required to join. (optional)
    * @return RequestConfig
    */
    fun apiTournamentUpdateRequestConfig(id: kotlin.String, clockTime: java.math.BigDecimal, clockIncrement: kotlin.Int, minutes: kotlin.Int, name: kotlin.String?, waitMinutes: kotlin.Int?, startDate: kotlin.Int?, variant: VariantKey?, rated: kotlin.Boolean?, position: kotlin.String?, berserkable: kotlin.Boolean?, streakable: kotlin.Boolean?, hasChat: kotlin.Boolean?, description: kotlin.String?, password: kotlin.String?, conditionsMinRatingRating: kotlin.Int?, conditionsMaxRatingRating: kotlin.Int?, conditionsNbRatedGameNb: kotlin.Int?) : RequestConfig<Map<String, Any?>> {
        val localVariableBody = mapOf("name" to name, "clockTime" to clockTime, "clockIncrement" to clockIncrement, "minutes" to minutes, "waitMinutes" to waitMinutes, "startDate" to startDate, "variant" to variant, "rated" to rated, "position" to position, "berserkable" to berserkable, "streakable" to streakable, "hasChat" to hasChat, "description" to description, "password" to password, "conditions.minRating.rating" to conditionsMinRatingRating, "conditions.maxRating.rating" to conditionsMaxRatingRating, "conditions.nbRatedGame.nb" to conditionsNbRatedGameNb)
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf("Content-Type" to "application/x-www-form-urlencoded")

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/tournament/{id}".replace("{"+"id"+"}", "$id"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Pause of leave an Arena tournament
    * Leave a future Arena tournament, or take a break on an ongoing Arena tournament. It&#39;s possible to join again later. Points and streaks are preserved. 
    * @param id The tournament ID. 
    * @return Ok
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun apiTournamentWithdraw(id: kotlin.String) : Ok {
        val localVariableConfig = apiTournamentWithdrawRequestConfig(id = id)

        val localVarResponse = request<Unit, Ok>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as Ok
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation apiTournamentWithdraw
    *
    * @param id The tournament ID. 
    * @return RequestConfig
    */
    fun apiTournamentWithdrawRequestConfig(id: kotlin.String) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/tournament/{id}/withdraw".replace("{"+"id"+"}", "$id"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Get tournaments created by a user
    * Get all tournaments created by a given user.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
    * @param username The user whose created tournaments to fetch 
    * @param status Include tournaments in the given status: \&quot;Created\&quot; (10), \&quot;Started\&quot; (20), \&quot;Finished\&quot; (30)  You can add this parameter more than once to include tournaments in different statuses.   Example: &#x60;?status&#x3D;10&amp;status&#x3D;20&#x60;  (optional)
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun apiUserNameTournamentCreated(username: kotlin.String, status: kotlin.Int?) : kotlin.Any {
        val localVariableConfig = apiUserNameTournamentCreatedRequestConfig(username = username, status = status)

        val localVarResponse = request<Unit, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation apiUserNameTournamentCreated
    *
    * @param username The user whose created tournaments to fetch 
    * @param status Include tournaments in the given status: \&quot;Created\&quot; (10), \&quot;Started\&quot; (20), \&quot;Finished\&quot; (30)  You can add this parameter more than once to include tournaments in different statuses.   Example: &#x60;?status&#x3D;10&amp;status&#x3D;20&#x60;  (optional)
    * @return RequestConfig
    */
    fun apiUserNameTournamentCreatedRequestConfig(username: kotlin.String, status: kotlin.Int?) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf<kotlin.String, List<kotlin.String>>()
            .apply {
                if (status != null) {
                    put("status", listOf(status.toString()))
                }
            }
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/api/user/{username}/tournament/created".replace("{"+"username"+"}", "$username"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Export games of an Arena tournament
    * Download games of a tournament in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (most recent first) 
    * @param id The tournament ID. 
    * @param player Only games of a particular player. Leave empty to fetch games of all players. (optional)
    * @param moves Include the PGN moves. (optional, default to true)
    * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. (optional, default to false)
    * @param tags Include the PGN tags. (optional, default to true)
    * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  (optional, default to false)
    * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  (optional, default to false)
    * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  (optional, default to false)
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun gamesByTournament(id: kotlin.String, player: kotlin.String?, moves: kotlin.Boolean?, pgnInJson: kotlin.Boolean?, tags: kotlin.Boolean?, clocks: kotlin.Boolean?, evals: kotlin.Boolean?, opening: kotlin.Boolean?) : kotlin.Any {
        val localVariableConfig = gamesByTournamentRequestConfig(id = id, player = player, moves = moves, pgnInJson = pgnInJson, tags = tags, clocks = clocks, evals = evals, opening = opening)

        val localVarResponse = request<Unit, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation gamesByTournament
    *
    * @param id The tournament ID. 
    * @param player Only games of a particular player. Leave empty to fetch games of all players. (optional)
    * @param moves Include the PGN moves. (optional, default to true)
    * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. (optional, default to false)
    * @param tags Include the PGN tags. (optional, default to true)
    * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  (optional, default to false)
    * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  (optional, default to false)
    * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  (optional, default to false)
    * @return RequestConfig
    */
    fun gamesByTournamentRequestConfig(id: kotlin.String, player: kotlin.String?, moves: kotlin.Boolean?, pgnInJson: kotlin.Boolean?, tags: kotlin.Boolean?, clocks: kotlin.Boolean?, evals: kotlin.Boolean?, opening: kotlin.Boolean?) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf<kotlin.String, List<kotlin.String>>()
            .apply {
                if (player != null) {
                    put("player", listOf(player.toString()))
                }
                if (moves != null) {
                    put("moves", listOf(moves.toString()))
                }
                if (pgnInJson != null) {
                    put("pgnInJson", listOf(pgnInJson.toString()))
                }
                if (tags != null) {
                    put("tags", listOf(tags.toString()))
                }
                if (clocks != null) {
                    put("clocks", listOf(clocks.toString()))
                }
                if (evals != null) {
                    put("evals", listOf(evals.toString()))
                }
                if (opening != null) {
                    put("opening", listOf(opening.toString()))
                }
            }
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/api/tournament/{id}/games".replace("{"+"id"+"}", "$id"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Get results of an Arena tournament
    * Players of an Arena tournament, with their score and performance, sorted by rank (best first).  **Players are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON)**, i.e. one JSON object per line.  If called on an ongoing tournament, results can be inconsistent due to ranking changes while the players are being streamed. Use on finished tournaments for guaranteed consistency. 
    * @param id The tournament ID. 
    * @param nb Max number of players to fetch (optional)
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun resultsByTournament(id: kotlin.String, nb: kotlin.Int?) : kotlin.Any {
        val localVariableConfig = resultsByTournamentRequestConfig(id = id, nb = nb)

        val localVarResponse = request<Unit, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation resultsByTournament
    *
    * @param id The tournament ID. 
    * @param nb Max number of players to fetch (optional)
    * @return RequestConfig
    */
    fun resultsByTournamentRequestConfig(id: kotlin.String, nb: kotlin.Int?) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf<kotlin.String, List<kotlin.String>>()
            .apply {
                if (nb != null) {
                    put("nb", listOf(nb.toString()))
                }
            }
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/api/tournament/{id}/results".replace("{"+"id"+"}", "$id"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Get team standing of a team battle
    * Teams of a team battle tournament, with top players, sorted by rank (best first). 
    * @param id The tournament ID. 
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun teamsByTournament(id: kotlin.String) : kotlin.Any {
        val localVariableConfig = teamsByTournamentRequestConfig(id = id)

        val localVarResponse = request<Unit, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation teamsByTournament
    *
    * @param id The tournament ID. 
    * @return RequestConfig
    */
    fun teamsByTournamentRequestConfig(id: kotlin.String) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/api/tournament/{id}/teams".replace("{"+"id"+"}", "$id"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Get info about an Arena tournament
    * Get detailed info about recently finished, current, or upcoming tournament&#39;s duels, player standings, and other info. 
    * @param id The tournament ID. 
    * @param page Specify which page of player standings to view. (optional, default to 1)
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun tournament(id: kotlin.String, page: java.math.BigDecimal?) : kotlin.Any {
        val localVariableConfig = tournamentRequestConfig(id = id, page = page)

        val localVarResponse = request<Unit, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation tournament
    *
    * @param id The tournament ID. 
    * @param page Specify which page of player standings to view. (optional, default to 1)
    * @return RequestConfig
    */
    fun tournamentRequestConfig(id: kotlin.String, page: java.math.BigDecimal?) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf<kotlin.String, List<kotlin.String>>()
            .apply {
                if (page != null) {
                    put("page", listOf(page.toString()))
                }
            }
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/api/tournament/{id}".replace("{"+"id"+"}", "$id"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

}
