/**
 * Lichess.org API reference
 *
 * # Introduction Welcome to the reference for the Lichess API! Lichess is free/libre, open-source chess server powered by volunteers and donations. - Get help in the [Lichess Discord channel](https://discord.gg/lichess) - [Contribute to this documentation on Github](https://github.com/lichess-org/api) - Check out [Lichess widgets to embed in your website](https://lichess.org/developers) - [Download all Lichess rated games](https://database.lichess.org/) - [Download all Lichess puzzles with themes, ratings and votes](https://database.lichess.org/#puzzles)  ## Endpoint All requests go to `https://lichess.org` (unless otherwise specified).  ## Clients - [Python general API](https://github.com/ZackClements/berserk) - [MicroPython general API](https://github.com/mkomon/uberserk) - [Python general API - async](https://pypi.org/project/async-lichess-sdk) - [Python Lichess Bot](https://github.com/careless25/lichess-bot) - [Python Board API for Certabo](https://github.com/haklein/certabo-lichess) - [Java general API](https://github.com/tors42/chariot)  ## Rate limiting All requests are rate limited using various strategies, to ensure the API remains responsive for everyone. Only make one request at a time. If you receive an HTTP response with a [429 status](https://en.wikipedia.org/wiki/List_of_HTTP_status_codes#429), please wait a full minute before resuming API usage.  ## Streaming with ND-JSON Some API endpoints stream their responses as [Newline Delimited JSON a.k.a. **nd-json**](http://ndjson.org/), with one JSON object per line.  Here's a [JavaScript utility function](https://gist.github.com/ornicar/a097406810939cf7be1df8ea30e94f3e) to help reading NDJSON streamed responses. 
 *
 * The version of the OpenAPI document: 2.0.0
 * 
 *
 * Please note:
 * This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * Do not edit this file manually.
 */

@file:Suppress(
    "ArrayInDataClass",
    "EnumEntryName",
    "RemoveRedundantQualifierName",
    "UnusedImport"
)

package org.openapitools.client.apis

import org.openapitools.client.models.ApiStreamEvent
import org.openapitools.client.models.Error
import org.openapitools.client.models.GameStreamEvent
import org.openapitools.client.models.NotFound
import org.openapitools.client.models.Ok
import org.openapitools.client.models.VariantKey

import org.openapitools.client.infrastructure.ApiClient
import org.openapitools.client.infrastructure.ClientException
import org.openapitools.client.infrastructure.ClientError
import org.openapitools.client.infrastructure.ServerException
import org.openapitools.client.infrastructure.ServerError
import org.openapitools.client.infrastructure.MultiValueMap
import org.openapitools.client.infrastructure.RequestConfig
import org.openapitools.client.infrastructure.RequestMethod
import org.openapitools.client.infrastructure.ResponseType
import org.openapitools.client.infrastructure.Success
import org.openapitools.client.infrastructure.toMultiValue

class BoardApi(basePath: kotlin.String = defaultBasePath) : ApiClient(basePath) {
    companion object {
        @JvmStatic
        val defaultBasePath: String by lazy {
            System.getProperties().getProperty("org.openapitools.client.baseUrl", "https://lichess.org")
        }
    }

    /**
    * Create a seek
    *    Create a public seek, to start a game with a random player.    ### Real-time seek    Specify the &#x60;time&#x60; and &#x60;increment&#x60; clock values.  The response is streamed but doesn&#39;t contain any information.    **Keep the connection open to keep the seek active**.    If the client closes the connection, the seek is canceled. This way, if the client terminates, the user won&#39;t be paired in a game they wouldn&#39;t play.   When the seek is accepted, or expires, the server closes the connection.    **Make sure to also have an [Event stream](#operation/apiStreamEvent) open**, to be notified when a game starts.   We recommend opening the [Event stream](#operation/apiStreamEvent) first, then the seek stream. This way,   you won&#39;t miss the game event if the seek is accepted immediately.    ### Correspondence seek    Specify the &#x60;days&#x60; per turn value.  The response is not streamed, it immediately completes with the seek ID. The seek remains active on the server until it is joined by someone.
    * @param rated Whether the game is rated and impacts players ratings. (optional, default to false)
    * @param time Clock initial time in minutes. Required for real-time seeks. (optional)
    * @param increment Clock increment in seconds. Required for real-time seeks. (optional)
    * @param days Days per turn. Required for correspondence seeks. (optional)
    * @param variant  (optional, default to VariantKey.standard)
    * @param color The color to play. Better left empty to automatically get 50% white. (optional, default to random)
    * @param ratingRange The rating range of potential opponents. Better left empty. Example: 1500-1800  (optional)
    * @return void
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun apiBoardSeek(rated: kotlin.Boolean?, time: java.math.BigDecimal?, increment: kotlin.Int?, days: kotlin.Int?, variant: VariantKey?, color: kotlin.String?, ratingRange: kotlin.String?) : Unit {
        val localVariableConfig = apiBoardSeekRequestConfig(rated = rated, time = time, increment = increment, days = days, variant = variant, color = color, ratingRange = ratingRange)

        val localVarResponse = request<Map<String, Any?>, Unit>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> Unit
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation apiBoardSeek
    *
    * @param rated Whether the game is rated and impacts players ratings. (optional, default to false)
    * @param time Clock initial time in minutes. Required for real-time seeks. (optional)
    * @param increment Clock increment in seconds. Required for real-time seeks. (optional)
    * @param days Days per turn. Required for correspondence seeks. (optional)
    * @param variant  (optional, default to VariantKey.standard)
    * @param color The color to play. Better left empty to automatically get 50% white. (optional, default to random)
    * @param ratingRange The rating range of potential opponents. Better left empty. Example: 1500-1800  (optional)
    * @return RequestConfig
    */
    fun apiBoardSeekRequestConfig(rated: kotlin.Boolean?, time: java.math.BigDecimal?, increment: kotlin.Int?, days: kotlin.Int?, variant: VariantKey?, color: kotlin.String?, ratingRange: kotlin.String?) : RequestConfig<Map<String, Any?>> {
        val localVariableBody = mapOf("rated" to rated, "time" to time, "increment" to increment, "days" to days, "variant" to variant, "color" to color, "ratingRange" to ratingRange)
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf("Content-Type" to "application/x-www-form-urlencoded")

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/board/seek",
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Stream incoming events
    *    Stream the events reaching a lichess user in real time as [ndjson](#section/Introduction/Streaming-with-ND-JSON).    Each line is a JSON object containing a &#x60;type&#x60; field. Possible values are:   - &#x60;gameStart&#x60; Start of a game   - &#x60;gameFinish&#x60; Completion of a game   - &#x60;challenge&#x60; A player sends you a challenge   - &#x60;challengeCanceled&#x60; A player cancels their challenge to you   - &#x60;challengeDeclined&#x60; The opponent declines your challenge     When the stream opens, all current challenges and games are sent.
    * @return ApiStreamEvent
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun apiStreamEvent() : ApiStreamEvent {
        val localVariableConfig = apiStreamEventRequestConfig()

        val localVarResponse = request<Unit, ApiStreamEvent>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as ApiStreamEvent
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation apiStreamEvent
    *
    * @return RequestConfig
    */
    fun apiStreamEventRequestConfig() : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/api/stream/event",
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Abort a game
    * Abort a game being played with the Board API. 
    * @param gameId  
    * @return Ok
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun boardGameAbort(gameId: kotlin.String) : Ok {
        val localVariableConfig = boardGameAbortRequestConfig(gameId = gameId)

        val localVarResponse = request<Unit, Ok>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as Ok
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation boardGameAbort
    *
    * @param gameId  
    * @return RequestConfig
    */
    fun boardGameAbortRequestConfig(gameId: kotlin.String) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/board/game/{gameId}/abort".replace("{"+"gameId"+"}", "$gameId"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Fetch the game chat
    * Get the messages posted in the game chat 
    * @param gameId  
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun boardGameChatGet(gameId: kotlin.String) : kotlin.Any {
        val localVariableConfig = boardGameChatGetRequestConfig(gameId = gameId)

        val localVarResponse = request<Unit, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation boardGameChatGet
    *
    * @param gameId  
    * @return RequestConfig
    */
    fun boardGameChatGetRequestConfig(gameId: kotlin.String) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/api/board/game/{gameId}/chat".replace("{"+"gameId"+"}", "$gameId"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Write in the chat
    * Post a message to the player or spectator chat, in a game being played with the Board API. 
    * @param gameId  
    * @param room  
    * @param text  
    * @return Ok
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun boardGameChatPost(gameId: kotlin.String, room: kotlin.String, text: kotlin.String) : Ok {
        val localVariableConfig = boardGameChatPostRequestConfig(gameId = gameId, room = room, text = text)

        val localVarResponse = request<Map<String, Any?>, Ok>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as Ok
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation boardGameChatPost
    *
    * @param gameId  
    * @param room  
    * @param text  
    * @return RequestConfig
    */
    fun boardGameChatPostRequestConfig(gameId: kotlin.String, room: kotlin.String, text: kotlin.String) : RequestConfig<Map<String, Any?>> {
        val localVariableBody = mapOf("room" to room, "text" to text)
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf("Content-Type" to "application/x-www-form-urlencoded")

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/board/game/{gameId}/chat".replace("{"+"gameId"+"}", "$gameId"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Claim victory of a game
    * Claim victory when the opponent has left the game for a while. 
    * @param gameId  
    * @return Ok
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun boardGameClaimVictory(gameId: kotlin.String) : Ok {
        val localVariableConfig = boardGameClaimVictoryRequestConfig(gameId = gameId)

        val localVarResponse = request<Unit, Ok>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as Ok
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation boardGameClaimVictory
    *
    * @param gameId  
    * @return RequestConfig
    */
    fun boardGameClaimVictoryRequestConfig(gameId: kotlin.String) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/board/game/{gameId}/claim-victory".replace("{"+"gameId"+"}", "$gameId"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Handle draw offers
    * Create/accept/decline draw offers. - &#x60;yes&#x60;: Offer a draw, or accept the opponent&#39;s draw offer. - &#x60;no&#x60;: Decline a draw offer from the opponent. 
    * @param gameId  
    * @param accept  
    * @return Ok
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun boardGameDraw(gameId: kotlin.String, accept: kotlin.Boolean) : Ok {
        val localVariableConfig = boardGameDrawRequestConfig(gameId = gameId, accept = accept)

        val localVarResponse = request<Unit, Ok>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as Ok
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation boardGameDraw
    *
    * @param gameId  
    * @param accept  
    * @return RequestConfig
    */
    fun boardGameDrawRequestConfig(gameId: kotlin.String, accept: kotlin.Boolean) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/board/game/{gameId}/draw/{accept}".replace("{"+"gameId"+"}", "$gameId").replace("{"+"accept"+"}", "$accept"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Make a Board move
    * Make a move in a game being played with the Board API.  The move can also contain a draw offer/agreement. 
    * @param gameId  
    * @param move The move to play, in UCI format 
    * @param offeringDraw Whether to offer (or agree to) a draw (optional)
    * @return Ok
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun boardGameMove(gameId: kotlin.String, move: kotlin.String, offeringDraw: kotlin.Boolean?) : Ok {
        val localVariableConfig = boardGameMoveRequestConfig(gameId = gameId, move = move, offeringDraw = offeringDraw)

        val localVarResponse = request<Unit, Ok>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as Ok
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation boardGameMove
    *
    * @param gameId  
    * @param move The move to play, in UCI format 
    * @param offeringDraw Whether to offer (or agree to) a draw (optional)
    * @return RequestConfig
    */
    fun boardGameMoveRequestConfig(gameId: kotlin.String, move: kotlin.String, offeringDraw: kotlin.Boolean?) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf<kotlin.String, List<kotlin.String>>()
            .apply {
                if (offeringDraw != null) {
                    put("offeringDraw", listOf(offeringDraw.toString()))
                }
            }
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/board/game/{gameId}/move/{move}".replace("{"+"gameId"+"}", "$gameId").replace("{"+"move"+"}", "$move"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Resign a game
    * Resign a game being played with the Board API. 
    * @param gameId  
    * @return Ok
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun boardGameResign(gameId: kotlin.String) : Ok {
        val localVariableConfig = boardGameResignRequestConfig(gameId = gameId)

        val localVarResponse = request<Unit, Ok>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as Ok
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation boardGameResign
    *
    * @param gameId  
    * @return RequestConfig
    */
    fun boardGameResignRequestConfig(gameId: kotlin.String) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/board/game/{gameId}/resign".replace("{"+"gameId"+"}", "$gameId"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Stream Board game state
    *  Stream the state of a game being played with the Board API, as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  Use this endpoint to get updates about the game in real-time, with a single request.  Each line is a JSON object containing a &#x60;type&#x60; field. Possible values are:   - &#x60;gameFull&#x60; Full game data. All values are immutable, except for the &#x60;state&#x60; field.   - &#x60;gameState&#x60; Current state of the game. Immutable values not included. Sent when a move is played, a draw is offered, or when the game ends.   - &#x60;chatLine&#x60; Chat message sent by a user in the &#x60;room&#x60; \&quot;player\&quot; or \&quot;spectator\&quot;.    The first line is always of type &#x60;gameFull&#x60;.
    * @param gameId  
    * @return GameStreamEvent
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun boardGameStream(gameId: kotlin.String) : GameStreamEvent {
        val localVariableConfig = boardGameStreamRequestConfig(gameId = gameId)

        val localVarResponse = request<Unit, GameStreamEvent>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as GameStreamEvent
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation boardGameStream
    *
    * @param gameId  
    * @return RequestConfig
    */
    fun boardGameStreamRequestConfig(gameId: kotlin.String) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/api/board/game/stream/{gameId}".replace("{"+"gameId"+"}", "$gameId"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Handle takeback offers
    * Create/accept/decline takebacks. - &#x60;yes&#x60;: Propose a takeback, or accept the opponent&#39;s takeback offer. - &#x60;no&#x60;: Decline a takeback offer from the opponent. 
    * @param gameId  
    * @param accept  
    * @return Ok
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun boardGameTakeback(gameId: kotlin.String, accept: kotlin.Boolean) : Ok {
        val localVariableConfig = boardGameTakebackRequestConfig(gameId = gameId, accept = accept)

        val localVarResponse = request<Unit, Ok>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as Ok
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation boardGameTakeback
    *
    * @param gameId  
    * @param accept  
    * @return RequestConfig
    */
    fun boardGameTakebackRequestConfig(gameId: kotlin.String, accept: kotlin.Boolean) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/board/game/{gameId}/takeback/{accept}".replace("{"+"gameId"+"}", "$gameId").replace("{"+"accept"+"}", "$accept"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

}
