/**
 * Lichess.org API reference
 *
 * # Introduction Welcome to the reference for the Lichess API! Lichess is free/libre, open-source chess server powered by volunteers and donations. - Get help in the [Lichess Discord channel](https://discord.gg/lichess) - [Contribute to this documentation on Github](https://github.com/lichess-org/api) - Check out [Lichess widgets to embed in your website](https://lichess.org/developers) - [Download all Lichess rated games](https://database.lichess.org/) - [Download all Lichess puzzles with themes, ratings and votes](https://database.lichess.org/#puzzles)  ## Endpoint All requests go to `https://lichess.org` (unless otherwise specified).  ## Clients - [Python general API](https://github.com/ZackClements/berserk) - [MicroPython general API](https://github.com/mkomon/uberserk) - [Python general API - async](https://pypi.org/project/async-lichess-sdk) - [Python Lichess Bot](https://github.com/careless25/lichess-bot) - [Python Board API for Certabo](https://github.com/haklein/certabo-lichess) - [Java general API](https://github.com/tors42/chariot)  ## Rate limiting All requests are rate limited using various strategies, to ensure the API remains responsive for everyone. Only make one request at a time. If you receive an HTTP response with a [429 status](https://en.wikipedia.org/wiki/List_of_HTTP_status_codes#429), please wait a full minute before resuming API usage.  ## Streaming with ND-JSON Some API endpoints stream their responses as [Newline Delimited JSON a.k.a. **nd-json**](http://ndjson.org/), with one JSON object per line.  Here's a [JavaScript utility function](https://gist.github.com/ornicar/a097406810939cf7be1df8ea30e94f3e) to help reading NDJSON streamed responses. 
 *
 * The version of the OpenAPI document: 2.0.0
 * 
 *
 * Please note:
 * This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * Do not edit this file manually.
 */

@file:Suppress(
    "ArrayInDataClass",
    "EnumEntryName",
    "RemoveRedundantQualifierName",
    "UnusedImport"
)

package org.openapitools.client.apis

import org.openapitools.client.models.Error
import org.openapitools.client.models.Ok

import org.openapitools.client.infrastructure.ApiClient
import org.openapitools.client.infrastructure.ClientException
import org.openapitools.client.infrastructure.ClientError
import org.openapitools.client.infrastructure.ServerException
import org.openapitools.client.infrastructure.ServerError
import org.openapitools.client.infrastructure.MultiValueMap
import org.openapitools.client.infrastructure.RequestConfig
import org.openapitools.client.infrastructure.RequestMethod
import org.openapitools.client.infrastructure.ResponseType
import org.openapitools.client.infrastructure.Success
import org.openapitools.client.infrastructure.toMultiValue

class BroadcastsApi(basePath: kotlin.String = defaultBasePath) : ApiClient(basePath) {
    companion object {
        @JvmStatic
        val defaultBasePath: String by lazy {
            System.getProperties().getProperty("org.openapitools.client.baseUrl", "https://lichess.org")
        }
    }

    /**
    * Export all rounds as PGN
    * Download all games of all rounds of a broadcast in PGN format.  You may want to [download only the games of a single round](#operation/broadcastRoundPgn) instead. 
    * @param broadcastTournamentId The broadcast tournament ID (8 characters). 
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun broadcastAllRoundsPgn(broadcastTournamentId: kotlin.String) : kotlin.Any {
        val localVariableConfig = broadcastAllRoundsPgnRequestConfig(broadcastTournamentId = broadcastTournamentId)

        val localVarResponse = request<Unit, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation broadcastAllRoundsPgn
    *
    * @param broadcastTournamentId The broadcast tournament ID (8 characters). 
    * @return RequestConfig
    */
    fun broadcastAllRoundsPgnRequestConfig(broadcastTournamentId: kotlin.String) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/api/broadcast/{broadcastTournamentId}.pgn".replace("{"+"broadcastTournamentId"+"}", "$broadcastTournamentId"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Get official broadcasts
    * Get all incoming, ongoing, and finished official broadcasts. The broadcasts are sorted by start date, most recent first.  Broadcasts are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
    * @param nb Max number of broadcasts to fetch (optional, default to 20)
    * @return kotlin.collections.List<kotlin.Any>
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun broadcastIndex(nb: kotlin.Int?) : kotlin.collections.List<kotlin.Any> {
        val localVariableConfig = broadcastIndexRequestConfig(nb = nb)

        val localVarResponse = request<Unit, kotlin.collections.List<kotlin.Any>>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.collections.List<kotlin.Any>
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation broadcastIndex
    *
    * @param nb Max number of broadcasts to fetch (optional, default to 20)
    * @return RequestConfig
    */
    fun broadcastIndexRequestConfig(nb: kotlin.Int?) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf<kotlin.String, List<kotlin.String>>()
            .apply {
                if (nb != null) {
                    put("nb", listOf(nb.toString()))
                }
            }
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/api/broadcast",
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Push PGN to your broadcast round
    * Update your broadcast with new PGN. Only for broadcast without a source URL. 
    * @param broadcastRoundId The broadcast round ID (8 characters). 
    * @param body The PGN. It can contain up to 64 games, separated by a double new line. 
    * @return kotlin.collections.List<Ok>
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun broadcastPush(broadcastRoundId: kotlin.String, body: kotlin.String) : kotlin.collections.List<Ok> {
        val localVariableConfig = broadcastPushRequestConfig(broadcastRoundId = broadcastRoundId, body = body)

        val localVarResponse = request<kotlin.String, kotlin.collections.List<Ok>>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.collections.List<Ok>
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation broadcastPush
    *
    * @param broadcastRoundId The broadcast round ID (8 characters). 
    * @param body The PGN. It can contain up to 64 games, separated by a double new line. 
    * @return RequestConfig
    */
    fun broadcastPushRequestConfig(broadcastRoundId: kotlin.String, body: kotlin.String) : RequestConfig<kotlin.String> {
        val localVariableBody = body
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/broadcast/round/{broadcastRoundId}/push".replace("{"+"broadcastRoundId"+"}", "$broadcastRoundId"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Create a broadcast round
    * Create a new broadcast round to relay external games. This endpoint accepts the same form data as the web form. 
    * @param broadcastTournamentId The broadcast tournament ID (8 characters). 
    * @param name Name of the broadcast round. Length must be between 3 and 80 characters.  Example: &#x60;Round 1&#x60;  
    * @param syncUrl URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: &#x60;https://myserver.org/myevent/round-10/games.pgn&#x60;  If the syncUrl is missing, then the broadcast needs to be fed by [pushing PGN to it](#operation/broadcastPush).  (optional)
    * @param startsAt Timestamp in milliseconds of broadcast round start. Leave empty to manually start the broadcast round.  Example: &#x60;1356998400070&#x60;  (optional)
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun broadcastRoundCreate(broadcastTournamentId: kotlin.String, name: kotlin.String, syncUrl: kotlin.String?, startsAt: kotlin.Int?) : kotlin.Any {
        val localVariableConfig = broadcastRoundCreateRequestConfig(broadcastTournamentId = broadcastTournamentId, name = name, syncUrl = syncUrl, startsAt = startsAt)

        val localVarResponse = request<Map<String, Any?>, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation broadcastRoundCreate
    *
    * @param broadcastTournamentId The broadcast tournament ID (8 characters). 
    * @param name Name of the broadcast round. Length must be between 3 and 80 characters.  Example: &#x60;Round 1&#x60;  
    * @param syncUrl URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: &#x60;https://myserver.org/myevent/round-10/games.pgn&#x60;  If the syncUrl is missing, then the broadcast needs to be fed by [pushing PGN to it](#operation/broadcastPush).  (optional)
    * @param startsAt Timestamp in milliseconds of broadcast round start. Leave empty to manually start the broadcast round.  Example: &#x60;1356998400070&#x60;  (optional)
    * @return RequestConfig
    */
    fun broadcastRoundCreateRequestConfig(broadcastTournamentId: kotlin.String, name: kotlin.String, syncUrl: kotlin.String?, startsAt: kotlin.Int?) : RequestConfig<Map<String, Any?>> {
        val localVariableBody = mapOf("name" to name, "syncUrl" to syncUrl, "startsAt" to startsAt)
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf("Content-Type" to "application/x-www-form-urlencoded")

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/broadcast/{broadcastTournamentId}/new".replace("{"+"broadcastTournamentId"+"}", "$broadcastTournamentId"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Get your broadcast round
    * Get information about a broadcast round that you created. 
    * @param broadcastTournamentSlug The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastRoundId&#x60; is actually used. 
    * @param broadcastRoundSlug The broadcast round slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastRoundId&#x60; is actually used. 
    * @param broadcastRoundId The broadcast Round ID (8 characters). 
    * @return kotlin.collections.List<kotlin.Any>
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun broadcastRoundGet(broadcastTournamentSlug: kotlin.String, broadcastRoundSlug: kotlin.String, broadcastRoundId: kotlin.String) : kotlin.collections.List<kotlin.Any> {
        val localVariableConfig = broadcastRoundGetRequestConfig(broadcastTournamentSlug = broadcastTournamentSlug, broadcastRoundSlug = broadcastRoundSlug, broadcastRoundId = broadcastRoundId)

        val localVarResponse = request<Unit, kotlin.collections.List<kotlin.Any>>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.collections.List<kotlin.Any>
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation broadcastRoundGet
    *
    * @param broadcastTournamentSlug The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastRoundId&#x60; is actually used. 
    * @param broadcastRoundSlug The broadcast round slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastRoundId&#x60; is actually used. 
    * @param broadcastRoundId The broadcast Round ID (8 characters). 
    * @return RequestConfig
    */
    fun broadcastRoundGetRequestConfig(broadcastTournamentSlug: kotlin.String, broadcastRoundSlug: kotlin.String, broadcastRoundId: kotlin.String) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/broadcast/{broadcastTournamentSlug}/{broadcastRoundSlug}/{broadcastRoundId}".replace("{"+"broadcastTournamentSlug"+"}", "$broadcastTournamentSlug").replace("{"+"broadcastRoundSlug"+"}", "$broadcastRoundSlug").replace("{"+"broadcastRoundId"+"}", "$broadcastRoundId"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Export one round as PGN
    * Download all games of a single round of a broadcast tournament in PGN format.  You *could* poll this endpoint to get updates about a tournament, but it would be slow, and very inneficient.  Instead, consider [streaming the tournament](#operation/broadcastStreamRoundPgn) to get a new PGN every time a game is updated, in real-time. 
    * @param broadcastRoundId The round ID (8 characters). 
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun broadcastRoundPgn(broadcastRoundId: kotlin.String) : kotlin.Any {
        val localVariableConfig = broadcastRoundPgnRequestConfig(broadcastRoundId = broadcastRoundId)

        val localVarResponse = request<Unit, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation broadcastRoundPgn
    *
    * @param broadcastRoundId The round ID (8 characters). 
    * @return RequestConfig
    */
    fun broadcastRoundPgnRequestConfig(broadcastRoundId: kotlin.String) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/api/broadcast/round/{broadcastRoundId}.pgn".replace("{"+"broadcastRoundId"+"}", "$broadcastRoundId"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Update your broadcast round
    * Update information about a broadcast round that you created. This endpoint accepts the same form data as the web form. All fields must be populated with data. Missing fields will override the broadcast with empty data. For instance, if you omit &#x60;startDate&#x60;, then any pre-existing start date will be removed. 
    * @param broadcastRoundId The broadcast round ID (8 characters). 
    * @param name Name of the broadcast round. Length must be between 3 and 80 characters.  Example: &#x60;Round 10&#x60;  
    * @param syncUrl URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: &#x60;https://myserver.org/myevent/round-10/games.pgn&#x60;  (optional)
    * @param startsAt Timestamp in milliseconds of broadcast start. Leave empty to manually start the broadcast.  Example: &#x60;1356998400070&#x60;  (optional)
    * @return Ok
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun broadcastRoundUpdate(broadcastRoundId: kotlin.String, name: kotlin.String, syncUrl: kotlin.String?, startsAt: kotlin.Int?) : Ok {
        val localVariableConfig = broadcastRoundUpdateRequestConfig(broadcastRoundId = broadcastRoundId, name = name, syncUrl = syncUrl, startsAt = startsAt)

        val localVarResponse = request<Map<String, Any?>, Ok>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as Ok
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation broadcastRoundUpdate
    *
    * @param broadcastRoundId The broadcast round ID (8 characters). 
    * @param name Name of the broadcast round. Length must be between 3 and 80 characters.  Example: &#x60;Round 10&#x60;  
    * @param syncUrl URL that Lichess will poll to get updates about the games. It must be publicly accessible from the Internet.  Example: &#x60;https://myserver.org/myevent/round-10/games.pgn&#x60;  (optional)
    * @param startsAt Timestamp in milliseconds of broadcast start. Leave empty to manually start the broadcast.  Example: &#x60;1356998400070&#x60;  (optional)
    * @return RequestConfig
    */
    fun broadcastRoundUpdateRequestConfig(broadcastRoundId: kotlin.String, name: kotlin.String, syncUrl: kotlin.String?, startsAt: kotlin.Int?) : RequestConfig<Map<String, Any?>> {
        val localVariableBody = mapOf("name" to name, "syncUrl" to syncUrl, "startsAt" to startsAt)
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf("Content-Type" to "application/x-www-form-urlencoded")

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/broadcast/round/{broadcastRoundId}/edit".replace("{"+"broadcastRoundId"+"}", "$broadcastRoundId"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Stream an ongoing broadcast tournament as PGN
    * This streaming endpoint first sends all games of a broadcast tournament in PGN format.  Then, it waits for new moves to be played. As soon as it happens, the entire PGN of the game is sent to the stream.  The stream will also send PGNs when games are added to the tournament.  This is the best way to get updates about an ongoing tournament. Streaming means no polling, and no pollings means no latency, and minimum impact on the server. 
    * @param broadcastRoundId The broadcast round ID (8 characters). 
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun broadcastStreamRoundPgn(broadcastRoundId: kotlin.String) : kotlin.Any {
        val localVariableConfig = broadcastStreamRoundPgnRequestConfig(broadcastRoundId = broadcastRoundId)

        val localVarResponse = request<Unit, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation broadcastStreamRoundPgn
    *
    * @param broadcastRoundId The broadcast round ID (8 characters). 
    * @return RequestConfig
    */
    fun broadcastStreamRoundPgnRequestConfig(broadcastRoundId: kotlin.String) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/api/stream/broadcast/round/{broadcastRoundId}.pgn".replace("{"+"broadcastRoundId"+"}", "$broadcastRoundId"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Create a broadcast tournament
    * Create a new broadcast tournament to relay external games. This endpoint accepts the same form data as the [web form](https://lichess.org/broadcast/new). 
    * @param name Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: &#x60;Sinquefield Cup&#x60;  
    * @param description Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: &#x60;An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.&#x60;  
    * @param markup Optional long description of the broadcast. Markdown is supported. Length must be less than 20,000 characters. (optional)
    * @param official For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police. (optional)
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun broadcastTourCreate(name: kotlin.String, description: kotlin.String, markup: kotlin.String?, official: kotlin.Boolean?) : kotlin.Any {
        val localVariableConfig = broadcastTourCreateRequestConfig(name = name, description = description, markup = markup, official = official)

        val localVarResponse = request<Map<String, Any?>, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation broadcastTourCreate
    *
    * @param name Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: &#x60;Sinquefield Cup&#x60;  
    * @param description Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: &#x60;An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.&#x60;  
    * @param markup Optional long description of the broadcast. Markdown is supported. Length must be less than 20,000 characters. (optional)
    * @param official For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police. (optional)
    * @return RequestConfig
    */
    fun broadcastTourCreateRequestConfig(name: kotlin.String, description: kotlin.String, markup: kotlin.String?, official: kotlin.Boolean?) : RequestConfig<Map<String, Any?>> {
        val localVariableBody = mapOf("name" to name, "description" to description, "markup" to markup, "official" to official)
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf("Content-Type" to "application/x-www-form-urlencoded")

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/broadcast/new",
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Get your broadcast tournament
    * Get information about a broadcast tournament that you created. 
    * @param slug The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastTournamentId&#x60; is actually used. 
    * @param broadcastTournamentId The broadcast tournament ID (8 characters). 
    * @return kotlin.collections.List<kotlin.Any>
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun broadcastTourGet(slug: kotlin.String, broadcastTournamentId: kotlin.String) : kotlin.collections.List<kotlin.Any> {
        val localVariableConfig = broadcastTourGetRequestConfig(slug = slug, broadcastTournamentId = broadcastTournamentId)

        val localVarResponse = request<Unit, kotlin.collections.List<kotlin.Any>>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.collections.List<kotlin.Any>
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation broadcastTourGet
    *
    * @param slug The broadcast tournament slug. Only used for SEO, the slug can be safely replaced by &#x60;-&#x60;. Only the &#x60;broadcastTournamentId&#x60; is actually used. 
    * @param broadcastTournamentId The broadcast tournament ID (8 characters). 
    * @return RequestConfig
    */
    fun broadcastTourGetRequestConfig(slug: kotlin.String, broadcastTournamentId: kotlin.String) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/broadcast/{slug}/{broadcastTournamentId}".replace("{"+"slug"+"}", "$slug").replace("{"+"broadcastTournamentId"+"}", "$broadcastTournamentId"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Update your broadcast tournament
    * Update information about a broadcast tournament that you created. This endpoint accepts the same form data as the web form. All fields must be populated with data. Missing fields will override the broadcast with empty data. 
    * @param broadcastTournamentId The broadcast ID (8 characters). 
    * @param name Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: &#x60;Sinquefield Cup&#x60;  
    * @param description Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: &#x60;An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.&#x60;  
    * @param markup Optional long description of the broadcast tournament. Markdown is supported. Length must be less than 20,000 characters. (optional)
    * @param official For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police. (optional)
    * @return Ok
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun broadcastTourUpdate(broadcastTournamentId: kotlin.String, name: kotlin.String, description: kotlin.String, markup: kotlin.String?, official: kotlin.Boolean?) : Ok {
        val localVariableConfig = broadcastTourUpdateRequestConfig(broadcastTournamentId = broadcastTournamentId, name = name, description = description, markup = markup, official = official)

        val localVarResponse = request<Map<String, Any?>, Ok>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as Ok
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation broadcastTourUpdate
    *
    * @param broadcastTournamentId The broadcast ID (8 characters). 
    * @param name Name of the broadcast tournament. Length must be between 3 and 80 characters.  Example: &#x60;Sinquefield Cup&#x60;  
    * @param description Short description of the broadcast tournament. Length must be between 3 and 400 characters.  Example: &#x60;An 11 round classical tournament featuring the 9 highest rated players in the world. Including Carlsen, Caruana, Ding, Aronian, Nakamura and more.&#x60;  
    * @param markup Optional long description of the broadcast tournament. Markdown is supported. Length must be less than 20,000 characters. (optional)
    * @param official For Lichess internal usage only. You are not allowed to use this flag. If you do it, we will have to call the police. (optional)
    * @return RequestConfig
    */
    fun broadcastTourUpdateRequestConfig(broadcastTournamentId: kotlin.String, name: kotlin.String, description: kotlin.String, markup: kotlin.String?, official: kotlin.Boolean?) : RequestConfig<Map<String, Any?>> {
        val localVariableBody = mapOf("name" to name, "description" to description, "markup" to markup, "official" to official)
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf("Content-Type" to "application/x-www-form-urlencoded")

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/broadcast/{broadcastTournamentId}/edit".replace("{"+"broadcastTournamentId"+"}", "$broadcastTournamentId"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

}
