/**
 * Lichess.org API reference
 *
 * # Introduction Welcome to the reference for the Lichess API! Lichess is free/libre, open-source chess server powered by volunteers and donations. - Get help in the [Lichess Discord channel](https://discord.gg/lichess) - [Contribute to this documentation on Github](https://github.com/lichess-org/api) - Check out [Lichess widgets to embed in your website](https://lichess.org/developers) - [Download all Lichess rated games](https://database.lichess.org/) - [Download all Lichess puzzles with themes, ratings and votes](https://database.lichess.org/#puzzles)  ## Endpoint All requests go to `https://lichess.org` (unless otherwise specified).  ## Clients - [Python general API](https://github.com/ZackClements/berserk) - [MicroPython general API](https://github.com/mkomon/uberserk) - [Python general API - async](https://pypi.org/project/async-lichess-sdk) - [Python Lichess Bot](https://github.com/careless25/lichess-bot) - [Python Board API for Certabo](https://github.com/haklein/certabo-lichess) - [Java general API](https://github.com/tors42/chariot)  ## Rate limiting All requests are rate limited using various strategies, to ensure the API remains responsive for everyone. Only make one request at a time. If you receive an HTTP response with a [429 status](https://en.wikipedia.org/wiki/List_of_HTTP_status_codes#429), please wait a full minute before resuming API usage.  ## Streaming with ND-JSON Some API endpoints stream their responses as [Newline Delimited JSON a.k.a. **nd-json**](http://ndjson.org/), with one JSON object per line.  Here's a [JavaScript utility function](https://gist.github.com/ornicar/a097406810939cf7be1df8ea30e94f3e) to help reading NDJSON streamed responses. 
 *
 * The version of the OpenAPI document: 2.0.0
 * 
 *
 * Please note:
 * This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * Do not edit this file manually.
 */

@file:Suppress(
    "ArrayInDataClass",
    "EnumEntryName",
    "RemoveRedundantQualifierName",
    "UnusedImport"
)

package org.openapitools.client.apis

import org.openapitools.client.models.ChallengeJson
import org.openapitools.client.models.Error
import org.openapitools.client.models.GameJson
import org.openapitools.client.models.InlineResponse2003
import org.openapitools.client.models.NotFound
import org.openapitools.client.models.Ok
import org.openapitools.client.models.VariantKey

import org.openapitools.client.infrastructure.ApiClient
import org.openapitools.client.infrastructure.ClientException
import org.openapitools.client.infrastructure.ClientError
import org.openapitools.client.infrastructure.ServerException
import org.openapitools.client.infrastructure.ServerError
import org.openapitools.client.infrastructure.MultiValueMap
import org.openapitools.client.infrastructure.RequestConfig
import org.openapitools.client.infrastructure.RequestMethod
import org.openapitools.client.infrastructure.ResponseType
import org.openapitools.client.infrastructure.Success
import org.openapitools.client.infrastructure.toMultiValue

class ChallengesApi(basePath: kotlin.String = defaultBasePath) : ApiClient(basePath) {
    companion object {
        @JvmStatic
        val defaultBasePath: String by lazy {
            System.getProperties().getProperty("org.openapitools.client.baseUrl", "https://lichess.org")
        }
    }

    /**
    * Admin challenge tokens
    * **For administrators only. You are not allowed to use this endpoint.**  Create and obtain &#x60;challenge:write&#x60; tokens for multiple users.  If a similar token already exists for a user, it is reused. This endpoint is idempotent. 
    * @param users Usernames separated with commas 
    * @param description User visible description of the token 
    * @return void
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun adminChallengeTokens(users: kotlin.String, description: kotlin.String) : Unit {
        val localVariableConfig = adminChallengeTokensRequestConfig(users = users, description = description)

        val localVarResponse = request<Map<String, Any?>, Unit>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> Unit
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation adminChallengeTokens
    *
    * @param users Usernames separated with commas 
    * @param description User visible description of the token 
    * @return RequestConfig
    */
    fun adminChallengeTokensRequestConfig(users: kotlin.String, description: kotlin.String) : RequestConfig<Map<String, Any?>> {
        val localVariableBody = mapOf("users" to users, "description" to description)
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf("Content-Type" to "application/x-www-form-urlencoded")

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/token/admin-challenge",
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Accept a challenge
    * Accept an incoming challenge.  You should receive a &#x60;gameStart&#x60; event on the [incoming events stream](#operation/apiStreamEvent). 
    * @param challengeId  
    * @return Ok
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun challengeAccept(challengeId: kotlin.String) : Ok {
        val localVariableConfig = challengeAcceptRequestConfig(challengeId = challengeId)

        val localVarResponse = request<Unit, Ok>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as Ok
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation challengeAccept
    *
    * @param challengeId  
    * @return RequestConfig
    */
    fun challengeAcceptRequestConfig(challengeId: kotlin.String) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/challenge/{challengeId}/accept".replace("{"+"challengeId"+"}", "$challengeId"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Challenge the AI
    * Start a game with Lichess AI.  You will be notified on the [event stream](#operation/apiStreamEvent) that a new game has started. 
    * @param level AI strength (optional)
    * @param clockLimit Clock initial time in seconds. If empty, a correspondence game is created. (optional)
    * @param clockIncrement Clock increment in seconds. If empty, a correspondence game is created. (optional)
    * @param days Days per move, for correspondence games. Clock settings must be omitted. (optional)
    * @param color Which color you get to play (optional, default to Color.random)
    * @param variant  (optional, default to VariantKey.standard)
    * @param fen Custom initial position (in FEN). Variant must be standard, and the game cannot be rated. (optional, default to "rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1")
    * @return GameJson
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun challengeAi(level: java.math.BigDecimal?, clockLimit: java.math.BigDecimal?, clockIncrement: kotlin.Int?, days: kotlin.Int?, color: kotlin.String?, variant: VariantKey?, fen: kotlin.String?) : GameJson {
        val localVariableConfig = challengeAiRequestConfig(level = level, clockLimit = clockLimit, clockIncrement = clockIncrement, days = days, color = color, variant = variant, fen = fen)

        val localVarResponse = request<Map<String, Any?>, GameJson>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as GameJson
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation challengeAi
    *
    * @param level AI strength (optional)
    * @param clockLimit Clock initial time in seconds. If empty, a correspondence game is created. (optional)
    * @param clockIncrement Clock increment in seconds. If empty, a correspondence game is created. (optional)
    * @param days Days per move, for correspondence games. Clock settings must be omitted. (optional)
    * @param color Which color you get to play (optional, default to Color.random)
    * @param variant  (optional, default to VariantKey.standard)
    * @param fen Custom initial position (in FEN). Variant must be standard, and the game cannot be rated. (optional, default to "rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1")
    * @return RequestConfig
    */
    fun challengeAiRequestConfig(level: java.math.BigDecimal?, clockLimit: java.math.BigDecimal?, clockIncrement: kotlin.Int?, days: kotlin.Int?, color: kotlin.String?, variant: VariantKey?, fen: kotlin.String?) : RequestConfig<Map<String, Any?>> {
        val localVariableBody = mapOf("level" to level, "clock.limit" to clockLimit, "clock.increment" to clockIncrement, "days" to days, "color" to color, "variant" to variant, "fen" to fen)
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf("Content-Type" to "application/x-www-form-urlencoded")

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/challenge/ai",
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Cancel a challenge
    * Cancel a challenge you sent, or aborts the game if the challenge was accepted, but the game was not yet played. Note that the ID of a game is the same as the ID of the challenge that created it. 
    * @param challengeId  
    * @param opponentToken Optional &#x60;challenge:write&#x60; token of the opponent. If set, the game can be canceled even if both players have moved. (optional)
    * @return Ok
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun challengeCancel(challengeId: kotlin.String, opponentToken: kotlin.String?) : Ok {
        val localVariableConfig = challengeCancelRequestConfig(challengeId = challengeId, opponentToken = opponentToken)

        val localVarResponse = request<Unit, Ok>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as Ok
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation challengeCancel
    *
    * @param challengeId  
    * @param opponentToken Optional &#x60;challenge:write&#x60; token of the opponent. If set, the game can be canceled even if both players have moved. (optional)
    * @return RequestConfig
    */
    fun challengeCancelRequestConfig(challengeId: kotlin.String, opponentToken: kotlin.String?) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf<kotlin.String, List<kotlin.String>>()
            .apply {
                if (opponentToken != null) {
                    put("opponentToken", listOf(opponentToken.toString()))
                }
            }
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/challenge/{challengeId}/cancel".replace("{"+"challengeId"+"}", "$challengeId"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Create a challenge
    * Challenge someone to play. The targeted player can choose to accept or decline.  If the challenge is accepted, you will be notified on the [event stream](#operation/apiStreamEvent) that a new game has started. The game ID will be the same as the challenge ID.  If you also have an OAuth token with &#x60;challenge:write&#x60; scope for the receiving user, you can make them accept the challenge immediately by setting the &#x60;acceptByToken&#x60; field.  Challenges for realtime games (not correspondence) expire after 20s if not accepted. To prevent that, use the &#x60;keepAliveStream&#x60; flag described below. 
    * @param username  
    * @param rated Game is rated and impacts players ratings (optional)
    * @param clockLimit Clock initial time in seconds. If empty, a correspondence game is created. (optional)
    * @param clockIncrement Clock increment in seconds. If empty, a correspondence game is created. (optional)
    * @param days Days per move, for correspondence games. Clock settings must be omitted. (optional)
    * @param color Which color you get to play (optional, default to random)
    * @param variant  (optional, default to VariantKey.standard)
    * @param fen Custom initial position (in FEN). Variant must be standard, and the game cannot be rated. Castling moves will use UCI_Chess960 notation, for example e1h1 instead of e1g1. (optional, default to "rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1")
    * @param keepAliveStream If set, the response is streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). The challenge is kept alive until the connection is closed by the client. When the challenge is accepted, declined or canceled, a message of the form &#x60;{\\\&quot;done\\\&quot;:\\\&quot;accepted\\\&quot;}&#x60; is sent, then the connection is closed by the server. If not set, the response is not streamed, and the challenge expires after 20s if not accepted.  (optional)
    * @param acceptByToken Immediately accept the challenge and create the game. Pass in an OAuth token (with the &#x60;challenge:write&#x60; scope) for the receiving user. On success, the response will contain a &#x60;game&#x60; field instead of a &#x60;challenge&#x60; field.  Alternatively, consider the [bulk pairing API](#operation/bulkPairingCreate).  (optional)
    * @param message **Only if &#x60;acceptByToken&#x60; is set.**  Message that is sent to each player, when the game is created. It is sent from your user account.  &#x60;{opponent}&#x60;, &#x60;{player}&#x60; and &#x60;{game}&#x60; are placeholders that will be replaced with the opponent name, player name, and the game URLs.  You can omit this field to send the default message, but if you set your own message, it must at least contain the &#x60;{game}&#x60; placeholder.  (optional, default to "Your game with {opponent} is ready: {game}.")
    * @return ChallengeJson
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun challengeCreate(username: kotlin.String, rated: kotlin.Boolean?, clockLimit: java.math.BigDecimal?, clockIncrement: kotlin.Int?, days: kotlin.Int?, color: kotlin.String?, variant: VariantKey?, fen: kotlin.String?, keepAliveStream: kotlin.Boolean?, acceptByToken: kotlin.String?, message: kotlin.String?) : ChallengeJson {
        val localVariableConfig = challengeCreateRequestConfig(username = username, rated = rated, clockLimit = clockLimit, clockIncrement = clockIncrement, days = days, color = color, variant = variant, fen = fen, keepAliveStream = keepAliveStream, acceptByToken = acceptByToken, message = message)

        val localVarResponse = request<Map<String, Any?>, ChallengeJson>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as ChallengeJson
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation challengeCreate
    *
    * @param username  
    * @param rated Game is rated and impacts players ratings (optional)
    * @param clockLimit Clock initial time in seconds. If empty, a correspondence game is created. (optional)
    * @param clockIncrement Clock increment in seconds. If empty, a correspondence game is created. (optional)
    * @param days Days per move, for correspondence games. Clock settings must be omitted. (optional)
    * @param color Which color you get to play (optional, default to random)
    * @param variant  (optional, default to VariantKey.standard)
    * @param fen Custom initial position (in FEN). Variant must be standard, and the game cannot be rated. Castling moves will use UCI_Chess960 notation, for example e1h1 instead of e1g1. (optional, default to "rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1")
    * @param keepAliveStream If set, the response is streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). The challenge is kept alive until the connection is closed by the client. When the challenge is accepted, declined or canceled, a message of the form &#x60;{\\\&quot;done\\\&quot;:\\\&quot;accepted\\\&quot;}&#x60; is sent, then the connection is closed by the server. If not set, the response is not streamed, and the challenge expires after 20s if not accepted.  (optional)
    * @param acceptByToken Immediately accept the challenge and create the game. Pass in an OAuth token (with the &#x60;challenge:write&#x60; scope) for the receiving user. On success, the response will contain a &#x60;game&#x60; field instead of a &#x60;challenge&#x60; field.  Alternatively, consider the [bulk pairing API](#operation/bulkPairingCreate).  (optional)
    * @param message **Only if &#x60;acceptByToken&#x60; is set.**  Message that is sent to each player, when the game is created. It is sent from your user account.  &#x60;{opponent}&#x60;, &#x60;{player}&#x60; and &#x60;{game}&#x60; are placeholders that will be replaced with the opponent name, player name, and the game URLs.  You can omit this field to send the default message, but if you set your own message, it must at least contain the &#x60;{game}&#x60; placeholder.  (optional, default to "Your game with {opponent} is ready: {game}.")
    * @return RequestConfig
    */
    fun challengeCreateRequestConfig(username: kotlin.String, rated: kotlin.Boolean?, clockLimit: java.math.BigDecimal?, clockIncrement: kotlin.Int?, days: kotlin.Int?, color: kotlin.String?, variant: VariantKey?, fen: kotlin.String?, keepAliveStream: kotlin.Boolean?, acceptByToken: kotlin.String?, message: kotlin.String?) : RequestConfig<Map<String, Any?>> {
        val localVariableBody = mapOf("rated" to rated, "clock.limit" to clockLimit, "clock.increment" to clockIncrement, "days" to days, "color" to color, "variant" to variant, "fen" to fen, "keepAliveStream" to keepAliveStream, "acceptByToken" to acceptByToken, "message" to message)
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf("Content-Type" to "application/x-www-form-urlencoded")

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/challenge/{username}".replace("{"+"username"+"}", "$username"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Decline a challenge
    * Decline an incoming challenge. 
    * @param challengeId  
    * @param reason Reason challenge was declined. It will be translated to the player&#39;s language. See [the full list in the translation file](https://github.com/ornicar/lila/blob/43fbd61029ff3960a21fbd213944bed66325696d/translation/source/challenge.xml#L14). (optional)
    * @return Ok
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun challengeDecline(challengeId: kotlin.String, reason: kotlin.String?) : Ok {
        val localVariableConfig = challengeDeclineRequestConfig(challengeId = challengeId, reason = reason)

        val localVarResponse = request<Map<String, Any?>, Ok>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as Ok
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation challengeDecline
    *
    * @param challengeId  
    * @param reason Reason challenge was declined. It will be translated to the player&#39;s language. See [the full list in the translation file](https://github.com/ornicar/lila/blob/43fbd61029ff3960a21fbd213944bed66325696d/translation/source/challenge.xml#L14). (optional)
    * @return RequestConfig
    */
    fun challengeDeclineRequestConfig(challengeId: kotlin.String, reason: kotlin.String?) : RequestConfig<Map<String, Any?>> {
        val localVariableBody = mapOf("reason" to reason)
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf("Content-Type" to "application/x-www-form-urlencoded")

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/challenge/{challengeId}/decline".replace("{"+"challengeId"+"}", "$challengeId"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * List your challenges
    * Get a list of challenges created by or targeted at you. 
    * @return InlineResponse2003
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun challengeList() : InlineResponse2003 {
        val localVariableConfig = challengeListRequestConfig()

        val localVarResponse = request<Unit, InlineResponse2003>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as InlineResponse2003
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation challengeList
    *
    * @return RequestConfig
    */
    fun challengeListRequestConfig() : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/api/challenge",
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Open-ended challenge
    * Create a challenge that any 2 players can join.  Share the URL of the challenge. the first 2 players to click it will be paired for a game.  The response body also contains &#x60;whiteUrl&#x60; and &#x60;blackUrl&#x60;. You can control which color each player gets by giving them these URLs, instead of the main challenge URL.  Open challenges expire after 24h.  To directly pair 2 known players, use [this endpoint](#operation/challengeCreate) instead, with the &#x60;acceptByToken&#x60; parameter. 
    * @param rated Game is rated and impacts players ratings (optional)
    * @param clockLimit Clock initial time in seconds. If empty, a correspondence game is created. (optional)
    * @param clockIncrement Clock increment in seconds. If empty, a correspondence game is created. (optional)
    * @param variant  (optional, default to VariantKey.standard)
    * @param fen Custom initial position (in FEN). Variant must be standard, and the game cannot be rated. (optional, default to "rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1")
    * @param name Optional name for the challenge, that players will see on the challenge page. (optional)
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun challengeOpen(rated: kotlin.Boolean?, clockLimit: java.math.BigDecimal?, clockIncrement: kotlin.Int?, variant: VariantKey?, fen: kotlin.String?, name: kotlin.String?) : kotlin.Any {
        val localVariableConfig = challengeOpenRequestConfig(rated = rated, clockLimit = clockLimit, clockIncrement = clockIncrement, variant = variant, fen = fen, name = name)

        val localVarResponse = request<Map<String, Any?>, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation challengeOpen
    *
    * @param rated Game is rated and impacts players ratings (optional)
    * @param clockLimit Clock initial time in seconds. If empty, a correspondence game is created. (optional)
    * @param clockIncrement Clock increment in seconds. If empty, a correspondence game is created. (optional)
    * @param variant  (optional, default to VariantKey.standard)
    * @param fen Custom initial position (in FEN). Variant must be standard, and the game cannot be rated. (optional, default to "rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR w KQkq - 0 1")
    * @param name Optional name for the challenge, that players will see on the challenge page. (optional)
    * @return RequestConfig
    */
    fun challengeOpenRequestConfig(rated: kotlin.Boolean?, clockLimit: java.math.BigDecimal?, clockIncrement: kotlin.Int?, variant: VariantKey?, fen: kotlin.String?, name: kotlin.String?) : RequestConfig<Map<String, Any?>> {
        val localVariableBody = mapOf("rated" to rated, "clock.limit" to clockLimit, "clock.increment" to clockIncrement, "variant" to variant, "fen" to fen, "name" to name)
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf("Content-Type" to "application/x-www-form-urlencoded")

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/challenge/open",
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Start clocks of a game
    * Start the clocks of a game immediately, even if a player has not yet made a move.  Requires the OAuth tokens of both players with &#x60;challenge:write&#x60; scope.  If the clocks have already started, the call will have no effect. 
    * @param gameId  
    * @param token1 OAuth token of a player (optional)
    * @param token2 OAuth token of the other player (optional)
    * @return Ok
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun challengeStartClocks(gameId: kotlin.String, token1: kotlin.String?, token2: kotlin.String?) : Ok {
        val localVariableConfig = challengeStartClocksRequestConfig(gameId = gameId, token1 = token1, token2 = token2)

        val localVarResponse = request<Unit, Ok>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as Ok
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation challengeStartClocks
    *
    * @param gameId  
    * @param token1 OAuth token of a player (optional)
    * @param token2 OAuth token of the other player (optional)
    * @return RequestConfig
    */
    fun challengeStartClocksRequestConfig(gameId: kotlin.String, token1: kotlin.String?, token2: kotlin.String?) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf<kotlin.String, List<kotlin.String>>()
            .apply {
                if (token1 != null) {
                    put("token1", listOf(token1.toString()))
                }
                if (token2 != null) {
                    put("token2", listOf(token2.toString()))
                }
            }
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/challenge/{gameId}/start-clocks".replace("{"+"gameId"+"}", "$gameId"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Add time to the opponent clock
    * Add seconds to the opponent&#39;s clock. Can be used to create games with time odds. 
    * @param gameId  
    * @param seconds How many seconds to give 
    * @return Ok
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun roundAddTime(gameId: kotlin.String, seconds: kotlin.String) : Ok {
        val localVariableConfig = roundAddTimeRequestConfig(gameId = gameId, seconds = seconds)

        val localVarResponse = request<Unit, Ok>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as Ok
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation roundAddTime
    *
    * @param gameId  
    * @param seconds How many seconds to give 
    * @return RequestConfig
    */
    fun roundAddTimeRequestConfig(gameId: kotlin.String, seconds: kotlin.String) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/round/{gameId}/add-time/{seconds}".replace("{"+"gameId"+"}", "$gameId").replace("{"+"seconds"+"}", "$seconds"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

}
