/**
 * Lichess.org API reference
 *
 * # Introduction Welcome to the reference for the Lichess API! Lichess is free/libre, open-source chess server powered by volunteers and donations. - Get help in the [Lichess Discord channel](https://discord.gg/lichess) - [Contribute to this documentation on Github](https://github.com/lichess-org/api) - Check out [Lichess widgets to embed in your website](https://lichess.org/developers) - [Download all Lichess rated games](https://database.lichess.org/) - [Download all Lichess puzzles with themes, ratings and votes](https://database.lichess.org/#puzzles)  ## Endpoint All requests go to `https://lichess.org` (unless otherwise specified).  ## Clients - [Python general API](https://github.com/ZackClements/berserk) - [MicroPython general API](https://github.com/mkomon/uberserk) - [Python general API - async](https://pypi.org/project/async-lichess-sdk) - [Python Lichess Bot](https://github.com/careless25/lichess-bot) - [Python Board API for Certabo](https://github.com/haklein/certabo-lichess) - [Java general API](https://github.com/tors42/chariot)  ## Rate limiting All requests are rate limited using various strategies, to ensure the API remains responsive for everyone. Only make one request at a time. If you receive an HTTP response with a [429 status](https://en.wikipedia.org/wiki/List_of_HTTP_status_codes#429), please wait a full minute before resuming API usage.  ## Streaming with ND-JSON Some API endpoints stream their responses as [Newline Delimited JSON a.k.a. **nd-json**](http://ndjson.org/), with one JSON object per line.  Here's a [JavaScript utility function](https://gist.github.com/ornicar/a097406810939cf7be1df8ea30e94f3e) to help reading NDJSON streamed responses. 
 *
 * The version of the OpenAPI document: 2.0.0
 * 
 *
 * Please note:
 * This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * Do not edit this file manually.
 */

@file:Suppress(
    "ArrayInDataClass",
    "EnumEntryName",
    "RemoveRedundantQualifierName",
    "UnusedImport"
)

package org.openapitools.client.apis

import org.openapitools.client.models.PerfType

import org.openapitools.client.infrastructure.ApiClient
import org.openapitools.client.infrastructure.ClientException
import org.openapitools.client.infrastructure.ClientError
import org.openapitools.client.infrastructure.ServerException
import org.openapitools.client.infrastructure.ServerError
import org.openapitools.client.infrastructure.MultiValueMap
import org.openapitools.client.infrastructure.RequestConfig
import org.openapitools.client.infrastructure.RequestMethod
import org.openapitools.client.infrastructure.ResponseType
import org.openapitools.client.infrastructure.Success
import org.openapitools.client.infrastructure.toMultiValue

class GamesApi(basePath: kotlin.String = defaultBasePath) : ApiClient(basePath) {
    companion object {
        @JvmStatic
        val defaultBasePath: String by lazy {
            System.getProperties().getProperty("org.openapitools.client.baseUrl", "https://lichess.org")
        }
    }

    /**
    * Get my ongoing games
    * Get the ongoing games of the current user. Real-time and correspondence games are included. The most urgent games are listed first. 
    * @param nb Max number of games to fetch (optional, default to 9)
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun apiAccountPlaying(nb: kotlin.Int?) : kotlin.Any {
        val localVariableConfig = apiAccountPlayingRequestConfig(nb = nb)

        val localVarResponse = request<Unit, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation apiAccountPlaying
    *
    * @param nb Max number of games to fetch (optional, default to 9)
    * @return RequestConfig
    */
    fun apiAccountPlayingRequestConfig(nb: kotlin.Int?) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf<kotlin.String, List<kotlin.String>>()
            .apply {
                if (nb != null) {
                    put("nb", listOf(nb.toString()))
                }
            }
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/api/account/playing",
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Export games of a user
    * Download all games of any user in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (most recent first)  We recommend streaming the response, for it can be very long. &lt;https://lichess.org/@/german11&gt; for instance has more than 320,000 games.  The game stream is throttled, depending on who is making the request:   - Anonymous request: 20 games per second   - [OAuth2 authenticated](#section/Authentication) request: 30 games per second   - Authenticated, downloading your own games: 60 games per second 
    * @param username The user name. 
    * @param since Download games played since this timestamp. (optional)
    * @param until Download games played until this timestamp. (optional)
    * @param max How many games to download. Leave empty to download all games. (optional)
    * @param vs [Filter] Only games played against this opponent (optional)
    * @param rated [Filter] Only rated (&#x60;true&#x60;) or casual (&#x60;false&#x60;) games (optional)
    * @param perfType [Filter] Only games in these speeds or variants.   Multiple perf types can be specified, separated by a comma.   Example: blitz,rapid,classical (optional)
    * @param color [Filter] Only games played as this color. (optional, default to null)
    * @param analysed [Filter] Only games with or without a computer analysis available (optional)
    * @param moves Include the PGN moves. (optional, default to true)
    * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. The response type must be set to &#x60;application/x-ndjson&#x60; by the request &#x60;Accept&#x60; header. (optional, default to false)
    * @param tags Include the PGN tags. (optional, default to true)
    * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  (optional, default to false)
    * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  (optional, default to false)
    * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  (optional, default to false)
    * @param ongoing Include ongoing games. The last 3 moves will be omitted. (optional, default to false)
    * @param finished Include finished games. Set to &#x60;false&#x60; to only get ongoing games. (optional, default to true)
    * @param players URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt;  (optional)
    * @param sort Sort order of the games. (optional, default to dateDesc)
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun apiGamesUser(username: kotlin.String, since: kotlin.Int?, until: kotlin.Int?, max: kotlin.Int?, vs: kotlin.String?, rated: kotlin.Boolean?, perfType: PerfType?, color: kotlin.String?, analysed: kotlin.Boolean?, moves: kotlin.Boolean?, pgnInJson: kotlin.Boolean?, tags: kotlin.Boolean?, clocks: kotlin.Boolean?, evals: kotlin.Boolean?, opening: kotlin.Boolean?, ongoing: kotlin.Boolean?, finished: kotlin.Boolean?, players: kotlin.String?, sort: kotlin.String?) : kotlin.Any {
        val localVariableConfig = apiGamesUserRequestConfig(username = username, since = since, until = until, max = max, vs = vs, rated = rated, perfType = perfType, color = color, analysed = analysed, moves = moves, pgnInJson = pgnInJson, tags = tags, clocks = clocks, evals = evals, opening = opening, ongoing = ongoing, finished = finished, players = players, sort = sort)

        val localVarResponse = request<Unit, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation apiGamesUser
    *
    * @param username The user name. 
    * @param since Download games played since this timestamp. (optional)
    * @param until Download games played until this timestamp. (optional)
    * @param max How many games to download. Leave empty to download all games. (optional)
    * @param vs [Filter] Only games played against this opponent (optional)
    * @param rated [Filter] Only rated (&#x60;true&#x60;) or casual (&#x60;false&#x60;) games (optional)
    * @param perfType [Filter] Only games in these speeds or variants.   Multiple perf types can be specified, separated by a comma.   Example: blitz,rapid,classical (optional)
    * @param color [Filter] Only games played as this color. (optional, default to null)
    * @param analysed [Filter] Only games with or without a computer analysis available (optional)
    * @param moves Include the PGN moves. (optional, default to true)
    * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. The response type must be set to &#x60;application/x-ndjson&#x60; by the request &#x60;Accept&#x60; header. (optional, default to false)
    * @param tags Include the PGN tags. (optional, default to true)
    * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  (optional, default to false)
    * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  (optional, default to false)
    * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  (optional, default to false)
    * @param ongoing Include ongoing games. The last 3 moves will be omitted. (optional, default to false)
    * @param finished Include finished games. Set to &#x60;false&#x60; to only get ongoing games. (optional, default to true)
    * @param players URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt;  (optional)
    * @param sort Sort order of the games. (optional, default to dateDesc)
    * @return RequestConfig
    */
    fun apiGamesUserRequestConfig(username: kotlin.String, since: kotlin.Int?, until: kotlin.Int?, max: kotlin.Int?, vs: kotlin.String?, rated: kotlin.Boolean?, perfType: PerfType?, color: kotlin.String?, analysed: kotlin.Boolean?, moves: kotlin.Boolean?, pgnInJson: kotlin.Boolean?, tags: kotlin.Boolean?, clocks: kotlin.Boolean?, evals: kotlin.Boolean?, opening: kotlin.Boolean?, ongoing: kotlin.Boolean?, finished: kotlin.Boolean?, players: kotlin.String?, sort: kotlin.String?) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf<kotlin.String, List<kotlin.String>>()
            .apply {
                if (since != null) {
                    put("since", listOf(since.toString()))
                }
                if (until != null) {
                    put("until", listOf(until.toString()))
                }
                if (max != null) {
                    put("max", listOf(max.toString()))
                }
                if (vs != null) {
                    put("vs", listOf(vs.toString()))
                }
                if (rated != null) {
                    put("rated", listOf(rated.toString()))
                }
                if (perfType != null) {
                    put("perfType", listOf(perfType.toString()))
                }
                if (color != null) {
                    put("color", listOf(color.toString()))
                }
                if (analysed != null) {
                    put("analysed", listOf(analysed.toString()))
                }
                if (moves != null) {
                    put("moves", listOf(moves.toString()))
                }
                if (pgnInJson != null) {
                    put("pgnInJson", listOf(pgnInJson.toString()))
                }
                if (tags != null) {
                    put("tags", listOf(tags.toString()))
                }
                if (clocks != null) {
                    put("clocks", listOf(clocks.toString()))
                }
                if (evals != null) {
                    put("evals", listOf(evals.toString()))
                }
                if (opening != null) {
                    put("opening", listOf(opening.toString()))
                }
                if (ongoing != null) {
                    put("ongoing", listOf(ongoing.toString()))
                }
                if (finished != null) {
                    put("finished", listOf(finished.toString()))
                }
                if (players != null) {
                    put("players", listOf(players.toString()))
                }
                if (sort != null) {
                    put("sort", listOf(sort.toString()))
                }
            }
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/api/games/user/{username}".replace("{"+"username"+"}", "$username"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Export ongoing game of a user
    * Download the ongoing game, or the last game played, of a user. Available in either PGN or JSON format. If the game is ongoing, the 3 last moves are omitted. 
    * @param username  
    * @param moves Include the PGN moves. (optional, default to true)
    * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. (optional, default to false)
    * @param tags Include the PGN tags. (optional, default to true)
    * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  (optional, default to true)
    * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  (optional, default to true)
    * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  (optional, default to true)
    * @param literate Insert textual annotations in the PGN about the opening, analysis variations, mistakes, and game termination.  Example: &#x60;5... g4? { (-0.98 → 0.60) Mistake. Best move was h6. } (5... h6 6. d4 Ne7 7. g3 d5 8. exd5 fxg3 9. hxg3 c6 10. dxc6)&#x60;  (optional, default to false)
    * @param players URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt;  (optional)
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun apiUserCurrentGame(username: kotlin.String, moves: kotlin.Boolean?, pgnInJson: kotlin.Boolean?, tags: kotlin.Boolean?, clocks: kotlin.Boolean?, evals: kotlin.Boolean?, opening: kotlin.Boolean?, literate: kotlin.Boolean?, players: kotlin.String?) : kotlin.Any {
        val localVariableConfig = apiUserCurrentGameRequestConfig(username = username, moves = moves, pgnInJson = pgnInJson, tags = tags, clocks = clocks, evals = evals, opening = opening, literate = literate, players = players)

        val localVarResponse = request<Unit, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation apiUserCurrentGame
    *
    * @param username  
    * @param moves Include the PGN moves. (optional, default to true)
    * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. (optional, default to false)
    * @param tags Include the PGN tags. (optional, default to true)
    * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  (optional, default to true)
    * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  (optional, default to true)
    * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  (optional, default to true)
    * @param literate Insert textual annotations in the PGN about the opening, analysis variations, mistakes, and game termination.  Example: &#x60;5... g4? { (-0.98 → 0.60) Mistake. Best move was h6. } (5... h6 6. d4 Ne7 7. g3 d5 8. exd5 fxg3 9. hxg3 c6 10. dxc6)&#x60;  (optional, default to false)
    * @param players URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt;  (optional)
    * @return RequestConfig
    */
    fun apiUserCurrentGameRequestConfig(username: kotlin.String, moves: kotlin.Boolean?, pgnInJson: kotlin.Boolean?, tags: kotlin.Boolean?, clocks: kotlin.Boolean?, evals: kotlin.Boolean?, opening: kotlin.Boolean?, literate: kotlin.Boolean?, players: kotlin.String?) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf<kotlin.String, List<kotlin.String>>()
            .apply {
                if (moves != null) {
                    put("moves", listOf(moves.toString()))
                }
                if (pgnInJson != null) {
                    put("pgnInJson", listOf(pgnInJson.toString()))
                }
                if (tags != null) {
                    put("tags", listOf(tags.toString()))
                }
                if (clocks != null) {
                    put("clocks", listOf(clocks.toString()))
                }
                if (evals != null) {
                    put("evals", listOf(evals.toString()))
                }
                if (opening != null) {
                    put("opening", listOf(opening.toString()))
                }
                if (literate != null) {
                    put("literate", listOf(literate.toString()))
                }
                if (players != null) {
                    put("players", listOf(players.toString()))
                }
            }
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/api/user/{username}/current-game".replace("{"+"username"+"}", "$username"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Import one game
    * Import a game from PGN. See &lt;https://lichess.org/paste&gt;.  Rate limiting: 200 games per hour for OAuth requests, 100 games per hour for anonymous requests.  To broadcast ongoing games, consider [pushing to a broadcast instead](#operation/broadcastPush). 
    * @param pgn The PGN. It can contain only one game. Most standard tags are supported. (optional)
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun gameImport(pgn: kotlin.String?) : kotlin.Any {
        val localVariableConfig = gameImportRequestConfig(pgn = pgn)

        val localVarResponse = request<Map<String, Any?>, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation gameImport
    *
    * @param pgn The PGN. It can contain only one game. Most standard tags are supported. (optional)
    * @return RequestConfig
    */
    fun gameImportRequestConfig(pgn: kotlin.String?) : RequestConfig<Map<String, Any?>> {
        val localVariableBody = mapOf("pgn" to pgn)
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf("Content-Type" to "application/x-www-form-urlencoded")

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/import",
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Export one game
    * Download one game in either PGN or JSON format.  Ongoing games have their last 3 moves omitted, after move 5. 
    * @param gameId The game ID (8 characters). 
    * @param moves Include the PGN moves. (optional, default to true)
    * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. (optional, default to false)
    * @param tags Include the PGN tags. (optional, default to true)
    * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  (optional, default to true)
    * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  (optional, default to true)
    * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  (optional, default to true)
    * @param literate Insert textual annotations in the PGN about the opening, analysis variations, mistakes, and game termination.  Example: &#x60;5... g4? { (-0.98 → 0.60) Mistake. Best move was h6. } (5... h6 6. d4 Ne7 7. g3 d5 8. exd5 fxg3 9. hxg3 c6 10. dxc6)&#x60;  (optional, default to false)
    * @param players URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt;  (optional)
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun gamePgn(gameId: kotlin.String, moves: kotlin.Boolean?, pgnInJson: kotlin.Boolean?, tags: kotlin.Boolean?, clocks: kotlin.Boolean?, evals: kotlin.Boolean?, opening: kotlin.Boolean?, literate: kotlin.Boolean?, players: kotlin.String?) : kotlin.Any {
        val localVariableConfig = gamePgnRequestConfig(gameId = gameId, moves = moves, pgnInJson = pgnInJson, tags = tags, clocks = clocks, evals = evals, opening = opening, literate = literate, players = players)

        val localVarResponse = request<Unit, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation gamePgn
    *
    * @param gameId The game ID (8 characters). 
    * @param moves Include the PGN moves. (optional, default to true)
    * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. (optional, default to false)
    * @param tags Include the PGN tags. (optional, default to true)
    * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  (optional, default to true)
    * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  (optional, default to true)
    * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  (optional, default to true)
    * @param literate Insert textual annotations in the PGN about the opening, analysis variations, mistakes, and game termination.  Example: &#x60;5... g4? { (-0.98 → 0.60) Mistake. Best move was h6. } (5... h6 6. d4 Ne7 7. g3 d5 8. exd5 fxg3 9. hxg3 c6 10. dxc6)&#x60;  (optional, default to false)
    * @param players URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt;  (optional)
    * @return RequestConfig
    */
    fun gamePgnRequestConfig(gameId: kotlin.String, moves: kotlin.Boolean?, pgnInJson: kotlin.Boolean?, tags: kotlin.Boolean?, clocks: kotlin.Boolean?, evals: kotlin.Boolean?, opening: kotlin.Boolean?, literate: kotlin.Boolean?, players: kotlin.String?) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf<kotlin.String, List<kotlin.String>>()
            .apply {
                if (moves != null) {
                    put("moves", listOf(moves.toString()))
                }
                if (pgnInJson != null) {
                    put("pgnInJson", listOf(pgnInJson.toString()))
                }
                if (tags != null) {
                    put("tags", listOf(tags.toString()))
                }
                if (clocks != null) {
                    put("clocks", listOf(clocks.toString()))
                }
                if (evals != null) {
                    put("evals", listOf(evals.toString()))
                }
                if (opening != null) {
                    put("opening", listOf(opening.toString()))
                }
                if (literate != null) {
                    put("literate", listOf(literate.toString()))
                }
                if (players != null) {
                    put("players", listOf(players.toString()))
                }
            }
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/game/export/{gameId}".replace("{"+"gameId"+"}", "$gameId"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Stream games of users
    * Stream the games played between a list of users, in real time. Only games where **both players** are part of the list are included.  By default, games are only sent to the stream when they start. To also get all ongoing games at the beginning of the stream, use the &#x60;withCurrentGames&#x60; flag.  Maximum number of users: 300.  Games are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  The method is &#x60;POST&#x60; so a longer list of IDs can be sent in the request body. 
    * @param body Up to 300 user IDs separated by commas. 
    * @param withCurrentGames Include the already started games at the beginning of the stream. (optional, default to false)
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun gamesByUsers(body: kotlin.String, withCurrentGames: kotlin.Boolean?) : kotlin.Any {
        val localVariableConfig = gamesByUsersRequestConfig(body = body, withCurrentGames = withCurrentGames)

        val localVarResponse = request<kotlin.String, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation gamesByUsers
    *
    * @param body Up to 300 user IDs separated by commas. 
    * @param withCurrentGames Include the already started games at the beginning of the stream. (optional, default to false)
    * @return RequestConfig
    */
    fun gamesByUsersRequestConfig(body: kotlin.String, withCurrentGames: kotlin.Boolean?) : RequestConfig<kotlin.String> {
        val localVariableBody = body
        val localVariableQuery: MultiValueMap = mutableMapOf<kotlin.String, List<kotlin.String>>()
            .apply {
                if (withCurrentGames != null) {
                    put("withCurrentGames", listOf(withCurrentGames.toString()))
                }
            }
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/stream/games-by-users",
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Export games by IDs
    * Download games by IDs in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format, depending on the request Accept header.  Games are sorted by reverse chronological order (most recent first)  The method is &#x60;POST&#x60; so a longer list of IDs can be sent in the request body.  300 IDs can be submitted.  Ongoing games have their last 3 moves omitted, after move 5. 
    * @param body Game IDs separated by commas. Up to 300. 
    * @param moves Include the PGN moves. (optional, default to true)
    * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. (optional, default to false)
    * @param tags Include the PGN tags. (optional, default to true)
    * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  (optional, default to false)
    * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  (optional, default to false)
    * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  (optional, default to false)
    * @param players URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt;  (optional)
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun gamesExportIds(body: kotlin.String, moves: kotlin.Boolean?, pgnInJson: kotlin.Boolean?, tags: kotlin.Boolean?, clocks: kotlin.Boolean?, evals: kotlin.Boolean?, opening: kotlin.Boolean?, players: kotlin.String?) : kotlin.Any {
        val localVariableConfig = gamesExportIdsRequestConfig(body = body, moves = moves, pgnInJson = pgnInJson, tags = tags, clocks = clocks, evals = evals, opening = opening, players = players)

        val localVarResponse = request<kotlin.String, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation gamesExportIds
    *
    * @param body Game IDs separated by commas. Up to 300. 
    * @param moves Include the PGN moves. (optional, default to true)
    * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. (optional, default to false)
    * @param tags Include the PGN tags. (optional, default to true)
    * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  (optional, default to false)
    * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  (optional, default to false)
    * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  (optional, default to false)
    * @param players URL of a text file containing real names and ratings, to replace Lichess usernames and ratings in the PGN. Example: &lt;https://gist.githubusercontent.com/ornicar/6bfa91eb61a2dcae7bcd14cce1b2a4eb/raw/768b9f6cc8a8471d2555e47ba40fb0095e5fba37/gistfile1.txt&gt;  (optional)
    * @return RequestConfig
    */
    fun gamesExportIdsRequestConfig(body: kotlin.String, moves: kotlin.Boolean?, pgnInJson: kotlin.Boolean?, tags: kotlin.Boolean?, clocks: kotlin.Boolean?, evals: kotlin.Boolean?, opening: kotlin.Boolean?, players: kotlin.String?) : RequestConfig<kotlin.String> {
        val localVariableBody = body
        val localVariableQuery: MultiValueMap = mutableMapOf<kotlin.String, List<kotlin.String>>()
            .apply {
                if (moves != null) {
                    put("moves", listOf(moves.toString()))
                }
                if (pgnInJson != null) {
                    put("pgnInJson", listOf(pgnInJson.toString()))
                }
                if (tags != null) {
                    put("tags", listOf(tags.toString()))
                }
                if (clocks != null) {
                    put("clocks", listOf(clocks.toString()))
                }
                if (evals != null) {
                    put("evals", listOf(evals.toString()))
                }
                if (opening != null) {
                    put("opening", listOf(opening.toString()))
                }
                if (players != null) {
                    put("players", listOf(players.toString()))
                }
            }
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/games/export/_ids",
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Stream moves of a game
    * Stream positions and moves of any ongoing game, in [ndjson](#section/Introduction/Streaming-with-ND-JSON).  A description of the game is sent as a first message. Then a message is sent each time a move is played. Finally a description of the game is sent when it finishes, and the stream is closed.  After move 5, the stream intentionally remains 3 moves behind the game status, as to prevent cheat bots from using this API.  No more than 8 game streams can be opened at the same time from the same IP address. 
    * @param id  
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun streamGame(id: kotlin.String) : kotlin.Any {
        val localVariableConfig = streamGameRequestConfig(id = id)

        val localVarResponse = request<Unit, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation streamGame
    *
    * @param id  
    * @return RequestConfig
    */
    fun streamGameRequestConfig(id: kotlin.String) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/api/stream/game/{id}".replace("{"+"id"+"}", "$id"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

}
