/**
 * Lichess.org API reference
 *
 * # Introduction Welcome to the reference for the Lichess API! Lichess is free/libre, open-source chess server powered by volunteers and donations. - Get help in the [Lichess Discord channel](https://discord.gg/lichess) - [Contribute to this documentation on Github](https://github.com/lichess-org/api) - Check out [Lichess widgets to embed in your website](https://lichess.org/developers) - [Download all Lichess rated games](https://database.lichess.org/) - [Download all Lichess puzzles with themes, ratings and votes](https://database.lichess.org/#puzzles)  ## Endpoint All requests go to `https://lichess.org` (unless otherwise specified).  ## Clients - [Python general API](https://github.com/ZackClements/berserk) - [MicroPython general API](https://github.com/mkomon/uberserk) - [Python general API - async](https://pypi.org/project/async-lichess-sdk) - [Python Lichess Bot](https://github.com/careless25/lichess-bot) - [Python Board API for Certabo](https://github.com/haklein/certabo-lichess) - [Java general API](https://github.com/tors42/chariot)  ## Rate limiting All requests are rate limited using various strategies, to ensure the API remains responsive for everyone. Only make one request at a time. If you receive an HTTP response with a [429 status](https://en.wikipedia.org/wiki/List_of_HTTP_status_codes#429), please wait a full minute before resuming API usage.  ## Streaming with ND-JSON Some API endpoints stream their responses as [Newline Delimited JSON a.k.a. **nd-json**](http://ndjson.org/), with one JSON object per line.  Here's a [JavaScript utility function](https://gist.github.com/ornicar/a097406810939cf7be1df8ea30e94f3e) to help reading NDJSON streamed responses. 
 *
 * The version of the OpenAPI document: 2.0.0
 * 
 *
 * Please note:
 * This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * Do not edit this file manually.
 */

@file:Suppress(
    "ArrayInDataClass",
    "EnumEntryName",
    "RemoveRedundantQualifierName",
    "UnusedImport"
)

package org.openapitools.client.apis

import org.openapitools.client.models.Error

import org.openapitools.client.infrastructure.ApiClient
import org.openapitools.client.infrastructure.ClientException
import org.openapitools.client.infrastructure.ClientError
import org.openapitools.client.infrastructure.ServerException
import org.openapitools.client.infrastructure.ServerError
import org.openapitools.client.infrastructure.MultiValueMap
import org.openapitools.client.infrastructure.RequestConfig
import org.openapitools.client.infrastructure.RequestMethod
import org.openapitools.client.infrastructure.ResponseType
import org.openapitools.client.infrastructure.Success
import org.openapitools.client.infrastructure.toMultiValue

class OAuthApi(basePath: kotlin.String = defaultBasePath) : ApiClient(basePath) {
    companion object {
        @JvmStatic
        val defaultBasePath: String by lazy {
            System.getProperties().getProperty("org.openapitools.client.baseUrl", "https://lichess.org")
        }
    }

    /**
    * Obtain access token
    * OAuth2 token endpoint. Exchanges an authorization code for an access token. 
    * @param grantType Must be &#x60;authorization_code&#x60;. (optional)
    * @param code The authorization code that was sent in the &#x60;code&#x60; parameter to your &#x60;redirect_uri&#x60;. (optional)
    * @param codeVerifier A &#x60;code_challenge&#x60; was used to request the authorization code. This must be the &#x60;code_verifier&#x60; it was derived from. (optional)
    * @param redirectUri Must match the &#x60;redirect_uri&#x60; used to request the authorization code. (optional)
    * @param clientId Must match the &#x60;client_id&#x60; used to request the authorization code. (optional)
    * @return void
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun apiToken(grantType: kotlin.String?, code: kotlin.String?, codeVerifier: kotlin.String?, redirectUri: kotlin.String?, clientId: kotlin.String?) : Unit {
        val localVariableConfig = apiTokenRequestConfig(grantType = grantType, code = code, codeVerifier = codeVerifier, redirectUri = redirectUri, clientId = clientId)

        val localVarResponse = request<Map<String, Any?>, Unit>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> Unit
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation apiToken
    *
    * @param grantType Must be &#x60;authorization_code&#x60;. (optional)
    * @param code The authorization code that was sent in the &#x60;code&#x60; parameter to your &#x60;redirect_uri&#x60;. (optional)
    * @param codeVerifier A &#x60;code_challenge&#x60; was used to request the authorization code. This must be the &#x60;code_verifier&#x60; it was derived from. (optional)
    * @param redirectUri Must match the &#x60;redirect_uri&#x60; used to request the authorization code. (optional)
    * @param clientId Must match the &#x60;client_id&#x60; used to request the authorization code. (optional)
    * @return RequestConfig
    */
    fun apiTokenRequestConfig(grantType: kotlin.String?, code: kotlin.String?, codeVerifier: kotlin.String?, redirectUri: kotlin.String?, clientId: kotlin.String?) : RequestConfig<Map<String, Any?>> {
        val localVariableBody = mapOf("grant_type" to grantType, "code" to code, "code_verifier" to codeVerifier, "redirect_uri" to redirectUri, "client_id" to clientId)
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf("Content-Type" to "application/x-www-form-urlencoded")

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/token",
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Revoke access token
    * Revokes the access token sent as Bearer for this request.
    * @return void
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun apiTokenDelete() : Unit {
        val localVariableConfig = apiTokenDeleteRequestConfig()

        val localVarResponse = request<Unit, Unit>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> Unit
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation apiTokenDelete
    *
    * @return RequestConfig
    */
    fun apiTokenDeleteRequestConfig() : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.DELETE,
            path = "/api/token",
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Request authorization code
    * OAuth2 authorization endpoint.  Start the OAuth2 Authorization Code Flow with PKCE by securely generating two random strings unique to each authorization request: * &#x60;code_verifier&#x60; * &#x60;state&#x60;  Store these in session storage. Make sure not to reveal &#x60;code_verifier&#x60; to eavesdroppers. Do not show it in URLs, do not abuse &#x60;state&#x60; to store it, do not send it over insecure connections. However it is fine if the user themselves can extract &#x60;code_verifier&#x60;, which will always be possible for fully client-side apps.  Then send the user to this endpoint. They will be prompted to grant authorization and then be redirected back to the given &#x60;redirect_uri&#x60;.  If the authorization failed, the following query string parameters will be appended to the redirection: * &#x60;error&#x60;, in particular with value &#x60;access_denied&#x60; if the user    cancelled authorization * &#x60;error_description&#x60; to aid debugging * &#x60;state&#x60;, exactly as passed in the &#x60;state&#x60; parameter  If the authorization succeeded, the following query string parameters will be appended to the redirection: * &#x60;code&#x60;, containing a fresh short-lived authorization code * &#x60;state&#x60;, exactly as passed in the &#x60;state&#x60; parameter  Next, to defend against cross site request forgery, check that the returned &#x60;state&#x60; matches the &#x60;state&#x60; you originally generated.  Finally, continue by using the authorization code to [obtain an access token](#operation/apiToken). 
    * @param responseType Must be &#x60;code&#x60;. 
    * @param clientId Arbitrary identifier that uniquely identifies your application. 
    * @param redirectUri The absolute URL that the user should be redirected to with the authorization result. 
    * @param codeChallengeMethod Must be &#x60;S256&#x60;. 
    * @param codeChallenge Compute &#x60;BASE64URL(SHA256(code_verifier))&#x60;. 
    * @param scope Space separated list of requested OAuth scopes, if any. (optional)
    * @param state Arbitrary state that will be returned verbatim with the authorization result. (optional)
    * @return void
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun oauth(responseType: kotlin.String, clientId: kotlin.String, redirectUri: kotlin.String, codeChallengeMethod: kotlin.String, codeChallenge: kotlin.String, scope: kotlin.String?, state: kotlin.String?) : Unit {
        val localVariableConfig = oauthRequestConfig(responseType = responseType, clientId = clientId, redirectUri = redirectUri, codeChallengeMethod = codeChallengeMethod, codeChallenge = codeChallenge, scope = scope, state = state)

        val localVarResponse = request<Unit, Unit>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> Unit
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation oauth
    *
    * @param responseType Must be &#x60;code&#x60;. 
    * @param clientId Arbitrary identifier that uniquely identifies your application. 
    * @param redirectUri The absolute URL that the user should be redirected to with the authorization result. 
    * @param codeChallengeMethod Must be &#x60;S256&#x60;. 
    * @param codeChallenge Compute &#x60;BASE64URL(SHA256(code_verifier))&#x60;. 
    * @param scope Space separated list of requested OAuth scopes, if any. (optional)
    * @param state Arbitrary state that will be returned verbatim with the authorization result. (optional)
    * @return RequestConfig
    */
    fun oauthRequestConfig(responseType: kotlin.String, clientId: kotlin.String, redirectUri: kotlin.String, codeChallengeMethod: kotlin.String, codeChallenge: kotlin.String, scope: kotlin.String?, state: kotlin.String?) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf<kotlin.String, List<kotlin.String>>()
            .apply {
                put("response_type", listOf(responseType.toString()))
                put("client_id", listOf(clientId.toString()))
                put("redirect_uri", listOf(redirectUri.toString()))
                put("code_challenge_method", listOf(codeChallengeMethod.toString()))
                put("code_challenge", listOf(codeChallenge.toString()))
                if (scope != null) {
                    put("scope", listOf(scope.toString()))
                }
                if (state != null) {
                    put("state", listOf(state.toString()))
                }
            }
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/oauth",
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

}
