/**
 * Lichess.org API reference
 *
 * # Introduction Welcome to the reference for the Lichess API! Lichess is free/libre, open-source chess server powered by volunteers and donations. - Get help in the [Lichess Discord channel](https://discord.gg/lichess) - [Contribute to this documentation on Github](https://github.com/lichess-org/api) - Check out [Lichess widgets to embed in your website](https://lichess.org/developers) - [Download all Lichess rated games](https://database.lichess.org/) - [Download all Lichess puzzles with themes, ratings and votes](https://database.lichess.org/#puzzles)  ## Endpoint All requests go to `https://lichess.org` (unless otherwise specified).  ## Clients - [Python general API](https://github.com/ZackClements/berserk) - [MicroPython general API](https://github.com/mkomon/uberserk) - [Python general API - async](https://pypi.org/project/async-lichess-sdk) - [Python Lichess Bot](https://github.com/careless25/lichess-bot) - [Python Board API for Certabo](https://github.com/haklein/certabo-lichess) - [Java general API](https://github.com/tors42/chariot)  ## Rate limiting All requests are rate limited using various strategies, to ensure the API remains responsive for everyone. Only make one request at a time. If you receive an HTTP response with a [429 status](https://en.wikipedia.org/wiki/List_of_HTTP_status_codes#429), please wait a full minute before resuming API usage.  ## Streaming with ND-JSON Some API endpoints stream their responses as [Newline Delimited JSON a.k.a. **nd-json**](http://ndjson.org/), with one JSON object per line.  Here's a [JavaScript utility function](https://gist.github.com/ornicar/a097406810939cf7be1df8ea30e94f3e) to help reading NDJSON streamed responses. 
 *
 * The version of the OpenAPI document: 2.0.0
 * 
 *
 * Please note:
 * This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * Do not edit this file manually.
 */

@file:Suppress(
    "ArrayInDataClass",
    "EnumEntryName",
    "RemoveRedundantQualifierName",
    "UnusedImport"
)

package org.openapitools.client.apis

import org.openapitools.client.models.Speed
import org.openapitools.client.models.VariantKey

import org.openapitools.client.infrastructure.ApiClient
import org.openapitools.client.infrastructure.ClientException
import org.openapitools.client.infrastructure.ClientError
import org.openapitools.client.infrastructure.ServerException
import org.openapitools.client.infrastructure.ServerError
import org.openapitools.client.infrastructure.MultiValueMap
import org.openapitools.client.infrastructure.RequestConfig
import org.openapitools.client.infrastructure.RequestMethod
import org.openapitools.client.infrastructure.ResponseType
import org.openapitools.client.infrastructure.Success
import org.openapitools.client.infrastructure.toMultiValue

class OpeningExplorerApi(basePath: kotlin.String = defaultBasePath) : ApiClient(basePath) {
    companion object {
        @JvmStatic
        val defaultBasePath: String by lazy {
            System.getProperties().getProperty("org.openapitools.client.baseUrl", "https://lichess.org")
        }
    }

    /**
    * Lichess games
    * **Endpoint: &lt;https://explorer.lichess.ovh/lichess&gt;**  Games sampled from all Lichess players.  Example: &#x60;curl https://explorer.lichess.ovh/lichess?variant&#x3D;standard&amp;speeds&#x3D;blitz,rapid,classical&amp;ratings&#x3D;2200,2500&amp;fen&#x3D;rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR%20w%20KQkq%20-%200%201&#x60; 
    * @param variant Variant (optional, default to standard)
    * @param fen FEN of the root position (optional)
    * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  (optional, default to "")
    * @param speeds Comma separated list of game speeds to look for (optional)
    * @param ratings Comma separated list of rating groups, ranging from their value to the next higher group (optional)
    * @param since Include only games from this month or later (optional, default to "0000-01")
    * @param until Include only games from this month or earlier (optional, default to "3000-12")
    * @param moves Number of most common moves to display (optional, default to 12)
    * @param topGames Number of top games to display (optional, default to 4)
    * @param recentGames Number of recent games to display (optional, default to 4)
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun openingExplorerLichess(variant: VariantKey?, fen: kotlin.String?, play: kotlin.String?, speeds: kotlin.collections.List<Speed>?, ratings: kotlin.collections.List<java.math.BigDecimal>?, since: kotlin.String?, until: kotlin.String?, moves: java.math.BigDecimal?, topGames: java.math.BigDecimal?, recentGames: java.math.BigDecimal?) : kotlin.Any {
        val localVariableConfig = openingExplorerLichessRequestConfig(variant = variant, fen = fen, play = play, speeds = speeds, ratings = ratings, since = since, until = until, moves = moves, topGames = topGames, recentGames = recentGames)

        val localVarResponse = request<Unit, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation openingExplorerLichess
    *
    * @param variant Variant (optional, default to standard)
    * @param fen FEN of the root position (optional)
    * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  (optional, default to "")
    * @param speeds Comma separated list of game speeds to look for (optional)
    * @param ratings Comma separated list of rating groups, ranging from their value to the next higher group (optional)
    * @param since Include only games from this month or later (optional, default to "0000-01")
    * @param until Include only games from this month or earlier (optional, default to "3000-12")
    * @param moves Number of most common moves to display (optional, default to 12)
    * @param topGames Number of top games to display (optional, default to 4)
    * @param recentGames Number of recent games to display (optional, default to 4)
    * @return RequestConfig
    */
    fun openingExplorerLichessRequestConfig(variant: VariantKey?, fen: kotlin.String?, play: kotlin.String?, speeds: kotlin.collections.List<Speed>?, ratings: kotlin.collections.List<java.math.BigDecimal>?, since: kotlin.String?, until: kotlin.String?, moves: java.math.BigDecimal?, topGames: java.math.BigDecimal?, recentGames: java.math.BigDecimal?) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf<kotlin.String, List<kotlin.String>>()
            .apply {
                if (variant != null) {
                    put("variant", listOf(variant.toString()))
                }
                if (fen != null) {
                    put("fen", listOf(fen.toString()))
                }
                if (play != null) {
                    put("play", listOf(play.toString()))
                }
                if (speeds != null) {
                    put("speeds", toMultiValue(speeds.toList(), "multi"))
                }
                if (ratings != null) {
                    put("ratings", toMultiValue(ratings.toList(), "multi"))
                }
                if (since != null) {
                    put("since", listOf(since.toString()))
                }
                if (until != null) {
                    put("until", listOf(until.toString()))
                }
                if (moves != null) {
                    put("moves", listOf(moves.toString()))
                }
                if (topGames != null) {
                    put("topGames", listOf(topGames.toString()))
                }
                if (recentGames != null) {
                    put("recentGames", listOf(recentGames.toString()))
                }
            }
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/lichess",
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Masters database
    * **Endpoint: &lt;https://explorer.lichess.ovh/masters&gt;**  Example: &#x60;curl https://explorer.lichess.ovh/masters?play&#x3D;d2d4,d7d5,c2c4,c7c6,c4d5&#x60; 
    * @param fen FEN of the root position (optional)
    * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  (optional, default to "")
    * @param since Include only games from this year or later (optional, default to 1952)
    * @param until Include only games from thi year or earlier (optional)
    * @param moves Number of most common moves to display (optional, default to 12)
    * @param topGames Number of top games to display (optional, default to 15)
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun openingExplorerMaster(fen: kotlin.String?, play: kotlin.String?, since: java.math.BigDecimal?, until: java.math.BigDecimal?, moves: java.math.BigDecimal?, topGames: java.math.BigDecimal?) : kotlin.Any {
        val localVariableConfig = openingExplorerMasterRequestConfig(fen = fen, play = play, since = since, until = until, moves = moves, topGames = topGames)

        val localVarResponse = request<Unit, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation openingExplorerMaster
    *
    * @param fen FEN of the root position (optional)
    * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  (optional, default to "")
    * @param since Include only games from this year or later (optional, default to 1952)
    * @param until Include only games from thi year or earlier (optional)
    * @param moves Number of most common moves to display (optional, default to 12)
    * @param topGames Number of top games to display (optional, default to 15)
    * @return RequestConfig
    */
    fun openingExplorerMasterRequestConfig(fen: kotlin.String?, play: kotlin.String?, since: java.math.BigDecimal?, until: java.math.BigDecimal?, moves: java.math.BigDecimal?, topGames: java.math.BigDecimal?) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf<kotlin.String, List<kotlin.String>>()
            .apply {
                if (fen != null) {
                    put("fen", listOf(fen.toString()))
                }
                if (play != null) {
                    put("play", listOf(play.toString()))
                }
                if (since != null) {
                    put("since", listOf(since.toString()))
                }
                if (until != null) {
                    put("until", listOf(until.toString()))
                }
                if (moves != null) {
                    put("moves", listOf(moves.toString()))
                }
                if (topGames != null) {
                    put("topGames", listOf(topGames.toString()))
                }
            }
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/masters",
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * OTB master game
    * **Endpoint: &#x60;https://explorer.lichess.ovh/masters/pgn/{gameId}&#x60;**  Example: &#x60;curl https://explorer.lichess.ovh/masters/pgn/aAbqI4ey&#x60; 
    * @param gameId  
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun openingExplorerMasterGame(gameId: kotlin.String) : kotlin.Any {
        val localVariableConfig = openingExplorerMasterGameRequestConfig(gameId = gameId)

        val localVarResponse = request<Unit, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation openingExplorerMasterGame
    *
    * @param gameId  
    * @return RequestConfig
    */
    fun openingExplorerMasterGameRequestConfig(gameId: kotlin.String) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/master/pgn/{gameId}".replace("{"+"gameId"+"}", "$gameId"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Player games
    * **Endpoint: &lt;https://explorer.lichess.ovh/player&gt;**  Games of a Lichess player.  Responds with a stream of newline delimited JSON. Will start indexing on demand, immediately respond with the current results, and stream more updates until indexing is complete. The stream is throttled and deduplicated. Empty lines may be sent to avoid timeouts.  Will index new games at most once per minute, and revisit previously ongoing games at most once every day.  Example: &#x60;curl https://explorer.lichess.ovh/player?player&#x3D;revoof&amp;color&#x3D;white&amp;play&#x3D;d2d4,d7d5&amp;recentGames&#x3D;1&#x60; 
    * @param variant Variant (optional, default to standard)
    * @param fen FEN of the root position (optional)
    * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  (optional, default to "")
    * @param speeds Comma separated list of game speeds to look for (optional)
    * @param modes Comma separated list of modes (optional)
    * @param since Include only games from this month or later (optional, default to "0000-01")
    * @param until Include only games from this month or earlier (optional, default to "3000-12")
    * @param moves Number of most common moves to display (optional)
    * @param recentGames Number of recent games to display (optional, default to 4)
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun openingExplorerPlayer(variant: VariantKey?, fen: kotlin.String?, play: kotlin.String?, speeds: kotlin.collections.List<Speed>?, modes: kotlin.collections.List<kotlin.String>?, since: kotlin.String?, until: kotlin.String?, moves: java.math.BigDecimal?, recentGames: java.math.BigDecimal?) : kotlin.Any {
        val localVariableConfig = openingExplorerPlayerRequestConfig(variant = variant, fen = fen, play = play, speeds = speeds, modes = modes, since = since, until = until, moves = moves, recentGames = recentGames)

        val localVarResponse = request<Unit, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation openingExplorerPlayer
    *
    * @param variant Variant (optional, default to standard)
    * @param fen FEN of the root position (optional)
    * @param play Comma separated sequence of legal moves in UCI notation. Play additional moves starting from &#x60;fen&#x60;. Required to find an opening name, if &#x60;fen&#x60; is not an exact match for a named position.  (optional, default to "")
    * @param speeds Comma separated list of game speeds to look for (optional)
    * @param modes Comma separated list of modes (optional)
    * @param since Include only games from this month or later (optional, default to "0000-01")
    * @param until Include only games from this month or earlier (optional, default to "3000-12")
    * @param moves Number of most common moves to display (optional)
    * @param recentGames Number of recent games to display (optional, default to 4)
    * @return RequestConfig
    */
    fun openingExplorerPlayerRequestConfig(variant: VariantKey?, fen: kotlin.String?, play: kotlin.String?, speeds: kotlin.collections.List<Speed>?, modes: kotlin.collections.List<kotlin.String>?, since: kotlin.String?, until: kotlin.String?, moves: java.math.BigDecimal?, recentGames: java.math.BigDecimal?) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf<kotlin.String, List<kotlin.String>>()
            .apply {
                if (variant != null) {
                    put("variant", listOf(variant.toString()))
                }
                if (fen != null) {
                    put("fen", listOf(fen.toString()))
                }
                if (play != null) {
                    put("play", listOf(play.toString()))
                }
                if (speeds != null) {
                    put("speeds", toMultiValue(speeds.toList(), "multi"))
                }
                if (modes != null) {
                    put("modes", toMultiValue(modes.toList(), "multi"))
                }
                if (since != null) {
                    put("since", listOf(since.toString()))
                }
                if (until != null) {
                    put("until", listOf(until.toString()))
                }
                if (moves != null) {
                    put("moves", listOf(moves.toString()))
                }
                if (recentGames != null) {
                    put("recentGames", listOf(recentGames.toString()))
                }
            }
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/player?",
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

}
