/**
 * Lichess.org API reference
 *
 * # Introduction Welcome to the reference for the Lichess API! Lichess is free/libre, open-source chess server powered by volunteers and donations. - Get help in the [Lichess Discord channel](https://discord.gg/lichess) - [Contribute to this documentation on Github](https://github.com/lichess-org/api) - Check out [Lichess widgets to embed in your website](https://lichess.org/developers) - [Download all Lichess rated games](https://database.lichess.org/) - [Download all Lichess puzzles with themes, ratings and votes](https://database.lichess.org/#puzzles)  ## Endpoint All requests go to `https://lichess.org` (unless otherwise specified).  ## Clients - [Python general API](https://github.com/ZackClements/berserk) - [MicroPython general API](https://github.com/mkomon/uberserk) - [Python general API - async](https://pypi.org/project/async-lichess-sdk) - [Python Lichess Bot](https://github.com/careless25/lichess-bot) - [Python Board API for Certabo](https://github.com/haklein/certabo-lichess) - [Java general API](https://github.com/tors42/chariot)  ## Rate limiting All requests are rate limited using various strategies, to ensure the API remains responsive for everyone. Only make one request at a time. If you receive an HTTP response with a [429 status](https://en.wikipedia.org/wiki/List_of_HTTP_status_codes#429), please wait a full minute before resuming API usage.  ## Streaming with ND-JSON Some API endpoints stream their responses as [Newline Delimited JSON a.k.a. **nd-json**](http://ndjson.org/), with one JSON object per line.  Here's a [JavaScript utility function](https://gist.github.com/ornicar/a097406810939cf7be1df8ea30e94f3e) to help reading NDJSON streamed responses. 
 *
 * The version of the OpenAPI document: 2.0.0
 * 
 *
 * Please note:
 * This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * Do not edit this file manually.
 */

@file:Suppress(
    "ArrayInDataClass",
    "EnumEntryName",
    "RemoveRedundantQualifierName",
    "UnusedImport"
)

package org.openapitools.client.apis

import org.openapitools.client.models.Error
import org.openapitools.client.models.Ok
import org.openapitools.client.models.SwissUnauthorisedEdit
import org.openapitools.client.models.VariantKey

import org.openapitools.client.infrastructure.ApiClient
import org.openapitools.client.infrastructure.ClientException
import org.openapitools.client.infrastructure.ClientError
import org.openapitools.client.infrastructure.ServerException
import org.openapitools.client.infrastructure.ServerError
import org.openapitools.client.infrastructure.MultiValueMap
import org.openapitools.client.infrastructure.RequestConfig
import org.openapitools.client.infrastructure.RequestMethod
import org.openapitools.client.infrastructure.ResponseType
import org.openapitools.client.infrastructure.Success
import org.openapitools.client.infrastructure.toMultiValue

class SwissTournamentsApi(basePath: kotlin.String = defaultBasePath) : ApiClient(basePath) {
    companion object {
        @JvmStatic
        val defaultBasePath: String by lazy {
            System.getProperties().getProperty("org.openapitools.client.baseUrl", "https://lichess.org")
        }
    }

    /**
    * Join a Swiss tournament
    * Join a Swiss tournament, possibly with a password. 
    * @param id The tournament ID. 
    * @param password The tournament password, if one is required (optional)
    * @return Ok
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun apiSwissJoin(id: kotlin.String, password: kotlin.String?) : Ok {
        val localVariableConfig = apiSwissJoinRequestConfig(id = id, password = password)

        val localVarResponse = request<Map<String, Any?>, Ok>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as Ok
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation apiSwissJoin
    *
    * @param id The tournament ID. 
    * @param password The tournament password, if one is required (optional)
    * @return RequestConfig
    */
    fun apiSwissJoinRequestConfig(id: kotlin.String, password: kotlin.String?) : RequestConfig<Map<String, Any?>> {
        val localVariableBody = mapOf("password" to password)
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf("Content-Type" to "application/x-www-form-urlencoded")

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/swiss/{id}/join".replace("{"+"id"+"}", "$id"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Create a new Swiss tournament
    * Create a Swiss tournament for your team.  This endpoint mirrors the Swiss tournament form from your team pagee.  You can create up to 12 tournaments per day. 
    * @param teamId ID of the team 
    * @param clockLimit Clock initial time in seconds 
    * @param clockIncrement Clock increment in seconds 
    * @param nbRounds Maximum number of rounds to play 
    * @param name The tournament name. Leave empty to get a random Grandmaster name (optional)
    * @param startsAt Timestamp in milliseconds to start the tournament at a given date and time. By default, it starts 10 minutes after creation. (optional)
    * @param roundInterval How long to wait between each round, in seconds.  Set to 99999999 to manually schedule each round from the tournament UI.  (optional)
    * @param variant  (optional, default to VariantKey.standard)
    * @param description Anything you want to tell players about the tournament (optional)
    * @param rated Games are rated and impact players ratings (optional, default to true)
    * @param chatFor Who can read and write in the chat. - 0  &#x3D; No-one - 10 &#x3D; Only team leaders - 20 &#x3D; Only team members - 30 &#x3D; All Lichess players  (optional, default to 20)
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun apiSwissNew(teamId: kotlin.String, clockLimit: java.math.BigDecimal, clockIncrement: kotlin.Int, nbRounds: kotlin.Int, name: kotlin.String?, startsAt: kotlin.Int?, roundInterval: kotlin.Int?, variant: VariantKey?, description: kotlin.String?, rated: kotlin.Boolean?, chatFor: java.math.BigDecimal?) : kotlin.Any {
        val localVariableConfig = apiSwissNewRequestConfig(teamId = teamId, clockLimit = clockLimit, clockIncrement = clockIncrement, nbRounds = nbRounds, name = name, startsAt = startsAt, roundInterval = roundInterval, variant = variant, description = description, rated = rated, chatFor = chatFor)

        val localVarResponse = request<Map<String, Any?>, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation apiSwissNew
    *
    * @param teamId ID of the team 
    * @param clockLimit Clock initial time in seconds 
    * @param clockIncrement Clock increment in seconds 
    * @param nbRounds Maximum number of rounds to play 
    * @param name The tournament name. Leave empty to get a random Grandmaster name (optional)
    * @param startsAt Timestamp in milliseconds to start the tournament at a given date and time. By default, it starts 10 minutes after creation. (optional)
    * @param roundInterval How long to wait between each round, in seconds.  Set to 99999999 to manually schedule each round from the tournament UI.  (optional)
    * @param variant  (optional, default to VariantKey.standard)
    * @param description Anything you want to tell players about the tournament (optional)
    * @param rated Games are rated and impact players ratings (optional, default to true)
    * @param chatFor Who can read and write in the chat. - 0  &#x3D; No-one - 10 &#x3D; Only team leaders - 20 &#x3D; Only team members - 30 &#x3D; All Lichess players  (optional, default to 20)
    * @return RequestConfig
    */
    fun apiSwissNewRequestConfig(teamId: kotlin.String, clockLimit: java.math.BigDecimal, clockIncrement: kotlin.Int, nbRounds: kotlin.Int, name: kotlin.String?, startsAt: kotlin.Int?, roundInterval: kotlin.Int?, variant: VariantKey?, description: kotlin.String?, rated: kotlin.Boolean?, chatFor: java.math.BigDecimal?) : RequestConfig<Map<String, Any?>> {
        val localVariableBody = mapOf("name" to name, "clock.limit" to clockLimit, "clock.increment" to clockIncrement, "nbRounds" to nbRounds, "startsAt" to startsAt, "roundInterval" to roundInterval, "variant" to variant, "description" to description, "rated" to rated, "chatFor" to chatFor)
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf("Content-Type" to "application/x-www-form-urlencoded")

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/swiss/new/{teamId}".replace("{"+"teamId"+"}", "$teamId"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Terminate a Swiss tournament
    * Terminate a Swiss tournament 
    * @param id The Swiss tournament ID. 
    * @return Ok
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun apiSwissTerminate(id: kotlin.String) : Ok {
        val localVariableConfig = apiSwissTerminateRequestConfig(id = id)

        val localVarResponse = request<Unit, Ok>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as Ok
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation apiSwissTerminate
    *
    * @param id The Swiss tournament ID. 
    * @return RequestConfig
    */
    fun apiSwissTerminateRequestConfig(id: kotlin.String) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/swiss/{id}/terminate".replace("{"+"id"+"}", "$id"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Update a Swiss tournament.
    * Update a Swiss tournament.  Be mindful not to make important changes to ongoing tournaments. 
    * @param id The tournament ID. 
    * @param clockLimit Clock initial time in seconds 
    * @param clockIncrement Clock increment in seconds 
    * @param nbRounds Maximum number of rounds to play 
    * @param name The tournament name. Leave empty to get a random Grandmaster name (optional)
    * @param startsAt Timestamp in milliseconds to start the tournament at a given date and time. By default, it starts 10 minutes after creation. (optional)
    * @param roundInterval How long to wait between each round, in seconds.  Set to 99999999 to manually schedule each round from the tournament UI.  (optional)
    * @param variant  (optional, default to VariantKey.standard)
    * @param description Anything you want to tell players about the tournament (optional)
    * @param rated Games are rated and impact players ratings (optional, default to true)
    * @param chatFor Who can read and write in the chat. - 0  &#x3D; No-one - 10 &#x3D; Only team leaders - 20 &#x3D; Only team members - 30 &#x3D; All Lichess players  (optional, default to 20)
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun apiSwissUpdate(id: kotlin.String, clockLimit: java.math.BigDecimal, clockIncrement: kotlin.Int, nbRounds: kotlin.Int, name: kotlin.String?, startsAt: kotlin.Int?, roundInterval: kotlin.Int?, variant: VariantKey?, description: kotlin.String?, rated: kotlin.Boolean?, chatFor: java.math.BigDecimal?) : kotlin.Any {
        val localVariableConfig = apiSwissUpdateRequestConfig(id = id, clockLimit = clockLimit, clockIncrement = clockIncrement, nbRounds = nbRounds, name = name, startsAt = startsAt, roundInterval = roundInterval, variant = variant, description = description, rated = rated, chatFor = chatFor)

        val localVarResponse = request<Map<String, Any?>, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation apiSwissUpdate
    *
    * @param id The tournament ID. 
    * @param clockLimit Clock initial time in seconds 
    * @param clockIncrement Clock increment in seconds 
    * @param nbRounds Maximum number of rounds to play 
    * @param name The tournament name. Leave empty to get a random Grandmaster name (optional)
    * @param startsAt Timestamp in milliseconds to start the tournament at a given date and time. By default, it starts 10 minutes after creation. (optional)
    * @param roundInterval How long to wait between each round, in seconds.  Set to 99999999 to manually schedule each round from the tournament UI.  (optional)
    * @param variant  (optional, default to VariantKey.standard)
    * @param description Anything you want to tell players about the tournament (optional)
    * @param rated Games are rated and impact players ratings (optional, default to true)
    * @param chatFor Who can read and write in the chat. - 0  &#x3D; No-one - 10 &#x3D; Only team leaders - 20 &#x3D; Only team members - 30 &#x3D; All Lichess players  (optional, default to 20)
    * @return RequestConfig
    */
    fun apiSwissUpdateRequestConfig(id: kotlin.String, clockLimit: java.math.BigDecimal, clockIncrement: kotlin.Int, nbRounds: kotlin.Int, name: kotlin.String?, startsAt: kotlin.Int?, roundInterval: kotlin.Int?, variant: VariantKey?, description: kotlin.String?, rated: kotlin.Boolean?, chatFor: java.math.BigDecimal?) : RequestConfig<Map<String, Any?>> {
        val localVariableBody = mapOf("name" to name, "clock.limit" to clockLimit, "clock.increment" to clockIncrement, "nbRounds" to nbRounds, "startsAt" to startsAt, "roundInterval" to roundInterval, "variant" to variant, "description" to description, "rated" to rated, "chatFor" to chatFor)
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf("Content-Type" to "application/x-www-form-urlencoded")

        return RequestConfig(
            method = RequestMethod.POST,
            path = "/api/swiss/{id}/edit".replace("{"+"id"+"}", "$id"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Get team swiss tournaments
    * Get all swiss tournaments of a team.  Tournaments are sorted by reverse chronological order of start date (last starting first).  Tournaments are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON). 
    * @param teamId  
    * @param max How many tournaments to download. (optional, default to 100)
    * @return kotlin.collections.List<kotlin.Any>
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun apiTeamSwiss(teamId: kotlin.String, max: kotlin.Int?) : kotlin.collections.List<kotlin.Any> {
        val localVariableConfig = apiTeamSwissRequestConfig(teamId = teamId, max = max)

        val localVarResponse = request<Unit, kotlin.collections.List<kotlin.Any>>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.collections.List<kotlin.Any>
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation apiTeamSwiss
    *
    * @param teamId  
    * @param max How many tournaments to download. (optional, default to 100)
    * @return RequestConfig
    */
    fun apiTeamSwissRequestConfig(teamId: kotlin.String, max: kotlin.Int?) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf<kotlin.String, List<kotlin.String>>()
            .apply {
                if (max != null) {
                    put("max", listOf(max.toString()))
                }
            }
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/api/team/{teamId}/swiss".replace("{"+"teamId"+"}", "$teamId"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Export games of a Swiss tournament
    * Download games of a swiss tournament in PGN or [ndjson](#section/Introduction/Streaming-with-ND-JSON) format.  Games are sorted by reverse chronological order (last round first) 
    * @param id The tournament ID. 
    * @param moves Include the PGN moves. (optional, default to true)
    * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. (optional, default to false)
    * @param tags Include the PGN tags. (optional, default to true)
    * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  (optional, default to false)
    * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  (optional, default to false)
    * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  (optional, default to false)
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun gamesBySwiss(id: kotlin.String, moves: kotlin.Boolean?, pgnInJson: kotlin.Boolean?, tags: kotlin.Boolean?, clocks: kotlin.Boolean?, evals: kotlin.Boolean?, opening: kotlin.Boolean?) : kotlin.Any {
        val localVariableConfig = gamesBySwissRequestConfig(id = id, moves = moves, pgnInJson = pgnInJson, tags = tags, clocks = clocks, evals = evals, opening = opening)

        val localVarResponse = request<Unit, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation gamesBySwiss
    *
    * @param id The tournament ID. 
    * @param moves Include the PGN moves. (optional, default to true)
    * @param pgnInJson Include the full PGN within the JSON response, in a &#x60;pgn&#x60; field. (optional, default to false)
    * @param tags Include the PGN tags. (optional, default to true)
    * @param clocks Include clock comments in the PGN moves, when available.  Example: &#x60;2. exd5 { [%clk 1:01:27] } e5 { [%clk 1:01:28] }&#x60;  (optional, default to false)
    * @param evals Include analysis evaluation comments in the PGN, when available.  Example: &#x60;12. Bxf6 { [%eval 0.23] } a3 { [%eval -1.09] }&#x60;  (optional, default to false)
    * @param opening Include the opening name.  Example: &#x60;[Opening \&quot;King&#39;s Gambit Accepted, King&#39;s Knight Gambit\&quot;]&#x60;  (optional, default to false)
    * @return RequestConfig
    */
    fun gamesBySwissRequestConfig(id: kotlin.String, moves: kotlin.Boolean?, pgnInJson: kotlin.Boolean?, tags: kotlin.Boolean?, clocks: kotlin.Boolean?, evals: kotlin.Boolean?, opening: kotlin.Boolean?) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf<kotlin.String, List<kotlin.String>>()
            .apply {
                if (moves != null) {
                    put("moves", listOf(moves.toString()))
                }
                if (pgnInJson != null) {
                    put("pgnInJson", listOf(pgnInJson.toString()))
                }
                if (tags != null) {
                    put("tags", listOf(tags.toString()))
                }
                if (clocks != null) {
                    put("clocks", listOf(clocks.toString()))
                }
                if (evals != null) {
                    put("evals", listOf(evals.toString()))
                }
                if (opening != null) {
                    put("opening", listOf(opening.toString()))
                }
            }
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/api/swiss/{id}/games".replace("{"+"id"+"}", "$id"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Get results of a swiss tournament
    * Players of a swiss tournament, with their score and performance, sorted by rank (best first).  Players are streamed as [ndjson](#section/Introduction/Streaming-with-ND-JSON).  If called on an ongoing tournament, results can be inconsistent due to ranking changes while the players are being streamed. Use on finished tournaments for guaranteed consistency. 
    * @param id The tournament ID. 
    * @param nb Max number of players to fetch (optional)
    * @return kotlin.Any
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun resultsBySwiss(id: kotlin.String, nb: kotlin.Int?) : kotlin.Any {
        val localVariableConfig = resultsBySwissRequestConfig(id = id, nb = nb)

        val localVarResponse = request<Unit, kotlin.Any>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.Any
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation resultsBySwiss
    *
    * @param id The tournament ID. 
    * @param nb Max number of players to fetch (optional)
    * @return RequestConfig
    */
    fun resultsBySwissRequestConfig(id: kotlin.String, nb: kotlin.Int?) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf<kotlin.String, List<kotlin.String>>()
            .apply {
                if (nb != null) {
                    put("nb", listOf(nb.toString()))
                }
            }
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/api/swiss/{id}/results".replace("{"+"id"+"}", "$id"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

    /**
    * Export TRF of a Swiss tournament
    * Download a tournament in the Tournament Report File format, the FIDE standard.  Documentation: &lt;https://www.fide.com/FIDE/handbook/C04Annex2_TRF16.pdf&gt;  Example: &lt;https://lichess.org/swiss/j8rtJ5GL.trf&gt; 
    * @param id The tournament ID. 
    * @return kotlin.String
    * @throws UnsupportedOperationException If the API returns an informational or redirection response
    * @throws ClientException If the API returns a client error response
    * @throws ServerException If the API returns a server error response
    */
    @Suppress("UNCHECKED_CAST")
    @Throws(UnsupportedOperationException::class, ClientException::class, ServerException::class)
    fun swissTrf(id: kotlin.String) : kotlin.String {
        val localVariableConfig = swissTrfRequestConfig(id = id)

        val localVarResponse = request<Unit, kotlin.String>(
            localVariableConfig
        )

        return when (localVarResponse.responseType) {
            ResponseType.Success -> (localVarResponse as Success<*>).data as kotlin.String
            ResponseType.Informational -> throw UnsupportedOperationException("Client does not support Informational responses.")
            ResponseType.Redirection -> throw UnsupportedOperationException("Client does not support Redirection responses.")
            ResponseType.ClientError -> {
                val localVarError = localVarResponse as ClientError<*>
                throw ClientException("Client error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
            ResponseType.ServerError -> {
                val localVarError = localVarResponse as ServerError<*>
                throw ServerException("Server error : ${localVarError.statusCode} ${localVarError.message.orEmpty()}", localVarError.statusCode, localVarResponse)
            }
        }
    }

    /**
    * To obtain the request config of the operation swissTrf
    *
    * @param id The tournament ID. 
    * @return RequestConfig
    */
    fun swissTrfRequestConfig(id: kotlin.String) : RequestConfig<Unit> {
        val localVariableBody = null
        val localVariableQuery: MultiValueMap = mutableMapOf()
        val localVariableHeaders: MutableMap<String, String> = mutableMapOf()

        return RequestConfig(
            method = RequestMethod.GET,
            path = "/swiss/{id}.trf".replace("{"+"id"+"}", "$id"),
            query = localVariableQuery,
            headers = localVariableHeaders,
            body = localVariableBody
        )
    }

}
