/**
 * Lichess.org API reference
 *
 * # Introduction Welcome to the reference for the Lichess API! Lichess is free/libre, open-source chess server powered by volunteers and donations. - Get help in the [Lichess Discord channel](https://discord.gg/lichess) - [Contribute to this documentation on Github](https://github.com/lichess-org/api) - Check out [Lichess widgets to embed in your website](https://lichess.org/developers) - [Download all Lichess rated games](https://database.lichess.org/) - [Download all Lichess puzzles with themes, ratings and votes](https://database.lichess.org/#puzzles)  ## Endpoint All requests go to `https://lichess.org` (unless otherwise specified).  ## Clients - [Python general API](https://github.com/ZackClements/berserk) - [MicroPython general API](https://github.com/mkomon/uberserk) - [Python general API - async](https://pypi.org/project/async-lichess-sdk) - [Python Lichess Bot](https://github.com/careless25/lichess-bot) - [Python Board API for Certabo](https://github.com/haklein/certabo-lichess) - [Java general API](https://github.com/tors42/chariot)  ## Rate limiting All requests are rate limited using various strategies, to ensure the API remains responsive for everyone. Only make one request at a time. If you receive an HTTP response with a [429 status](https://en.wikipedia.org/wiki/List_of_HTTP_status_codes#429), please wait a full minute before resuming API usage.  ## Streaming with ND-JSON Some API endpoints stream their responses as [Newline Delimited JSON a.k.a. **nd-json**](http://ndjson.org/), with one JSON object per line.  Here's a [JavaScript utility function](https://gist.github.com/ornicar/a097406810939cf7be1df8ea30e94f3e) to help reading NDJSON streamed responses. 
 *
 * The version of the OpenAPI document: 2.0.0
 * 
 *
 * Please note:
 * This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * Do not edit this file manually.
 */

@file:Suppress(
    "ArrayInDataClass",
    "EnumEntryName",
    "RemoveRedundantQualifierName",
    "UnusedImport"
)

package org.openapitools.client.models

import org.openapitools.client.models.Move

import com.squareup.moshi.Json

/**
 * 
 *
 * @param category `cursed-win` and `blessed-loss` means the 50-move rule prevents the decisive result.  `maybe-win` and `maybe-loss` means exact result is unknown due to [DTZ rounding](https://syzygy-tables.info/metrics#dtz), i.e., the win or loss could also be prevented by the 50-move rule if the user has deviated from the tablebase recommendation since the last pawn move or capture. 
 * @param dtz [DTZ50'' with rounding](https://syzygy-tables.info/metrics#dtz) or null if unknown 
 * @param dtm Distance to mate (only for positions with not more than 5 pieces)
 * @param checkmate 
 * @param stalemate 
 * @param variantWin Only in chess variants
 * @param variantLoss Only in chess variants
 * @param insufficientMaterial 
 * @param moves Information about legal moves, best first
 */

data class TablebaseJson (

    /* `cursed-win` and `blessed-loss` means the 50-move rule prevents the decisive result.  `maybe-win` and `maybe-loss` means exact result is unknown due to [DTZ rounding](https://syzygy-tables.info/metrics#dtz), i.e., the win or loss could also be prevented by the 50-move rule if the user has deviated from the tablebase recommendation since the last pawn move or capture.  */
    @Json(name = "category")
    val category: TablebaseJson.Category? = null,

    /* [DTZ50'' with rounding](https://syzygy-tables.info/metrics#dtz) or null if unknown  */
    @Json(name = "dtz")
    val dtz: kotlin.Int? = null,

    /* Distance to mate (only for positions with not more than 5 pieces) */
    @Json(name = "dtm")
    val dtm: kotlin.Int? = null,

    @Json(name = "checkmate")
    val checkmate: kotlin.Boolean? = null,

    @Json(name = "stalemate")
    val stalemate: kotlin.Boolean? = null,

    /* Only in chess variants */
    @Json(name = "variant_win")
    val variantWin: kotlin.Boolean? = null,

    /* Only in chess variants */
    @Json(name = "variant_loss")
    val variantLoss: kotlin.Boolean? = null,

    @Json(name = "insufficient_material")
    val insufficientMaterial: kotlin.Boolean? = null,

    /* Information about legal moves, best first */
    @Json(name = "moves")
    val moves: kotlin.collections.List<Move>? = null

) {

    /**
     * `cursed-win` and `blessed-loss` means the 50-move rule prevents the decisive result.  `maybe-win` and `maybe-loss` means exact result is unknown due to [DTZ rounding](https://syzygy-tables.info/metrics#dtz), i.e., the win or loss could also be prevented by the 50-move rule if the user has deviated from the tablebase recommendation since the last pawn move or capture. 
     *
     * Values: win,unknown,maybeMinusWin,cursedMinusWin,draw,blessedMinusLoss,maybeMinusLoss,loss
     */
    enum class Category(val value: kotlin.String) {
        @Json(name = "win") win("win"),
        @Json(name = "unknown") unknown("unknown"),
        @Json(name = "maybe-win") maybeMinusWin("maybe-win"),
        @Json(name = "cursed-win") cursedMinusWin("cursed-win"),
        @Json(name = "draw") draw("draw"),
        @Json(name = "blessed-loss") blessedMinusLoss("blessed-loss"),
        @Json(name = "maybe-loss") maybeMinusLoss("maybe-loss"),
        @Json(name = "loss") loss("loss");
    }
}

